@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/widgets.cpp   3.0.3   edited Oct 12 12:18 $
+** $Id:  qt/widgets.cpp   3.0.5   edited May 7 17:36 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -65,6 +65,16 @@
 #include "../application/filesave.xpm"
 #include "../application/fileprint.xpm"
 
+class MyLabel : public QLabel
+{
+public:
+    MyLabel( QWidget *parent = 0, const char *name = 0 )
+	: QLabel( parent, name ) { }
+
+    virtual QSize minimumSizeHint() const {
+	return QSize( 1, 1 );
+    }
+};
 
 class MyWhatsThis : public QWhatsThis
 {
@@ -511,7 +521,7 @@ WidgetView::WidgetView( QWidget *parent, const char *name )
 
     // Create an label and a message in the status bar
     // The message is updated when buttons are clicked etc.
-    msg = new QLabel( statusBar(), "message" );
+    msg = new MyLabel( statusBar(), "message" );
     msg->setAlignment( AlignCenter );
     QFont boldfont; boldfont.setWeight(QFont::Bold);
     msg->setFont( boldfont );
