@@ -1,3 +1,3 @@
-#error "/tmp/qt-3.0-reggie-28534/qt/extensions/nsplugin/src/npunix.c must be provided by Netscape"
+#error "/home/reggie/tmp/qt-3.0-reggie-5401/qt/extensions/nsplugin/src/npunix.c must be provided by Netscape"
 #error "This file is just a placeholder. Please see the documentation"
 #error "to learn how to obtain the real file"
