@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qwidget.h   3.0.2   edited Feb 11 02:58 $
+** $Id:  qt/qwidget.h   3.0.5   edited Apr 30 21:58 $
 **
 ** Definition of QWidget class
 **
@@ -442,7 +442,6 @@ public:
 #ifndef QMAC_NO_QUARTZ
     CGContextRef macCGContext(bool clipped=TRUE) const;
 #endif
-    bool macDropEnabled;
 #endif
 
 protected:
@@ -550,10 +549,11 @@ private:
     void	 focusInputContext();
     void	 checkChildrenDnd();
 #elif defined(Q_WS_MAC)
-    uint    own_id : 1; //owns the winid
+    uint    own_id : 1, macDropEnabled : 1;
     EventHandlerRef window_event;
     //mac event functions
-    void propagateUpdates();
+    void    propagateUpdates();
+    void    update( const QRegion& );
     //friends, way too many - fix this immediatly!
     friend void qt_clean_root_win();
     friend bool qt_recreate_root_win();
