@@ -34,6 +34,7 @@
 static ulong ref = 0;
 static bool use_xp  = FALSE;
 static bool init_xp = FALSE;
+static QMap<QString,HTHEME> *handleMap = 0;
 
 class QWindowsXPStylePrivate
 {
@@ -73,6 +74,13 @@ public:
 		limboWidget = 0;
 		delete tabbody;
 		tabbody = 0;
+		if ( handleMap ) {
+		    QMap<QString, HTHEME>::Iterator it;
+		    for ( it = handleMap->begin(); it != handleMap->end(); ++it )
+			CloseThemeData( it.data() );
+		    delete handleMap;
+		    handleMap = 0;
+		}		
 	    }
 	}
     }
@@ -119,16 +127,15 @@ const QWidget *QWindowsXPStylePrivate::currentWidget = 0;
 QWidget *QWindowsXPStylePrivate::limboWidget = 0;
 QPixmap *QWindowsXPStylePrivate::tabbody = 0;
 
+
 struct XPThemeData
 {
-    XPThemeData( const QWidget *w = 0, const QPainter *p = 0, LPCWSTR theme = 0, int part = 0, int state = 0, const QRect &r = QRect() )
+    XPThemeData( const QWidget *w = 0, QPainter *p = 0, const QString &theme = QString::null, int part = 0, int state = 0, const QRect &r = QRect() )
         : widget( w ), painter( p ), name( theme ),partId( part ), stateId( state ), rec( r ), htheme( 0 )
     {
     }
     ~XPThemeData()
     {
-        if ( htheme )
-            CloseThemeData( htheme );
     }
     
     HTHEME handle()
@@ -136,8 +143,21 @@ struct XPThemeData
 	if ( !use_xp )
 	    return NULL;
 	
-        if ( !htheme )
-            htheme = OpenThemeData( QWindowsXPStylePrivate::winId( widget ), name ); 
+	if ( !htheme && handleMap )
+	    htheme = handleMap->operator[]( name );
+
+        if ( !htheme ) {
+	    static wchar_t nm[256];
+	    Q_ASSERT( name.length() < 255 );
+	    memcpy( nm, (wchar_t*)name.unicode(), sizeof(wchar_t)*name.length() );
+	    nm[name.length()] = 0;
+            htheme = OpenThemeData( QWindowsXPStylePrivate::winId( widget ), nm );
+	    if ( htheme ) {
+		if ( !handleMap )
+		    handleMap = new QMap<QString, HTHEME>;
+		handleMap->operator[]( name ) = htheme;
+	    }
+	}
 	
         return htheme;
     }
@@ -158,18 +178,6 @@ struct XPThemeData
         return r;
     }
     
-    void operator=( const XPThemeData &orig )
-    {
-        if ( htheme )
-            CloseThemeData( htheme );
-	
-        name = orig.name;
-        partId = orig.partId;
-        stateId = orig.stateId;
-        rec = orig.rec;
-        htheme = orig.htheme;
-    }
-
     HRGN mask()
     {
 	if ( IsThemeBackgroundPartiallyTransparent( handle(), partId, stateId ) ) {
@@ -194,18 +202,33 @@ struct XPThemeData
 	if ( sId )
 	    stateId = sId;
 
-	ulong res = DrawThemeBackground( handle(), painter->handle(), partId, stateId, &rect(), 0 );
+	if ( name && name == "TAB" && (
+	    partId == TABP_TABITEMLEFTEDGE ||
+	    partId == TABP_TABITEMRIGHTEDGE ||
+	    partId == TABP_TABITEM ) ) {
+	    QRect oldrec = rec;
+	    rec = QRect( 0, 0, rec.width(), rec.height() );
+	    QPixmap pm( rec.size() );
+	    QPainter p( &pm );
+	    p.eraseRect( 0, 0, rec.width(), rec.height() );
+	    DrawThemeBackground( handle(), p.handle(), partId, stateId, &rect(), 0 );
+	    rec = oldrec;
+	    painter->drawPixmap( rec.x(), rec.y(), pm );
+	} else {
+	    ulong res = DrawThemeBackground( handle(), painter->handle(), partId, stateId, &rect(), 0 );
+	}
     }
 
     int partId;
     int stateId;
-    QRect rec;    
+    QRect rec;
 
 private:
     const QWidget *widget;
-    const QPainter *painter;
-    LPCWSTR name;
+    QPainter *painter;
+    QString name;
     HTHEME htheme;
+    bool workAround;
 };
 
 const QPixmap *QWindowsXPStylePrivate::tabBody( QWidget *widget )
@@ -213,7 +236,7 @@ const QPixmap *QWindowsXPStylePrivate::tabBody( QWidget *widget )
     if ( !tabbody ) {
 	tabbody = new QPixmap( 1, 1 );
 	QPainter painter( tabbody );
-	XPThemeData theme( widget, &painter, L"TAB", TABP_BODY, 0 );
+	XPThemeData theme( widget, &painter, "TAB", TABP_BODY, 0 );
 	SIZE sz;
 	GetThemePartSize( theme.handle(), painter.handle(), TABP_BODY, 0, 0, TS_TRUE, &sz );
 	painter.end();
@@ -246,8 +269,13 @@ void QWindowsXPStyle::unPolish( QApplication *app )
 
 void QWindowsXPStyle::polish( QApplication *app )
 {
+    static bool isPolished = FALSE;
+    if ( !isPolished )
+	ref--;
     QWindowsStyle::polish( app );
+    init_xp = FALSE;
     d->init();
+    isPolished = TRUE;
 }
 
 void QWindowsXPStyle::polish( QWidget *widget )
@@ -258,6 +286,7 @@ void QWindowsXPStyle::polish( QWidget *widget )
 
     if ( widget->inherits( "QButton" ) ) {
 	widget->installEventFilter( this );
+	widget->setBackgroundOrigin( QWidget::ParentOrigin );
     } else if ( widget->inherits( "QTabBar" ) ) {
 	widget->installEventFilter( this );
 	widget->setMouseTracking( TRUE );
@@ -289,7 +318,7 @@ void QWindowsXPStyle::polish( QWidget *widget )
     } else if ( widget->inherits( "QMenuBar" ) ) {
 	QPalette pal = widget->palette();
 
-	XPThemeData theme( widget, 0, L"MENUBAR", 0, 0 );
+	XPThemeData theme( widget, 0, "MENUBAR", 0, 0 );
 	if ( theme.isValid() ) {
 	    COLORREF cref;
 	    GetThemeColor( theme.handle(), 0, 0, TMT_MENUBAR, &cref );
@@ -334,19 +363,19 @@ void QWindowsXPStyle::updateRegion( QWidget *widget )
 
     if ( widget->inherits( "QTitleBar" ) && !widget->inherits( "QDockWindowTitleBar" ) ) {
 	if ( widget->isMinimized() ) {
-	    XPThemeData theme( widget, 0, L"WINDOW", WP_MINCAPTION, CS_ACTIVE, widget->rect() );
+	    XPThemeData theme( widget, 0, "WINDOW", WP_MINCAPTION, CS_ACTIVE, widget->rect() );
 	    theme.setTransparency();
-	    XPThemeData theme2( widget->parentWidget(), 0, L"WINDOW", WP_MINCAPTION, CS_ACTIVE, widget->rect() );
+	    XPThemeData theme2( widget->parentWidget(), 0, "WINDOW", WP_MINCAPTION, CS_ACTIVE, widget->rect() );
 	    theme2.setTransparency();
 	} else {
 	    int partId = WP_CAPTION;
 	    if ( widget->inherits( "QDockWindowTitleBar" ) )
 		partId = WP_SMALLCAPTION;
-	    XPThemeData theme( widget, 0, L"WINDOW", partId, CS_ACTIVE, widget->rect() );
+	    XPThemeData theme( widget, 0, "WINDOW", partId, CS_ACTIVE, widget->rect() );
 	    theme.setTransparency();
 	}
     } else if ( widget->inherits( "QWorkspaceChild" ) ) {
-	XPThemeData theme( widget, 0, L"WINDOW", WP_CAPTION, CS_ACTIVE, widget->rect() );
+	XPThemeData theme( widget, 0, "WINDOW", WP_CAPTION, CS_ACTIVE, widget->rect() );
 	theme.setTransparency();
 	theme.rec = widget->parentWidget()->rect();
 	RECT r = theme.rect();
@@ -366,7 +395,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	return;
     }
     
-    LPCWSTR name = 0;
+    QString name;
     int partId = 0;
     int stateId = 0;
     QRect rect = r;
@@ -374,7 +403,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
     switch ( op ) {
     case PE_ButtonCommand:
     case PE_ButtonBevel:
-	name = L"BUTTON";
+	name = "BUTTON";
 	partId = BP_PUSHBUTTON;
 	if ( !flags & Style_Enabled )
 	    stateId = PBS_DISABLED;
@@ -390,7 +419,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 	
     case PE_ButtonTool:
-	name = L"TOOLBAR";
+	name = "TOOLBAR";
 	partId = TP_BUTTON;
 	if ( !flags & Style_Enabled )
 	    stateId = TS_DISABLED;
@@ -405,7 +434,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 	
     case PE_ButtonDropDown:
-	name = L"TOOLBAR";
+	name = "TOOLBAR";
 	partId = TP_SPLITBUTTONDROPDOWN;
 	if ( !flags & Style_Enabled )
 	    stateId = TS_DISABLED;
@@ -420,7 +449,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 
     case PE_Indicator:
-	name = L"BUTTON";
+	name = "BUTTON";
 	partId = BP_CHECKBOX;
 	if ( !(flags & Style_Enabled) )
 	    stateId = CBS_UNCHECKEDDISABLED;
@@ -442,7 +471,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	return;
 
     case PE_ExclusiveIndicator:
-	name = L"BUTTON";
+	name = "BUTTON";
 	partId = BP_RADIOBUTTON;
 	if ( !(flags & Style_Enabled) )
 	    stateId = RBS_UNCHECKEDDISABLED;
@@ -465,7 +494,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 
     case PE_PanelLineEdit:
-	name = L"EDIT";
+	name = "EDIT";
 	partId = EP_EDITTEXT;
 	if ( !(flags & Style_Enabled) )
 	    stateId = ETS_DISABLED;
@@ -474,7 +503,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 
     case PE_PanelTabWidget:
-	name = L"TAB";
+	name = "TAB";
 	partId = TABP_PANE;
 	break;
 
@@ -489,13 +518,13 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 
     case PE_PanelDockWindow:
-	name = L"REBAR";
+	name = "REBAR";
 	partId = RP_BAND;
 	stateId = 1;
 	break;
 	
     case PE_HeaderSection:
-	name = L"HEADER";
+	name = "HEADER";
 	partId = HP_HEADERITEM;
 	if ( flags & Style_Down )
 	    stateId = HIS_PRESSED;
@@ -506,7 +535,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 
     case PE_HeaderArrow:
-	name = L"HEADER";
+	name = "HEADER";
 	partId = HP_HEADERSORTARROW;
 	if ( flags & Style_Down )
 	    stateId = HSAS_SORTEDDOWN;
@@ -515,12 +544,12 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 	
     case PE_StatusBarSection:
-	name = L"STATUS";
+	name = "STATUS";
 	partId = SP_PANE;
 	break;
 	
     case PE_GroupBoxFrame:
-	name = L"BUTTON";
+	name = "BUTTON";
 	partId = BP_GROUPBOX;
 	if ( !(flags & Style_Enabled) )
 	    stateId = GBS_DISABLED;
@@ -529,47 +558,49 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 
     case PE_SizeGrip:
-	name = L"STATUS";
+	name = "STATUS";
 	partId = SP_GRIPPER;
+	// empiric correction values...
+	rect.addCoords( -4, -8, 0, 0 ); 
 	break;
 
     case PE_ScrollBarAddLine:
-	name = L"SCROLLBAR";
+	name = "SCROLLBAR";
 	break;
 
     case PE_ScrollBarSubLine:
-	name = L"SCROLLBAR";
+	name = "SCROLLBAR";
 	break;
 
     case PE_ScrollBarAddPage:
-	name = L"SCROLLBAR";
+	name = "SCROLLBAR";
 	break;
 
     case PE_ScrollBarSubPage:
-	name = L"SCROLLBAR";
+	name = "SCROLLBAR";
 	break;
 
     case PE_ScrollBarSlider:
-	name = L"SCROLLBAR";
+	name = "SCROLLBAR";
 	break;
 
     case PE_ScrollBarFirst:
-	name = L"SCROLLBAR";
+	name = "SCROLLBAR";
 	break;
 	
     case PE_ScrollBarLast:
-	name = L"SCROLLBAR";
+	name = "SCROLLBAR";
 	break;
 	
     case PE_ProgressBarChunk:
-	name = L"PROGRESS";
+	name = "PROGRESS";
 	partId = PP_CHUNK;
 	stateId = 1;
 	rect = QRect( r.x(), r.y() + 3, r.width(), r.height() - 5 );
 	break;
 
     case PE_DockWindowHandle:
-	name = L"REBAR";
+	name = "REBAR";
 	if ( flags & Style_Horizontal )
 	    partId = RP_GRIPPER;
 	else
@@ -577,7 +608,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 	break;
 
     case PE_DockWindowSeparator:
-	name = L"TOOLBAR";
+	name = "TOOLBAR";
 	if ( flags & Style_Horizontal )
 	    partId = TP_SEPARATOR;
 	else
@@ -586,7 +617,7 @@ void QWindowsXPStyle::drawPrimitive( PrimitiveElement op,
 
     case PE_WindowFrame:
 	{
-	    name = L"WINDOW";
+	    name = "WINDOW";
 	    if ( flags & Style_Active )
 		stateId = FS_ACTIVE;
 	    else
@@ -644,7 +675,7 @@ void QWindowsXPStyle::drawControl( ControlElement element,
     }
     
     QRect rect(r);
-    LPCWSTR name = 0;
+    QString name;
     int partId = 0;
     int stateId = 0;
     if ( widget->hasMouse() )
@@ -654,7 +685,7 @@ void QWindowsXPStyle::drawControl( ControlElement element,
     case CE_PushButton:
 	//    case CE_PushButtonLabel:
 	{
-	    name = L"BUTTON";
+	    name = "BUTTON";
 	    partId = BP_PUSHBUTTON;
 	    QPushButton *pb = (QPushButton*)widget;
 	    if ( !(flags & Style_Enabled) )
@@ -672,7 +703,7 @@ void QWindowsXPStyle::drawControl( ControlElement element,
 
     case CE_TabBarTab:
 	//    case CE_TabBarLabel:
-	name = L"TAB";
+	name = "TAB";
 	{
 	    QTabBar *bar = (QTabBar*)widget;
 	    QTab *t = opt.tab();
@@ -708,7 +739,7 @@ void QWindowsXPStyle::drawControl( ControlElement element,
 	break;
 
     case CE_ProgressBarGroove:
-	name = L"PROGRESS";
+	name = "PROGRESS";
 	partId = PP_BAR;
 	stateId = 1;
 	break;
@@ -756,23 +787,23 @@ void QWindowsXPStyle::drawControlMask( ControlElement element,
 	return;
     }
 
-    LPCWSTR name = 0;
+    QString name = 0;
     int partId = 0;
     int stateId = 0;
     switch ( element ) {
     case CE_PushButton:
 	//    case CE_PushButtonLabel:
-	name = L"BUTTON";
+	name = "BUTTON";
 	partId = BP_PUSHBUTTON;
 	break;
 
     case CE_RadioButton:
-	name = L"BUTTON";
+	name = "BUTTON";
 	partId = BP_RADIOBUTTON;
 	break;
 
     case CE_CheckBox:
-	name = L"BUTTON";
+	name = "BUTTON";
 	partId = BP_CHECKBOX;
 	break;
 
@@ -852,7 +883,7 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
     case CC_SpinWidget:
         {
 	    QSpinWidget *spin = (QSpinWidget*)w;
-	    XPThemeData theme( w, p, L"SPIN" );
+	    XPThemeData theme( w, p, "SPIN" );
 
 	    if ( sub & SC_SpinWidgetFrame ) {
 		partId = EP_EDITTEXT;
@@ -863,7 +894,7 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
 		else 
 		    stateId = ETS_NORMAL;
 
-		XPThemeData ftheme( w, p, L"EDIT", partId, stateId, r );
+		XPThemeData ftheme( w, p, "EDIT", partId, stateId, r );
 		ftheme.drawBackground();
 	    }
 	    if ( sub & SC_SpinWidgetUp ) {
@@ -906,13 +937,13 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
 		    stateId = ETS_FOCUSED;
 		else
 		    stateId = ETS_NORMAL;
-		XPThemeData theme( w, p, L"EDIT", partId, stateId, r );
+		XPThemeData theme( w, p, "EDIT", partId, stateId, r );
 
 		theme.drawBackground();
 	    }
 
 	    if ( sub & SC_ComboBoxArrow ) {
-		XPThemeData theme( w, p, L"COMBOBOX" );
+		XPThemeData theme( w, p, "COMBOBOX" );
 		theme.rec = querySubControlMetrics( CC_ComboBox, w, SC_ComboBoxArrow, opt );
 		partId = CP_DROPDOWNBUTTON;
 		QComboBox *cb = (QComboBox*)w;
@@ -935,7 +966,7 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
 	
     case CC_ScrollBar:
         {
-	    XPThemeData theme( w, p, L"SCROLLBAR" );
+	    XPThemeData theme( w, p, "SCROLLBAR" );
 	    QScrollBar *bar = (QScrollBar*)w;
 	    bool maxedOut = ( bar->maxValue() == bar->minValue() );
 	    if ( maxedOut )
@@ -1056,7 +1087,7 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
         break;
     case CC_Slider:
 	{
-	    XPThemeData theme( w, p, L"TRACKBAR" );
+	    XPThemeData theme( w, p, "TRACKBAR" );
 	    QSlider *sl = (QSlider*)w;
 	    QRegion tickreg = sl->rect();
 	    if ( sub & SC_SliderGroove ) {
@@ -1191,7 +1222,7 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
 	
     case CC_ToolButton:
 	{
-	    XPThemeData theme( w, p, L"TOOLBAR" );
+	    XPThemeData theme( w, p, "TOOLBAR" );
 	    QToolButton *tb = (QToolButton*)w;
 	
 	    SFlags bflags = flags,
@@ -1251,7 +1282,7 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
 	{
 	    const QTitleBar *titlebar = (const QTitleBar *) w;
 
-	    XPThemeData theme( w, p, L"WINDOW" );
+	    XPThemeData theme( w, p, "WINDOW" );
 	    if ( sub & SC_TitleBarLabel ) {
 		theme.rec = titlebar->rect();
 		partId = titlebar->testWFlags( WStyle_Tool ) ? WP_SMALLCAPTION : 
@@ -1260,7 +1291,7 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
 		    partId = WP_SMALLCAPTION;
 		if ( !titlebar->isEnabled() )
 		    stateId = CS_DISABLED;
-		else if ( !titlebar->isActive() )
+		else if ( !titlebar->usesActiveColor() )
 		    stateId = CS_INACTIVE;
 		else 
 		    stateId = CS_ACTIVE;
@@ -1403,7 +1434,7 @@ void QWindowsXPStyle::drawComplexControl( ComplexControl control,
 		    if ( lh % 2 > 0 )
 			lh++;
 
-		    XPThemeData theme( w, p, L"TREEVIEW" );
+		    XPThemeData theme( w, p, "TREEVIEW" );
 
 		    // paint stuff in the magical area
 		    while ( child && y < r.height() ) {
@@ -1528,7 +1559,7 @@ int QWindowsXPStyle::pixelMetric( PixelMetric metric,
     case PM_IndicatorWidth:
     case PM_IndicatorHeight:
 	{
-	    XPThemeData theme( widget, 0, L"BUTTON", BP_CHECKBOX, CBS_UNCHECKEDNORMAL );
+	    XPThemeData theme( widget, 0, "BUTTON", BP_CHECKBOX, CBS_UNCHECKEDNORMAL );
 
 	    if ( theme.isValid() ) {
 		SIZE size;
@@ -1543,7 +1574,7 @@ int QWindowsXPStyle::pixelMetric( PixelMetric metric,
     case PM_ExclusiveIndicatorWidth:
     case PM_ExclusiveIndicatorHeight:
 	{
-	    XPThemeData theme( widget, 0, L"BUTTON", BP_RADIOBUTTON, RBS_UNCHECKEDNORMAL );
+	    XPThemeData theme( widget, 0, "BUTTON", BP_RADIOBUTTON, RBS_UNCHECKEDNORMAL );
 
 	    if ( theme.isValid() ) {
 		SIZE size;
@@ -1557,7 +1588,7 @@ int QWindowsXPStyle::pixelMetric( PixelMetric metric,
 
     case PM_ProgressBarChunkWidth:
 	{
-	    XPThemeData theme( widget, 0, L"PROGRESS", PP_CHUNK );
+	    XPThemeData theme( widget, 0, "PROGRESS", PP_CHUNK );
 
 	    if ( theme.isValid() ) {
 		SIZE size;
@@ -1569,7 +1600,7 @@ int QWindowsXPStyle::pixelMetric( PixelMetric metric,
 
     case PM_ScrollBarExtent:
 	{
-	    XPThemeData theme( widget, 0, L"SCROLLBAR", SBP_LOWERTRACKHORZ );
+	    XPThemeData theme( widget, 0, "SCROLLBAR", SBP_LOWERTRACKHORZ );
 
 	    if ( theme.isValid() ) {
 		SIZE size;
@@ -1581,7 +1612,7 @@ int QWindowsXPStyle::pixelMetric( PixelMetric metric,
 
     case PM_ScrollBarSliderMin:
 	{
-	    XPThemeData theme( widget, 0, L"SCROLLBAR", SBP_THUMBBTNVERT );
+	    XPThemeData theme( widget, 0, "SCROLLBAR", SBP_THUMBBTNVERT );
 
 	    if ( theme.isValid() ) {
 		SIZE size;
@@ -1593,7 +1624,7 @@ int QWindowsXPStyle::pixelMetric( PixelMetric metric,
 
     case PM_SliderThickness:
 	{
-	    XPThemeData theme( widget, 0, L"TRACKBAR", TKP_THUMB );
+	    XPThemeData theme( widget, 0, "TRACKBAR", TKP_THUMB );
 
 	    if ( theme.isValid() ) {
 		SIZE size;
@@ -1605,7 +1636,7 @@ int QWindowsXPStyle::pixelMetric( PixelMetric metric,
 
     case PM_MenuButtonIndicator:
 	{
-	    XPThemeData theme( widget, 0, L"TOOLBAR", TP_SPLITBUTTONDROPDOWN );
+	    XPThemeData theme( widget, 0, "TOOLBAR", TP_SPLITBUTTONDROPDOWN );
 
 	    if ( theme.isValid() ) {
 		SIZE size;
@@ -1630,6 +1661,9 @@ int QWindowsXPStyle::pixelMetric( PixelMetric metric,
     case PM_TitleBarHeight:
 	return QWindowsStyle::pixelMetric( metric, widget ) + 4;
 
+    case PM_DefaultFrameWidth:
+	return 1;
+
     default:
 	break;	
     }
@@ -1834,6 +1868,12 @@ bool QWindowsXPStyle::eventFilter( QObject *o, QEvent *e )
 	updateRegion( widget );
 	break;
 
+    case QEvent::Move:
+	if ( widget->paletteBackgroundPixmap() &&
+	     widget->backgroundOrigin() != QWidget::WidgetOrigin )
+	    widget->update();
+	break;
+
     default:
         break;
     }
