@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/metrowerks_xml.cpp   3.0.2   edited Feb 13 02:20 $
+** $Id:  qt/metrowerks_xml.cpp   3.0.5   edited May 21 13:38 $
 **
 ** Definition of ________ class.
 **
@@ -533,10 +533,8 @@ MetrowerksMakefileGenerator::init()
 	    project->variables()["QMAKE_LIBS"] += project->variables()["QMAKE_LIBS_QT"];
 	if(configs.findIndex("moc")) 
 	    configs.append("moc");
-	if ( !project->isActiveConfig("debug") ) {
+	if ( !project->isActiveConfig("debug") ) 
 	    project->variables()["DEFINES"].append("QT_NO_DEBUG");
-	    project->variables()["DEFINES"].append("QT_NO_CHECK");
-	}
     }
 
     //version handling
@@ -657,7 +655,7 @@ MetrowerksMakefileGenerator::createFork(const QString &f)
 }
 
 bool
-MetrowerksMakefileGenerator::fixifyToMacPath(QString &p, QString &v, bool exists)
+MetrowerksMakefileGenerator::fixifyToMacPath(QString &p, QString &v, bool )
 {
     v = "Absolute";
     if(p.find(':') != -1) //guess its macish already
