@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/pbuilder_pbx.cpp   3.0.2   edited Jan 16 07:40 $
+** $Id:  qt/pbuilder_pbx.cpp   3.0.5   edited Jun 22 02:13 $
 **
 ** Definition of ________ class.
 **
@@ -79,23 +79,24 @@ ProjectBuilderMakefileGenerator::writeMakefile(QTextStream &t)
 bool
 ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 {
-    QStringList tmp;
     int i;
+    QStringList tmp;
+    bool did_preprocess = FALSE;
 
     //HEADER
     t << "// !$*UTF8*$!" << "\n"
       << "{" << "\n"
       << "\t" << "archiveVersion = 1;" << "\n"
       << "\t" << "classes = {" << "\n" << "\t" << "};" << "\n"
-      << "\t" << "objectVersion = 34;" << "\n"
+      << "\t" << "objectVersion = " << pbuilderVersion() << ";" << "\n"
       << "\t" << "objects = {" << endl;
 
     //MAKE QMAKE equivlant
-    if(project->projectFile() != "(stdin)") {
+    if(!project->isActiveConfig("no_autoqmake") && project->projectFile() != "(stdin)") {
 	QString mkfile = Option::output_dir + Option::dir_sep + "qt_makeqmake.mak";
 	QFile mkf(mkfile);
 	if(mkf.open(IO_WriteOnly | IO_Translate)) {
-	    debug_msg(0, "Creating file: %s", mkfile.latin1());
+	    debug_msg(1, "Creating file: %s", mkfile.latin1());
 	    QTextStream mkt(&mkf);
 	    writeHeader(mkt);
 	    mkt << "QMAKE    = "	<<
@@ -129,25 +130,8 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	tmp = project->variables()[srcs[i]];
 	for(QStringList::Iterator it = tmp.begin(); it != tmp.end(); ++it) {
 	    QString file = (*it);
-	    if(file.right(Option::moc_ext.length()) == Option::moc_ext) {
+	    if(file.right(Option::moc_ext.length()) == Option::moc_ext) 
 		continue;
-	    } else if(!project->isEmpty("YACCIMPLS")) {
-		QStringList yaccs = project->variables()["YACCIMPLS"];
-		for(QStringList::Iterator yit = yaccs.begin(); yit != yaccs.end(); yit++) {
-		    if((*yit) == (*it)) {
-			file = project->first("YACCSOURCES");
-			break;
-		    }
-		}
-	    } else if(!project->isEmpty("LEXIMPLS") && !project->isActiveConfig("lex_included")) {
-		QStringList lexs = project->variables()["LEXIMPLS"];
-		for(QStringList::Iterator lit = lexs.begin(); lit != lexs.end(); lit++) {
-		    if((*lit) == (*it)) {
-			file = project->first("LEXSOURCES");
-			break;
-		    }
-		}
-	    }
 	    fileFixify(file);
 	    QString key = keyFor(file);
 	    project->variables()["QMAKE_PBX_" + srcs[i]].append(key);
@@ -192,22 +176,60 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	}
     }
     //PREPROCESS BUILDPHASE (just a makefile)
-    if(!project->isEmpty("UICIMPLS") || !project->isEmpty("SRCMOC")) {
+    if(!project->isEmpty("UICIMPLS") || !project->isEmpty("SRCMOC") ||
+	!project->isEmpty("YACCSOURCES") || !project->isEmpty("LEXSOURCES")) {
 	QString mkfile = Option::output_dir + Option::dir_sep + "qt_preprocess.mak";
 	QFile mkf(mkfile);
 	if(mkf.open(IO_WriteOnly | IO_Translate)) {
-	    debug_msg(0, "Creating file: %s", mkfile.latin1());
+	    did_preprocess = TRUE;
+	    debug_msg(1, "Creating file: %s", mkfile.latin1());
 	    QTextStream mkt(&mkf);
 	    writeHeader(mkt);
-	    mkt << "MOC = " << var("QMAKE_MOC") << endl;
-	    mkt << "UIC = " << var("QMAKE_UIC") << endl << endl;
+	    mkt << "MOC       = " << var("QMAKE_MOC") << endl;
+	    mkt << "UIC       = " << var("QMAKE_UIC") << endl;
+	    mkt << "LEX       = " << var("QMAKE_LEX") << endl;
+	    mkt << "LEXFLAGS  = " << var("QMAKE_LEXFLAGS") << endl;
+	    mkt << "YACC      = " << var("QMAKE_YACC") << endl;
+	    mkt << "YACCFLAGS = " << var("QMAKE_YACCFLAGS") << endl;
+	    mkt << "DEL_FILE  = " << var("QMAKE_DEL_FILE") << endl;
+	    mkt << "MOVE      = " << var("QMAKE_MOVE") << endl << endl;
 	    mkt << "FORMS = " << varList("UICIMPLS") << endl;
 	    mkt << "MOCS = " << varList("SRCMOC") << endl;
-	    mkt << "preprocess: $(FORMS) $(MOCS)" << endl << endl;
+	    mkt << "PARSERS =";
+	    if(!project->isEmpty("YACCSOURCES")) {
+		QStringList &yaccs = project->variables()["YACCSOURCES"];
+		for(QStringList::Iterator yit = yaccs.begin(); yit != yaccs.end(); ++yit) {
+		    QFileInfo fi((*yit));
+		    mkt << " " << fi.dirPath() << Option::dir_sep << fi.baseName(TRUE)
+			<< Option::yacc_mod << Option::cpp_ext.first();
+		}
+	    }
+	    if(!project->isEmpty("LEXSOURCES")) {
+		QStringList &lexs = project->variables()["LEXSOURCES"];
+		for(QStringList::Iterator lit = lexs.begin(); lit != lexs.end(); ++lit) {
+		    QFileInfo fi((*lit));
+		    mkt << " " << fi.dirPath() << Option::dir_sep << fi.baseName(TRUE)
+			<< Option::lex_mod << Option::cpp_ext.first();
+		}
+	    }
+	    mkt << "\n";
+	    mkt << "preprocess: $(FORMS) $(MOCS) $(PARSERS)" << endl;
+	    mkt << "preprocess_clean: mocclean uiclean parser_clean" << endl << endl;
+	    mkt << "mocclean:" << "\n";
+	    if(!project->isEmpty("SRCMOC"))
+		mkt << "\t-rm -f $(MOCS)" << "\n";
+	    mkt << "uiclean:" << "\n";
+	    if(!project->isEmpty("UICIMPLS"))
+		mkt << "\t-rm -f $(FORMS)" << "\n";
+	    mkt << "parser_clean:" << "\n";
+	    if(!project->isEmpty("YACCSOURCES") || !project->isEmpty("LEXSOURCES"))
+		mkt << "\t-rm -f $(PARSERS)" << "\n";
 	    writeUicSrc(mkt, "FORMS");
 	    writeMocSrc(mkt, "HEADERS");
 	    writeMocSrc(mkt, "SOURCES");
 	    writeMocSrc(mkt, "UICDECLS");
+	    writeYaccSrc(mkt, "YACCSOURCES");
+	    writeLexSrc(mkt, "LEXSOURCES");
 	    mkf.close();
 	}
 	QString phase_key = keyFor("QMAKE_PBX_PREPROCESST_BUILDPHASE");
@@ -244,92 +266,93 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	  << "\t\t" << "};" << "\n";
     }
 
-    //DUMP LIBRARIES
-    QStringList &libdirs = project->variables()["QMAKE_PBX_LIBPATHS"];
-    QString libs[] = { "QMAKE_LIBDIR_FLAGS", "QMAKE_LIBS", QString::null };
-    for(i = 0; !libs[i].isNull(); i++) {
-	tmp = project->variables()[libs[i]];
-	for(QStringList::Iterator it = tmp.begin(); it != tmp.end();) {
-	    bool remove = FALSE;
-	    QString library, name;
-	    if((*it).left(2) == "-L") {
-		QString r = (*it).right((*it).length() - 2);
-		fixEnvVariables(r);
-		libdirs.append(r);
-	    } else if((*it).left(2) == "-l") {
-		name = (*it).right((*it).length() - 2);
-		QString lib("lib" + name  + ".");
-		for(QStringList::Iterator lit = libdirs.begin(); lit != libdirs.end(); ++lit) {
-		    QString extns[] = { "dylib", "so", "a", QString::null };
-		    for(int n = 0; !extns[n].isNull(); n++) {
-			QString tmp =  (*lit) + Option::dir_sep + lib + extns[n];
-			if(QFile::exists(tmp)) {
-			    library = tmp;
-			    //don't remove, so it gets into LDFLAGS for now -- FIXME
-			    //remove = TRUE
+    if(!project->isActiveConfig("staticlib")) { //DUMP LIBRARIES
+	QStringList &libdirs = project->variables()["QMAKE_PBX_LIBPATHS"];
+	QString libs[] = { "QMAKE_LIBDIR_FLAGS", "QMAKE_LIBS", QString::null };
+	for(i = 0; !libs[i].isNull(); i++) {
+	    tmp = project->variables()[libs[i]];
+	    for(QStringList::Iterator it = tmp.begin(); it != tmp.end();) {
+		bool remove = FALSE;
+		QString library, name;
+		if((*it).left(2) == "-L") {
+		    QString r = (*it).right((*it).length() - 2);
+		    fixEnvVariables(r);
+		    libdirs.append(r);
+		} else if((*it).left(2) == "-l") {
+		    name = (*it).right((*it).length() - 2);
+		    QString lib("lib" + name  + ".");
+		    for(QStringList::Iterator lit = libdirs.begin(); lit != libdirs.end(); ++lit) {
+			QString extns[] = { "dylib", "so", "a", QString::null };
+			for(int n = 0; !extns[n].isNull(); n++) {
+			    QString tmp =  (*lit) + Option::dir_sep + lib + extns[n];
+			    if(QFile::exists(tmp)) {
+				library = tmp;
+				//don't remove, so it gets into LDFLAGS for now -- FIXME
+				//remove = TRUE
+				break;
+			    }
+			}
+		    }
+		} else if((*it) == "-framework") {
+		    ++it;
+		    if(it == tmp.end())
+			break;
+		    QStringList &fdirs = project->variables()["QMAKE_FRAMEWORKDIR"];
+		    if(fdirs.isEmpty())
+			fdirs.append("/System/Library/Frameworks/");
+		    for(QStringList::Iterator fit = fdirs.begin(); fit != fdirs.end(); ++fit) {
+			if(QFile::exists((*fit) + QDir::separator() + (*it) + ".framework")) {
+			    --it;
+			    it = tmp.remove(it);
+			    remove = TRUE;
+			    library = (*fit) + Option::dir_sep + (*it) + ".framework";
 			    break;
 			}
 		    }
+		} else if((*it).left(1) != "-") {
+		    remove = TRUE;
+		    library = (*it);
 		}
-	    } else if((*it) == "-framework") {
-		++it;
-		if(it == tmp.end())
-		    break;
-		QStringList &fdirs = project->variables()["QMAKE_FRAMEWORKDIR"];
-		if(fdirs.isEmpty())
-		    fdirs.append("/System/Library/Frameworks/");
-		for(QStringList::Iterator fit = fdirs.begin(); fit != fdirs.end(); ++fit) {
-		    if(QFile::exists((*fit) + QDir::separator() + (*it) + ".framework")) {
-			--it;
-			it = tmp.remove(it);
-			remove = TRUE;
-			library = (*fit) + Option::dir_sep + (*it) + ".framework";
-			break;
+		if(!library.isEmpty()) {
+		    if(name.isEmpty()) {
+			int slsh = library.findRev(Option::dir_sep);
+			if(slsh != -1)
+			    name = library.right(library.length() - slsh - 1);
 		    }
+		    fileFixify(library);
+		    QString key = keyFor(library);
+		    bool is_frmwrk = (library.right(10) == ".framework");
+		    t << "\t\t" << key << " = {" << "\n"
+		      << "\t\t\t" << "isa = " << (is_frmwrk ? "PBXFrameworkReference" : "PBXFileReference") << ";" << "\n"
+		      << "\t\t\t" << "name = \"" << name << "\";" << "\n"
+		      << "\t\t\t" << "path = \"" << library << "\";" << "\n"
+		      << "\t\t\t" << "refType = 0;" << "\n"
+		      << "\t\t" << "};" << "\n";
+		    project->variables()["QMAKE_PBX_LIBRARIES"].append(key);
+		    QString obj_key = library + ".o";
+		    obj_key = keyFor(obj_key);
+		    t << "\t\t" << obj_key << " = {" << "\n"
+		      << "\t\t\t" << "fileRef = " << key << ";" << "\n"
+		      << "\t\t\t" << "isa = PBXBuildFile;" << "\n"
+		      << "\t\t\t" << "settings = {" << "\n"
+		      << "\t\t\t" << "};" << "\n"
+		      << "\t\t" << "};" << "\n";
+		    project->variables()["QMAKE_PBX_BUILD_LIBRARIES"].append(obj_key);
 		}
-	    } else if((*it).left(1) != "-") {
-		remove = TRUE;
-		library = (*it);
+		if(remove)
+		    it = tmp.remove(it);
+		else
+		    ++it;
 	    }
-	    if(!library.isEmpty()) {
-		if(name.isEmpty()) {
-		    int slsh = library.findRev(Option::dir_sep);
-		    if(slsh != -1)
-			name = library.right(library.length() - slsh - 1);
-		}
-		fileFixify(library);
-		QString key = keyFor(library);
-		bool is_frmwrk = (library.right(10) == ".framework");
-		t << "\t\t" << key << " = {" << "\n"
-		  << "\t\t\t" << "isa = " << (is_frmwrk ? "PBXFrameworkReference" : "PBXFileReference") << ";" << "\n"
-		  << "\t\t\t" << "name = \"" << name << "\";" << "\n"
-		  << "\t\t\t" << "path = \"" << library << "\";" << "\n"
-		  << "\t\t\t" << "refType = 0;" << "\n"
-		  << "\t\t" << "};" << "\n";
-		project->variables()["QMAKE_PBX_LIBRARIES"].append(key);
-		QString obj_key = library + ".o";
-		obj_key = keyFor(obj_key);
-		t << "\t\t" << obj_key << " = {" << "\n"
-		  << "\t\t\t" << "fileRef = " << key << ";" << "\n"
-		  << "\t\t\t" << "isa = PBXBuildFile;" << "\n"
-		  << "\t\t\t" << "settings = {" << "\n"
-		  << "\t\t\t" << "};" << "\n"
-		  << "\t\t" << "};" << "\n";
-		project->variables()["QMAKE_PBX_BUILD_LIBRARIES"].append(obj_key);
-	    }
-	    if(remove)
-		it = tmp.remove(it);
-	    else
-		++it;
+	    project->variables()[libs[i]] = tmp;
 	}
-	project->variables()[libs[i]] = tmp;
     }
     //SUBLIBS BUILDPHASE (just another makefile)
     if(!project->isEmpty("SUBLIBS")) {
 	QString mkfile = Option::output_dir + Option::dir_sep + "qt_sublibs.mak";
 	QFile mkf(mkfile);
 	if(mkf.open(IO_WriteOnly | IO_Translate)) {
-	    debug_msg(0, "Creating file: %s", mkfile.latin1());
+	    debug_msg(1, "Creating file: %s", mkfile.latin1());
 	    QTextStream mkt(&mkf);
 	    writeHeader(mkt);
 	    mkt << "SUBLIBS= ";
@@ -379,19 +402,29 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	      << "\t\t\t" << "refType = 4;" << "\n"
 	      << "\t\t" << "};" << "\n";
 	}
-	tmp = project->variables()["QMAKE_PBX_BUILD_LIBRARIES"];
-	if(!tmp.isEmpty()) {
-	    QString grp("Frameworks & Libraries"), key = keyFor(grp);
-	    project->variables()["QMAKE_PBX_BUILDPHASES"].append(key);
-	    t << "\t\t" << key << " = {" << "\n"
-	      << "\t\t\t" << "buildActionMask = 2147483647;" << "\n"
-	      << "\t\t\t" << "files = (" << "\n"
-	      << varGlue("QMAKE_PBX_BUILD_LIBRARIES", "\t\t\t\t", ",\n\t\t\t\t", "\n")
-	      << "\t\t\t" << ");" << "\n"
-	      << "\t\t\t" << "isa = PBXFrameworksBuildPhase;" << "\n"
-	      << "\t\t\t" << "name = \"" << grp << "\";" << "\n"
-	      << "\t\t" << "};" << "\n";
-	}
+    }
+    {
+	QString grp("Frameworks & Libraries"), key = keyFor(grp);
+	project->variables()["QMAKE_PBX_BUILDPHASES"].append(key);
+	t << "\t\t" << key << " = {" << "\n"
+	  << "\t\t\t" << "buildActionMask = 2147483647;" << "\n"
+	  << "\t\t\t" << "files = (" << "\n"
+	  << varGlue("QMAKE_PBX_BUILD_LIBRARIES", "\t\t\t\t", ",\n\t\t\t\t", "\n")
+	  << "\t\t\t" << ");" << "\n"
+	  << "\t\t\t" << "isa = PBXFrameworksBuildPhase;" << "\n"
+	  << "\t\t\t" << "name = \"" << grp << "\";" << "\n"
+	  << "\t\t" << "};" << "\n";
+    }
+    if(project->first("TEMPLATE") == "app") { //BUNDLE RESOURCES
+	QString grp("Bundle Resources"), key = keyFor(grp);
+	project->variables()["QMAKE_PBX_BUILDPHASES"].append(key);
+	t << "\t\t" << key << " = {" << "\n"
+	  << "\t\t\t" << "buildActionMask = 2147483647;" << "\n"
+	  << "\t\t\t" << "files = (" << "\n"
+	  << "\t\t\t" << ");" << "\n"
+	  << "\t\t\t" << "isa = PBXResourcesBuildPhase;" << "\n"
+	  << "\t\t\t" << "name = \"" << grp << "\";" << "\n"
+	  << "\t\t" << "};" << "\n";
     }
 
     //DUMP EVERYTHING THAT TIES THE ABOVE TOGETHER
@@ -408,8 +441,7 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	  << "\t\t\t" << "refType = 4;" << "\n"
 	  << "\t\t" << "};" << "\n";
     }
-    //INSTALL BUILDPHASE (sh script)
-    if(!project->isEmpty("DESTDIR")) {
+    { //INSTALL BUILDPHASE (sh script)
 	QString targ = project->first("TARGET");
 	if(project->first("TEMPLATE") == "lib" && !project->isActiveConfig("staticlib") &&
 	   project->isActiveConfig("frameworklib"))
@@ -436,28 +468,40 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	QString script = Option::output_dir + Option::dir_sep + "qt_install.sh";
 	QFile shf(script);
 	if(shf.open(IO_WriteOnly | IO_Translate)) {
-	    debug_msg(0, "Creating file: %s", script.latin1());
-	    QString lib = project->first("QMAKE_ORIG_TARGET");
+	    debug_msg(1, "Creating file: %s", script.latin1());
+	    QString targ = project->first("QMAKE_ORIG_TARGET"), cpflags;
 	    if(project->first("TEMPLATE") == "app") {
-		lib += ".app";
-	    } else if(!project->isActiveConfig("staticlib") &&
-		      !project->isActiveConfig("frameworklib")) {
-		lib = project->first("TARGET_");
-		int slsh = lib.findRev(Option::dir_sep);
+		cpflags += "-r ";
+		targ += ".app";
+	    } else if(!project->isActiveConfig("frameworklib")) {
+		if(project->isActiveConfig("staticlib"))
+		    targ = project->first("TARGET");
+		else
+		    targ = project->first("TARGET_");
+		int slsh = targ.findRev(Option::dir_sep);
 		if(slsh != -1)
-		    lib = lib.right(lib.length() - slsh - 1);
+		    targ = targ.right(targ.length() - slsh - 1);
 	    }
 	    QTextStream sht(&shf);
 	    QString dstdir = project->first("DESTDIR");
 	    fixEnvVariables(dstdir);
+
 	    sht << "#!/bin/sh" << endl;
-	    sht << "cp -r \"$BUILD_ROOT/" << lib << "\" " << "\"" <<
-		dstdir << targ << "\"" << endl;
+	    //copy the actual target
+	    sht << "OUT_TARG=\"" << targ << "\"\n" 
+		<< "[ -z \"$BUILD_ROOT\" ] || OUT_TARG=\"${BUILD_ROOT}/${OUT_TARG}\"" << endl;
+	    sht << "[ \"$OUT_TARG\" = \"" 
+		<< (dstdir.isEmpty() ? QDir::currentDirPath() + QDir::separator(): dstdir) << targ << "\" ] || " 
+		<< "[ \"$OUT_TARG\" = \"" << targ << "\" ] || " 
+		<< "cp -r \"$OUT_TARG\" " << "\"" << dstdir << targ << "\"" << endl;
+	    //rename as a framework
 	    if(project->first("TEMPLATE") == "lib" && project->isActiveConfig("frameworklib"))
-		sht << "ln -s \"" << targ <<  "\" " << "\"" << dstdir << lib << "\"" << endl;
-	    for(QStringList::Iterator it = links.begin(); it != links.end(); ++it)
-		sht << "ln -s \"" << targ <<  "\" " <<
-		    "\"" << dstdir << (*it) << "\"" << endl;
+		sht << "ln -sf \"" << targ <<  "\" " << "\"" << dstdir << targ << "\"" << endl;
+	    //create all the version symlinks (just to be like unixmake)
+	    for(QStringList::Iterator it = links.begin(); it != links.end(); ++it) {
+		if(targ != (*it)) 
+		    sht << "ln -sf \"" << targ <<  "\" " << "\"" << dstdir << (*it) << "\"" << endl;
+	    }
 	    shf.close();
 #ifdef Q_OS_UNIX
 	    chmod(script.latin1(), S_IRWXU | S_IRWXG);
@@ -495,18 +539,23 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
       << "\t\t\t" << "refType = 3;" << "\n";
     if(project->first("TEMPLATE") == "app") {
 	t << "\t\t\t" << "isa = PBXApplicationReference;" << "\n"
-	<< "\t\t\t" << "path = " << project->first("QMAKE_ORIG_TARGET") << ".app;" << "\n";
+	  << "\t\t\t" << "name = " << project->first("QMAKE_ORIG_TARGET") << ".app;" << "\n"
+	  << "\t\t\t" << "path = \"" 
+	  << (!project->isEmpty("DESTDIR") ? project->first("DESTDIR") : QDir::currentDirPath()) 
+	  << ".app\";" << "\n";
     } else {
 	QString lib = project->first("QMAKE_ORIG_TARGET");
-	if(!project->isActiveConfig("staticlib") && !project->isActiveConfig("frameworklib")) {
+	if(project->isActiveConfig("staticlib")) {
+	    lib = project->first("TARGET");
+	} else if(!project->isActiveConfig("frameworklib")) {
 	    if(project->isActiveConfig("plugin"))
-	       lib = project->first("TARGET");
+		lib = project->first("TARGET");
 	    else
 		lib = project->first("TARGET_");
-	    int slsh = lib.findRev(Option::dir_sep);
-	    if(slsh != -1)
-		lib = lib.right(lib.length() - slsh - 1);
 	}
+	int slsh = lib.findRev(Option::dir_sep);
+	if(slsh != -1)
+	    lib = lib.right(lib.length() - slsh - 1);
 	t << "\t\t\t" << "isa = PBXLibraryReference;" << "\n"
 	  << "\t\t\t" << "path = " << lib << ";\n";
     }
@@ -529,13 +578,16 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
       << "\t\t\t\t" << "OTHER_CPLUSPLUSFLAGS = \"" <<
 	fixEnvsList("QMAKE_CXXFLAGS") << varGlue("PRL_EXPORT_DEFINES"," -D"," -D","") <<
 	varGlue("DEFINES"," -D"," -D","") << "\";" << "\n"
-      << "\t\t\t\t" << "OTHER_LDFLAGS = \"" << fixEnvsList("SUBLIBS") << " " <<
-	fixEnvsList("QMAKE_LFLAGS") << " " << fixEnvsList("QMAKE_LIBDIR_FLAGS") <<
-	" " << fixEnvsList("QMAKE_LIBS") << "\";" << "\n"
       << "\t\t\t\t" << "OTHER_REZFLAGS = \"\";" << "\n"
       << "\t\t\t\t" << "SECTORDER_FLAGS = \"\";" << "\n"
       << "\t\t\t\t" << "WARNING_CFLAGS = \"\";" << "\n";
-//    t << "\t\t\t\t" << "BUILD_ROOT = \"" << QDir::currentDirPath() << "\";" << "\n";
+#if 1
+    t << "\t\t\t\t" << "BUILD_ROOT = \"" << QDir::currentDirPath() << "\";" << "\n";
+#endif
+    if(!project->isActiveConfig("staticlib")) 
+	t << "\t\t\t\t" << "OTHER_LDFLAGS = \"" << fixEnvsList("SUBLIBS") << " " <<
+	    fixEnvsList("QMAKE_LFLAGS") << " " << fixEnvsList("QMAKE_LIBDIR_FLAGS") <<
+	    " " << fixEnvsList("QMAKE_LIBS") << "\";" << "\n";
     if(!project->isEmpty("DESTDIR"))
 	t << "\t\t\t\t" << "INSTALL_PATH = \"" << project->first("DESTDIR") << "\";" << "\n";
     if(!project->isEmpty("VERSION") && project->first("VERSION") != "0.0.0")
@@ -549,6 +601,7 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	QString lib = project->first("QMAKE_ORIG_TARGET");
 	if(!project->isActiveConfig("plugin") && project->isActiveConfig("staticlib")) {
 	    t << "\t\t\t\t" << "LIBRARY_STYLE = STATIC;" << "\n";
+	    lib = project->first("TARGET");
 	} else {
 	    t << "\t\t\t\t" << "LIBRARY_STYLE = DYNAMIC;" << "\n";
 	    if(!project->isActiveConfig("frameworklib")) {
@@ -556,16 +609,16 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 		    lib = project->first("TARGET");
 		else
 		    lib = project->first("TARGET_");
-		int slsh = lib.findRev(Option::dir_sep);
-		if(slsh != -1)
-		    lib = lib.right(lib.length() - slsh - 1);
 	    }
 	}
+	int slsh = lib.findRev(Option::dir_sep);
+	if(slsh != -1)
+	    lib = lib.right(lib.length() - slsh - 1);
 	t << "\t\t\t\t" << "PRODUCT_NAME = " << lib << ";" << "\n";
     }
     tmp = project->variables()["QMAKE_PBX_VARS"];
     for(QStringList::Iterator it = tmp.begin(); it != tmp.end(); ++it)
-	t << "\t\t\t\t" << (*it) << " = " << getenv((*it)) << ";" << "\n";
+	t << "\t\t\t\t" << (*it) << " = \"" << getenv((*it)) << "\";" << "\n";
     t << "\t\t\t" << "};" << "\n"
       << "\t\t\t" << "conditionalBuildSettings = {" << "\n"
       << "\t\t\t" << "};" << "\n"
@@ -577,6 +630,30 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
 	t << "\t\t\t" << "isa = PBXApplicationTarget;" << "\n"
 	  << "\t\t\t" << "name = \"" << project->first("QMAKE_ORIG_TARGET") << "\";" << "\n"
 	  << "\t\t\t" << "productName = " << project->first("QMAKE_ORIG_TARGET") << ";" << "\n";
+	t << "\t\t\t" << "productSettingsXML = " << "\"" << "<?xml version=" 
+	  << "\\\"1.0\\\" encoding=" << "\\\"UTF-8\\\"" << "?>" << "\n"
+	  << "\t\t\t\t" << "<!DOCTYPE plist SYSTEM \\\"file://localhost/System/" 
+	  << "Library/DTDs/PropertyList.dtd\\\">" << "\n"
+	  << "\t\t\t\t" << "<plist version=\\\"0.9\\\">" << "\n"
+	  << "\t\t\t\t" << "<dict>" << "\n"
+	  << "\t\t\t\t\t" << "<key>CFBundleDevelopmentRegion</key>" << "\n"
+	  << "\t\t\t\t\t" << "<string>English</string>" << "\n"
+	  << "\t\t\t\t\t" << "<key>CFBundleExecutable</key>" << "\n"
+	  << "\t\t\t\t\t" << "<string>" << project->first("QMAKE_ORIG_TARGET") << "</string>" << "\n"
+	  << "\t\t\t\t\t" << "<key>CFBundleIconFile</key>" << "\n"
+	  << "\t\t\t\t\t" << "<string></string>" << "\n"
+	  << "\t\t\t\t\t" << "<key>CFBundleInfoDictionaryVersion</key>"  << "\n"
+	  << "\t\t\t\t\t" << "<string>6.0</string>" << "\n"
+	  << "\t\t\t\t\t" << "<key>CFBundlePackageType</key>" << "\n"
+	  << "\t\t\t\t\t" << "<string>APPL</string>" << "\n"
+	  << "\t\t\t\t\t" << "<key>CFBundleSignature</key>" << "\n"
+	  << "\t\t\t\t\t" << "<string>????</string>" << "\n"
+	  << "\t\t\t\t\t" << "<key>CFBundleVersion</key>" << "\n"
+	  << "\t\t\t\t\t" << "<string>0.1</string>" << "\n"
+	  << "\t\t\t\t\t" << "<key>CSResourcesFileMapped</key>" << "\n"
+	  << "\t\t\t\t\t" << "<true/>" << "\n"
+	  << "\t\t\t\t" << "</dict>" << "\n"
+	  << "\t\t\t\t" << "</plist>" << "\";" << "\n";
     } else {
 	QString lib = project->first("QMAKE_ORIG_TARGET");
 	if(!project->isActiveConfig("frameworklib"))
@@ -623,18 +700,23 @@ ProjectBuilderMakefileGenerator::writeMakeParts(QTextStream &t)
       << "}" << endl;
 
     QString mkwrap = Option::output_dir + Option::dir_sep + ".." + Option::dir_sep + project->first("MAKEFILE");
+    Option::fixPathToLocalOS(mkwrap);
     QFile mkwrapf(mkwrap);
     if(mkwrapf.open(IO_WriteOnly | IO_Translate)) {
-	debug_msg(0, "Creating file: %s", mkwrap.latin1());
+	debug_msg(1, "Creating file: %s", mkwrap.latin1());
 	QTextStream mkwrapt(&mkwrapf);
 	writeHeader(mkwrapt);
+	const char *cleans = "uiclean mocclean preprocess_clean ";
 	mkwrapt << "#This is a makefile wrapper for PROJECT BUILDER\n"
 		<< "all:" << "\n\t" 
-		<< "cd " << project->first("QMAKE_ORIG_TARGET") + ".pbproj/ && pbxbuild" << "\n"
-		<< "distclean clean:" << "\n\t" 
-		<< "cd " << project->first("QMAKE_ORIG_TARGET") + ".pbproj/ && pbxbuild clean" << "\n"
-		<< "install:" 
-		<< endl;
+		<< "cd " << (project->first("QMAKE_ORIG_TARGET") + ".pbproj/ && pbxbuild") << "\n"
+		<< "distclean clean: preprocess_clean" << "\n\t" 
+		<< "cd " << (project->first("QMAKE_ORIG_TARGET") + ".pbproj/ && pbxbuild clean") << "\n"
+		<< (!did_preprocess ? cleans : "") << "install:" << "\n";
+	if(did_preprocess) 
+	    mkwrapt << cleans << ":" << "\n\t"
+		    << "make -f " 
+		    << Option::output_dir << Option::dir_sep << "qt_preprocess.mak $@" << endl;
     }
     return TRUE;
 }
@@ -706,3 +788,61 @@ ProjectBuilderMakefileGenerator::defaultMakefile() const
 	return UnixMakefileGenerator::defaultMakefile();
     return project->first("TARGET") + ".pbproj/project.pbxproj";
 }
+
+/* This function is such a hack it is almost pointless, but it
+   eliminates the warning message from ProjectBuilder that the project
+   file is for an older version. I guess this could be used someday if
+   the format of the output is dependant upon the version of
+   ProjectBuilder as well.
+*/
+int
+ProjectBuilderMakefileGenerator::pbuilderVersion() const
+{
+    QString ret;
+    if(project->isEmpty("QMAKE_PBUILDER_VERSION")) {
+	QString version, version_plist = project->first("QMAKE_PBUILDER_VERSION_PLIST");
+	if(version_plist.isEmpty())
+	    version_plist = "/Developer/Applications/Project Builder.app/Contents/version.plist";
+	else
+	    version_plist = version_plist.replace(QRegExp("\""), "");
+	QFile version_file(version_plist);
+	if(version_file.open(IO_ReadOnly)) {
+	    debug_msg(1, "version.plist: Reading file: %s", version_plist.latin1());
+	    QTextStream plist(&version_file);
+
+	    bool in_dict = FALSE;
+	    QString current_key;
+	    QRegExp keyreg("^<key>(.*)</key>$"), stringreg("^<string>(.*)</string>$");
+	    while(!plist.eof()) {
+		QString line = plist.readLine().stripWhiteSpace();
+		if(line == "<dict>")
+		    in_dict = TRUE;
+		else if(line == "</dict>")
+		    in_dict = FALSE;
+		else if(in_dict) {
+		    if(keyreg.exactMatch(line))
+			current_key = keyreg.cap(1);
+		    else if(current_key == "CFBundleShortVersionString" && stringreg.exactMatch(line))
+			version = stringreg.cap(1);
+		}
+	    }
+	    version_file.close();
+	} else debug_msg(1, "version.plist: Failure to open %s", version_plist.latin1());
+	if(version == "2.0")
+	    ret = "38";
+	else if(version == "1.1")
+	    ret = "34";
+    } else {
+	ret = project->first("QMAKE_PBUILDER_VERSION");
+    }
+    if(!ret.isEmpty()) {
+	bool ok;
+	int int_ret = ret.toInt(&ok);
+	if(ok) {
+	    debug_msg(1, "version.plist: Got version: %d", int_ret);
+	    return int_ret;
+	}
+    }
+    debug_msg(1, "version.plist: Fallback to default version");
+    return 34; //my fallback
+}
