@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/msvc_dsp.cpp   3.0.3   edited Mar 11 01:43 $
+** $Id:  qt/msvc_dsp.cpp   3.0.5   edited May 30 14:27 $
 **
 ** Definition of ________ class.
 **
@@ -102,8 +102,12 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 		if(project->variables()["SOURCES"].isEmpty())
 		    continue;
 
+		QString mocpath = var( "QMAKE_MOC" );
+		mocpath = mocpath.replace( QRegExp( "\\..*$" ), "" ) + " ";
+		
 		QStringList &list = project->variables()["SOURCES"];
-		for(QStringList::Iterator it = list.begin(); it != list.end(); ++it) {
+		QStringList::Iterator it;
+		for( it = list.begin(); it != list.end(); ++it) {
 		    t << "# Begin Source File\n\nSOURCE=" << (*it) << endl;
 		    if ( project->isActiveConfig("moc") &&
 			 (*it).right(qstrlen(Option::moc_ext)) == Option::moc_ext) {
@@ -111,9 +115,6 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 			base.replace(QRegExp("\\..*$"), "").upper();
 			base.replace(QRegExp("[^a-zA-Z]"), "_");
 
-			QString mocpath = var( "QMAKE_MOC" );
-			mocpath = mocpath.replace( QRegExp( "\\..*$" ), "" ) + " ";
-
 			QString build = "\n\n# Begin Custom Build - Moc'ing " + findMocSource((*it)) +
 					"...\n" "InputPath=.\\" + (*it) + "\n\n" "\"" + (*it) + "\""
 					" : $(SOURCE) \"$(INTDIR)\" \"$(OUTDIR)\"\n"
@@ -128,6 +129,11 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 		    }
 		    t << "# End Source File" << endl;
 		}
+		list = project->variables()["DEF_FILE"];
+		for( it = list.begin(); it != list.end(); ++it ) {
+		    t << "# Begin Source File\n\nSOURCE=" << (*it) << endl;
+		    t << "# End Source File" << endl;
+		}
 	    }
 	    else if(variable == "MSVCDSP_IMAGES") {
 		if(project->variables()["IMAGES"].isEmpty())
@@ -169,14 +175,45 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 	    else if(variable == "MSVCDSP_FORMSOURCES" || variable == "MSVCDSP_FORMHEADERS") {
 		if(project->variables()["FORMS"].isEmpty())
 		    continue;
+		
+		QString uiSourcesDir;
+		QString uiHeadersDir;
+		if(!project->variables()["UI_DIR"].isEmpty()) {
+		    uiSourcesDir = project->first("UI_DIR");
+		    uiHeadersDir = project->first("UI_DIR");
+		} else {
+		    if ( !project->variables()["UI_SOURCES_DIR"].isEmpty() )
+			uiSourcesDir = project->first("UI_SOURCES_DIR");
+		    else
+			uiSourcesDir = "";
+		    if ( !project->variables()["UI_HEADERS_DIR"].isEmpty() )
+			uiHeadersDir = project->first("UI_HEADERS_DIR");
+		    else
+			uiHeadersDir = "";
+		}
 
 		QStringList &list = project->variables()["FORMS"];
 		QString ext = variable == "MSVCDSP_FORMSOURCES" ? ".cpp" : ".h";
 		for(QStringList::Iterator it = list.begin(); it != list.end(); ++it) {
 		    QString base = (*it);
 		    int dot = base.findRev(".");
-		    base.replace( dot, base.length() - dot, ext );
-		    t << "# Begin Source File\n\nSOURCE=" << base << "\n# End Source File" << endl;
+  		    base.replace( dot, base.length() - dot, ext );
+		    QString fname = base;
+
+		    int lbs = fname.findRev( "\\" );
+		    QString fpath; 
+		    if ( lbs != -1 )
+			fpath = fname.left( lbs + 1 );
+		    fname = fname.right( fname.length() - lbs - 1 );
+
+		    t << "# Begin Source File\n\nSOURCE=";
+		    if ( ext == ".cpp" && !uiSourcesDir.isEmpty() )
+			t << uiSourcesDir << fname;
+		    else if ( ext == ".h" && !uiHeadersDir.isEmpty() )
+			t << uiHeadersDir << fname;
+		    else
+			t << base;
+		    t << "\n# End Source File" << endl;
 		}
 	    }
 	    else if(variable == "MSVCDSP_TRANSLATIONS" ) {
@@ -258,6 +295,9 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 		if ( project->variables()["SRCMOC"].isEmpty())
 		    continue;
 
+		QString mocpath = var( "QMAKE_MOC" );
+		mocpath = mocpath.replace( QRegExp( "\\..*$" ), "" ) + " ";
+
 		QStringList &list = project->variables()["SRCMOC"];
 		for(QStringList::Iterator it = list.begin(); it != list.end(); ++it) {
 		    t << "# Begin Source File\n\nSOURCE=" << (*it) << endl;
@@ -267,9 +307,6 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 			base.replace(QRegExp("\\..*$"), "").upper();
 			base.replace(QRegExp("[^a-zA-Z]"), "_");
 
-			QString mocpath = var( "QMAKE_MOC" );
-			mocpath = mocpath.replace( QRegExp( "\\..*$" ), "" ) + " ";
-
 			QString build = "\n\n# Begin Custom Build - Moc'ing " + findMocSource((*it)) +
 					"...\n" "InputPath=.\\" + (*it) + "\n\n" "\"" + (*it) + "\""
 					" : $(SOURCE) \"$(INTDIR)\" \"$(OUTDIR)\"\n"
@@ -309,6 +346,7 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 		t << "# Prop Default_Filter \"ui\"\n";
 
 		bool imagesBuildDone = FALSE;	    // Dirty hack to make it not create an output step for images more than once
+	
 		QString uicpath = var("QMAKE_UIC");
 		uicpath = uicpath.replace(QRegExp("\\..*$"), "") + " ";
 		QString mocpath = var( "QMAKE_MOC" );
@@ -326,42 +364,55 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 		    if ( lbs != -1 )
 			fpath = fname.left( lbs + 1 );
 		    fname = fname.right( fname.length() - lbs - 1 );
-		
+
 		    QString mocFile;
 		    if(!project->variables()["MOC_DIR"].isEmpty())
 			mocFile = project->first("MOC_DIR");
 		    else
 			mocFile = fpath;
 
-		    QString imagesBuild;
-		    if ( !project->variables()["IMAGES"].isEmpty() && !imagesBuildDone ) {
-			QStringList &list = project->variables()["IMAGES"];
-			for(QStringList::Iterator it = list.begin(); it != list.end(); ++it) {
-			    imagesBuild.append(" " + *it );
-			}
+		    QString uiSourcesDir;
+		    QString uiHeadersDir;
+		    if(!project->variables()["UI_DIR"].isEmpty()) {
+			uiSourcesDir = project->first("UI_DIR");
+			uiHeadersDir = project->first("UI_DIR");
+		    } else {
+			if ( !project->variables()["UI_SOURCES_DIR"].isEmpty() )
+			    uiSourcesDir = project->first("UI_SOURCES_DIR");
+			else
+			    uiSourcesDir = fpath;
+			if ( !project->variables()["UI_HEADERS_DIR"].isEmpty() )
+			    uiHeadersDir = project->first("UI_HEADERS_DIR");
+			else
+			    uiHeadersDir = fpath;
 		    }
 
 		    t << "USERDEP_" << base << "=\"$(QTDIR)\\bin\\moc.exe\" \"$(QTDIR)\\bin\\uic.exe\"" << endl << endl;
 
 		    QString build = "\n\n# Begin Custom Build - Uic'ing " + base + "...\n"
 			"InputPath=.\\" + base + "\n\n" "BuildCmds= \\\n\t" + uicpath + base +
-			" -o " + fpath + fname + ".h \\\n" "\t" + uicpath  + base +
-			" -i " + fname + ".h -o " + fpath + fname + ".cpp \\\n"
-			"\t" + mocpath + fpath + fname + ".h -o " + mocFile + "moc_" + fname + ".cpp \\\n";
+			" -o " + uiHeadersDir + fname + ".h \\\n" "\t" + uicpath  + base +
+			" -i " + fname + ".h -o " + uiSourcesDir + fname + ".cpp \\\n"
+			"\t" + mocpath + uiHeadersDir + fname + ".h -o " + mocFile + "moc_" + fname + ".cpp \\\n";
 		    
-		    if ( !project->variables()["IMAGES"].isEmpty() && !imagesBuildDone ) {
+		    if ( !imagesBuildDone && !project->variables()["IMAGES"].isEmpty() ) {
+			QString imagesBuild;
+			QStringList &list = project->variables()["IMAGES"];
+			for(QStringList::Iterator it = list.begin(); it != list.end(); ++it) {
+			    imagesBuild.append(" " + *it );
+			}
 			build.append("\t" + uicpath + "-embed " + project->first("QMAKE_ORIG_TARGET") + imagesBuild + " -o "
 			    + project->first("QMAKE_IMAGE_COLLECTION") + " \\\n"); 
 		    } 
 		    
-		    build.append("\n\"" + fpath + fname + ".h\" : \"$(SOURCE)\" \"$(INTDIR)\" \"$(OUTDIR)\""  "\n"
+		    build.append("\n\"" + uiHeadersDir + fname + ".h\" : \"$(SOURCE)\" \"$(INTDIR)\" \"$(OUTDIR)\""  "\n"
 			"\t$(BuildCmds)\n\n"
-			"\"" + fpath + fname + ".cpp\" : \"$(SOURCE)\" \"$(INTDIR)\" \"$(OUTDIR)\"" "\n"
+			"\"" + uiSourcesDir + fname + ".cpp\" : \"$(SOURCE)\" \"$(INTDIR)\" \"$(OUTDIR)\"" "\n"
 			"\t$(BuildCmds)\n\n"
 			"\"" + mocFile + "moc_" + fname + ".cpp\" : \"$(SOURCE)\" \"$(INTDIR)\" \"$(OUTDIR)\"" "\n"
 			"\t$(BuildCmds)\n\n");
 		    
-		    if ( !project->variables()["IMAGES"].isEmpty() && !imagesBuildDone ) {
+		    if ( !imagesBuildDone && !project->variables()["IMAGES"].isEmpty() ) {
 			build.append("\"" + project->first("QMAKE_IMAGE_COLLECTION") + "\"" + " : \"$(SOURCE)\" \"$(INTDIR)\" \"$(OUTDIR)\"" 
 			    "\n" "\t$(BuildCmds)\n\n");
 		    }
@@ -443,56 +494,19 @@ DspMakefileGenerator::writeDspParts(QTextStream &t)
 		}
 
 		t << "\n# End Group\n";
-	    } else  if ( variable == "MSVCDSP_IDLOUTPUT" ) {
-		QStringList &l = project->variables()["IDLOUTPUT"];
-		if ( l.isEmpty() )
-		    continue;
-		QString axlist = "ACTIVEQT";
-		QString axFile = varGlue( "ACTIVEQT", "", " ", "" );
-		if ( axFile.isEmpty() ) {
-		    axFile = varGlue( "_ACTIVEQT", "", " ", "" );
-		    axlist = "_ACTIVEQT";
-		}
-		bool fromIDL = FALSE;
-		QString inputFile;
-		if ( project->variables()[axlist].count() == 1 ) {
-		    inputFile = project->variables()[axlist].first();
-		    fromIDL = inputFile.right( 4 ).lower() == ".idl";
-		}
-
-		for ( QStringList::Iterator it = l.begin(); it != l.end(); ++it ) {
-		    QString sourcefile = *it;
-		    t << "# Begin Source File\n\nSOURCE=" << sourcefile << endl;
-		    if ( sourcefile.right( 4 ).lower() == ".tlb" ) {
-			QString idcoutput = sourcefile.left( sourcefile.length()-4) + ".idl";
-			if ( fromIDL )
-			    idcoutput = inputFile;
-			QString rcoutput = sourcefile.left( sourcefile.length()-4) + ".rc";
-			t << "USERDEP_" << sourcefile << "=" << varGlue( axlist, "\"", "\"\t\"", "\"" ) << endl << endl;
-
-			QString build = "\n\n# Begin Custom Build - Generating IDL from " + axFile + "...\n"
-					"# InputPath=" + sourcefile + "\n\n"
-					"\"" + sourcefile + "\" : $(SOURCE) \"$(INTDIR)\" \"$(OUTDIR)\"\n";
-					if ( !fromIDL )
-					    build += "\t$(QTDIR)\\bin\\idc " + axFile + " -o " + idcoutput + " -rc " + rcoutput + "\n";
-					build += "\tmidl " + idcoutput + " /tlb " + sourcefile + " /iid tmp\\iid_i.c"
-					" /dlldata tmp\\dlldata.c /cstub tmp\\cstub.c /header tmp\\cstub.h /proxy tmp\\proxy.c /sstub tmp\\sstub.c\n\n"
-					"# End Custom Build\n\n";
-
-			t << "!IF  \"$(CFG)\" == \"" << var("MSVCDSP_PROJECT") << " - Win32 Release\"" << build
-			  << "!ELSEIF  \"$(CFG)\" == \"" << var("MSVCDSP_PROJECT") << " - Win32 Debug\"" << build
-			  << "!ENDIF \n\n";
-		    } else if ( sourcefile.right( 4 ).lower() == ".idl" ) {
-			t << "# PROP Exclude_From_Build 1" << endl;
-		    }
-		    t << "# End Source File" << endl;
-		}
-	    }
-	    else if( variable == "MSVCDSP_CONFIGMODE" ) {
+	    } else if( variable == "MSVCDSP_CONFIGMODE" ) {
 		if( project->isActiveConfig( "release" ) )
 		    t << "Release";
 		else
 		    t << "Debug";
+	    } else if( variable == "MSVCDSP_IDLSOURCES" ) {
+		QStringList &l = project->variables()["MSVCDSP_IDLSOURCES"];
+		for(QStringList::Iterator it = l.begin(); it != l.end(); ++it) {
+		    t << "# Begin Source File" << endl << endl;
+		    t << "SOURCE=" << (*it) << endl;
+		    t << "# PROP Exclude_From_Build 1" << endl;
+		    t << "# End Source File" << endl << endl;
+		}
 	    }
 	    else
 		t << var(variable);
@@ -587,8 +601,14 @@ DspMakefileGenerator::init()
 			(*libit).replace(QRegExp("qt(-mt)?\\.lib"), ver);
 		}
 	    }
-	    if ( !project->isActiveConfig("dll") && !project->isActiveConfig("plugin") && !project->isActiveConfig("activeqt") ) {
-		project->variables()["QMAKE_LIBS"] +=project->variables()["QMAKE_LIBS_QT_DLL"];
+	    if ( project->isActiveConfig( "activeqt" ) ) {
+		project->variables().remove("QMAKE_LIBS_QT_ENTRY");
+		project->variables()["QMAKE_LIBS_QT_ENTRY"] = "$(QTDIR)\\lib\\qaxserver.lib";
+		if ( project->isActiveConfig( "dll" ) )
+		    project->variables()["QMAKE_LIBS"] += project->variables()["QMAKE_LIBS_QT_ENTRY"];
+	    }
+	    if ( !project->isActiveConfig("dll") && !project->isActiveConfig("plugin") ) {
+		project->variables()["QMAKE_LIBS"] +=project->variables()["QMAKE_LIBS_QT_ENTRY"];
 	    }
 	}
     }
@@ -723,20 +743,19 @@ DspMakefileGenerator::init()
         }
     }
 
-    if ( project->isActiveConfig("activeqt") ) {
-	project->variables()["QMAKE_LIBS"].append( "$(QTDIR)\\lib\\activeqt.lib" );
-	project->variables()["IDLOUTPUT"].append( "tmp\\" + targetfilename + ".rc" );
-	project->variables()["IDLOUTPUT"].append( "tmp\\" + targetfilename + ".tlb" );
-    }
-
     project->variables()["MSVCDSP_LIBS"] += project->variables()["QMAKE_LIBS"];
     project->variables()["MSVCDSP_LIBS"] += project->variables()["QMAKE_LIBS_WINDOWS"];
     project->variables()["MSVCDSP_LFLAGS" ] += project->variables()["QMAKE_LFLAGS"];
     project->variables()["MSVCDSP_CXXFLAGS" ] += project->variables()["QMAKE_CXXFLAGS"];
     project->variables()["MSVCDSP_DEFINES"].append(varGlue("DEFINES","/D ","" " /D ",""));
     project->variables()["MSVCDSP_DEFINES"].append(varGlue("PRL_EXPORT_DEFINES","/D ","" " /D ",""));
-    project->variables()["MSVCDSP_INCPATH"].append(varGlue("INCLUDEPATH","/I \"","\" /I \"","\"") +
-							    " /I \"" + specdir() + "\"");
+    QStringList &incs = project->variables()["INCLUDEPATH"];
+    for(QStringList::Iterator incit = incs.begin(); incit != incs.end(); ++incit) {
+	QString inc = (*incit);
+	inc.replace(QRegExp("\""), "");
+	project->variables()["MSVCDSP_INCPATH"].append("/I \"" + inc + "\"");
+    }
+    project->variables()["MSVCDSP_INCPATH"].append("/I \"" + specdir() + "\"");
     if ( project->isActiveConfig("qt") ) {
 	project->variables()["MSVCDSP_RELDEFS"].append("/D \"QT_NO_DEBUG\"");
     } else {
@@ -771,19 +790,55 @@ DspMakefileGenerator::init()
 	}
 
 	copydll += "\n# End Special Build Tool";
-	project->variables()["MSVCDSP_COPY_DLL"].append( copydll );
+	project->variables()["MSVCDSP_COPY_DLL_REL"].append( copydll );
+	project->variables()["MSVCDSP_COPY_DLL_DBG"].append( copydll );
     }
     if ( project->isActiveConfig("activeqt") ) {
-	QString regcmd = "# Begin Special Build Tool\n"
-			"TargetPath=" + targetfilename + "\n"
-			"SOURCE=$(InputPath)\n"
-			"PostBuild_Desc=Registering ActiveX control in " + targetfilename + "\n"
-			"PostBuild_Cmds=%1 -RegServer\n"
-			"# End Special Build Tool";
-	QString executable = project->variables()["MSVCDSP_TARGETDIRREL"].first() + "\\" + project->variables()["TARGET"].first();
-	project->variables()["MSVCDSP_REGSVR_REL"].append(regcmd.arg(executable) );
-	executable = project->variables()["MSVCDSP_TARGETDIRDEB"].first() + "\\" + project->variables()["TARGET"].first();
-	project->variables()["MSVCDSP_REGSVR_DBG"].append(regcmd.arg(executable) );
+	QString idl = project->variables()["QMAKE_IDL"].first();
+	QString idc = project->variables()["QMAKE_IDC"].first();
+	QString version = project->variables()["VERSION"].first();
+	if ( version.isEmpty() )
+	    version = "1.0";
+
+	project->variables()["MSVCDSP_IDLSOURCES"].append( "tmp\\" + targetfilename + ".idl" );
+	project->variables()["MSVCDSP_IDLSOURCES"].append( "tmp\\" + targetfilename + ".tlb" );
+	project->variables()["MSVCDSP_IDLSOURCES"].append( "tmp\\" + targetfilename + ".midl" );
+	if ( project->isActiveConfig( "dll" ) ) {
+	    QString regcmd = "# Begin Special Build Tool\n"
+			    "TargetPath=" + targetfilename + "\n"
+			    "SOURCE=$(InputPath)\n"
+			    "PostBuild_Desc=Finalizing ActiveQt server...\n"
+			    "PostBuild_Cmds=" +
+			    idc + " %1 -idl tmp\\" + targetfilename + ".idl -version " + version +
+			    "\t" + idl + " tmp\\" + targetfilename + ".idl /nologo /o tmp\\" + targetfilename + ".midl /tlb tmp\\" + targetfilename + ".tlb /iid tmp\\dump.midl /dlldata tmp\\dump.midl /cstub tmp\\dump.midl /header tmp\\dump.midl /proxy tmp\\dump.midl /sstub tmp\\dump.midl"
+			    "\t" + idc + " %1 /tlb tmp\\" + targetfilename + ".tlb"
+			    "\tregsvr32 /s %1\n"
+			    "# End Special Build Tool";
+
+	    QString executable = project->variables()["MSVCDSP_TARGETDIRREL"].first() + "\\" + project->variables()["TARGET"].first();
+	    project->variables()["MSVCDSP_COPY_DLL_REL"].append( regcmd.arg(executable).arg(executable).arg(executable) );
+	    
+	    executable = project->variables()["MSVCDSP_TARGETDIRDEB"].first() + "\\" + project->variables()["TARGET"].first();
+	    project->variables()["MSVCDSP_COPY_DLL_DBG"].append( regcmd.arg(executable).arg(executable).arg(executable) );
+	} else {
+	    QString regcmd = "# Begin Special Build Tool\n"
+			    "TargetPath=" + targetfilename + "\n"
+			    "SOURCE=$(InputPath)\n"
+			    "PostBuild_Desc=Finalizing ActiveQt server...\n"
+			    "PostBuild_Cmds="
+			    "%1 -dumpidl tmp\\" + targetfilename + ".idl -version " + version +
+			    "\t" + idl + " tmp\\" + targetfilename + ".idl /nologo /o tmp\\" + targetfilename + ".midl /tlb tmp\\" + targetfilename + ".tlb /iid tmp\\dump.midl /dlldata tmp\\dump.midl /cstub tmp\\dump.midl /header tmp\\dump.midl /proxy tmp\\dump.midl /sstub tmp\\dump.midl"
+			    "\t" + idc + " %1 /tlb tmp\\" + targetfilename + ".tlb"
+			    "\t%1 -regserver\n"
+			    "# End Special Build Tool";
+
+	    QString executable = project->variables()["MSVCDSP_TARGETDIRREL"].first() + "\\" + project->variables()["TARGET"].first();
+	    project->variables()["MSVCDSP_REGSVR_REL"].append( regcmd.arg(executable).arg(executable).arg(executable) );
+	    
+	    executable = project->variables()["MSVCDSP_TARGETDIRDEB"].first() + "\\" + project->variables()["TARGET"].first();
+	    project->variables()["MSVCDSP_REGSVR_DBG"].append( regcmd.arg(executable).arg(executable).arg(executable) );
+	}
+	
     }
     if ( !project->variables()["SOURCES"].isEmpty() || !project->variables()["RC_FILE"].isEmpty() ) {
 	project->variables()["SOURCES"] += project->variables()["RC_FILE"];
