@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/msvc_nmake.cpp   3.0.2   edited Feb 13 02:26 $
+** $Id:  qt/msvc_nmake.cpp   3.0.5   edited Jun 11 16:00 $
 **
 ** Definition of ________ class.
 **
@@ -77,24 +77,25 @@ void
 NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
 {
     t << "####### Compiler, tools and options" << endl << endl;
-    t << "CC	=	" << var("QMAKE_CC") << endl;
-    t << "CXX	=	" << var("QMAKE_CXX") << endl;
-    t << "LEX     = " << var("QMAKE_LEX") << endl;
-    t << "YACC    = " << var("QMAKE_YACC") << endl;
+    t << "CC		=	" << var("QMAKE_CC") << endl;
+    t << "CXX		=	" << var("QMAKE_CXX") << endl;
+    t << "LEX		= " << var("QMAKE_LEX") << endl;
+    t << "YACC		= " << var("QMAKE_YACC") << endl;
     t << "CFLAGS	=	" << var("QMAKE_CFLAGS") << " " 
       << varGlue("PRL_EXPORT_DEFINES","-D"," -D","") << " "
       <<  varGlue("DEFINES","-D"," -D","") << endl;
-    t << "CXXFLAGS=	" << var("QMAKE_CXXFLAGS") << " " 
+    t << "CXXFLAGS	=	" << var("QMAKE_CXXFLAGS") << " " 
       << varGlue("PRL_EXPORT_DEFINES","-D"," -D","") << " "
       << varGlue("DEFINES","-D"," -D","") << endl;
-    t << "LEXFLAGS=" << var("QMAKE_LEXFLAGS") << endl;
-    t << "YACCFLAGS=" << var("QMAKE_YACCFLAGS") << endl;
+    t << "LEXFLAGS	=" << var("QMAKE_LEXFLAGS") << endl;
+    t << "YACCFLAGS	=" << var("QMAKE_YACCFLAGS") << endl;
 
     t << "INCPATH	=	";
     QStringList &incs = project->variables()["INCLUDEPATH"];
     for(QStringList::Iterator incit = incs.begin(); incit != incs.end(); ++incit) {
 	QString inc = (*incit);
 	inc.replace(QRegExp("\\\\$"), "\\\\");
+	inc.replace(QRegExp("\""), "");
 	t << " -I\"" << inc << "\"";
     }
     t << " -I\"" << specdir() << "\""
@@ -107,20 +108,22 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
     else {
 	t << "LIB	=	" << var("QMAKE_LIB") << endl;
     }
-    t << "MOC	=	" << (project->isEmpty("QMAKE_MOC") ? QString("moc") : 
+    t << "MOC		=	" << (project->isEmpty("QMAKE_MOC") ? QString("moc") : 
 			      Option::fixPathToTargetOS(var("QMAKE_MOC"), FALSE)) << endl;
-    t << "UIC	=	" << (project->isEmpty("QMAKE_UIC") ? QString("uic") : 
+    t << "UIC		=	" << (project->isEmpty("QMAKE_UIC") ? QString("uic") : 
 			      Option::fixPathToTargetOS(var("QMAKE_UIC"), FALSE)) << endl;
-    t << "QMAKE =       " << (project->isEmpty("QMAKE_QMAKE") ? QString("qmake") : 
+    t << "QMAKE		=	" << (project->isEmpty("QMAKE_QMAKE") ? QString("qmake") : 
 			      Option::fixPathToTargetOS(var("QMAKE_QMAKE"), FALSE)) << endl;
-    t << "IDC	=	" << (project->isEmpty("QMAKE_IDC") ? QString("idc") :
+    t << "IDC		=	" << (project->isEmpty("QMAKE_IDC") ? QString("idc") :
 			      Option::fixPathToTargetOS(var("QMAKE_IDC"), FALSE)) << endl;
-    t << "ZIP	=	" << var("QMAKE_ZIP") << endl;
-    t << "COPY_FILE  =       " << var("QMAKE_COPY") << endl;
-    t << "COPY_DIR   =       " << var("QMAKE_COPY") << endl;
-    t << "DEL_FILE   =       " << var("QMAKE_DEL_FILE") << endl;
-    t << "DEL_DIR    =       " << var("QMAKE_DEL_DIR") << endl;
-    t << "MOVE  =       " << var("QMAKE_MOVE") << endl;
+    t << "IDL		=	" << (project->isEmpty("QMAKE_IDL") ? QString("midl") :
+			      Option::fixPathToTargetOS(var("QMAKE_IDL"), FALSE)) << endl;
+    t << "ZIP		=	" << var("QMAKE_ZIP") << endl;
+    t << "COPY_FILE	=       " << var("QMAKE_COPY") << endl;
+    t << "COPY_DIR	=       " << var("QMAKE_COPY") << endl;
+    t << "DEL_FILE	=       " << var("QMAKE_DEL_FILE") << endl;
+    t << "DEL_DIR	=       " << var("QMAKE_DEL_DIR") << endl;
+    t << "MOVE		=       " << var("QMAKE_MOVE") << endl;
     t << endl;
 
     t << "####### Files" << endl << endl;
@@ -132,7 +135,6 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
     t << "UICIMPLS =	" << varList("UICIMPLS") << endl;
     t << "SRCMOC	=	" << varList("SRCMOC") << endl;
     t << "OBJMOC	=	" << varList("OBJMOC") << endl;
-    t << "SRCIDC	=	" << varList("SRCIDC") << endl;
     t << "DIST	=	" << varList("DISTFILES") << endl;
     t << "TARGET	=	";
     if( !project->variables()[ "DESTDIR" ].isEmpty() )
@@ -151,10 +153,10 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
 
     t << "####### Build rules" << endl << endl;
     t << "all: " << varGlue("ALL_DEPS",""," "," ") << "$(TARGET)" << endl << endl;
-    t << "$(TARGET): $(UICDECLS) $(OBJECTS) $(OBJMOC) $(SRCIDC)" << var("TARGETDEPS");
+    t << "$(TARGET): $(UICDECLS) $(OBJECTS) $(OBJMOC) " << var("TARGETDEPS");
     if(!project->variables()["QMAKE_APP_OR_DLL"].isEmpty()) {
 	t << "\n\t" << "$(LINK) $(LFLAGS) /OUT:$(TARGET) @<< " << "\n\t  "
-	  << "$(OBJECTS) $(OBJMOC) $(LIBS) $(SRCIDC)";
+	  << "$(OBJECTS) $(OBJMOC) $(LIBS)";
     } else {
 	t << "\n\t" << "$(LIB) /OUT:$(TARGET) @<<" << "\n\t  "
 	  << "$(OBJECTS) $(OBJMOC)";
@@ -166,6 +168,24 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
 	    t << "\n\t" << "-copy $(TARGET) " << *dlldir;
 	}
     }
+    QString targetfilename = project->variables()["TARGET"].first();
+    if(project->isActiveConfig("activeqt")) {
+	QString version = project->variables()["VERSION"].first();
+	if ( version.isEmpty() )
+	    version = "1.0";
+
+	if ( project->isActiveConfig("dll")) {
+	    t << "\n\t" << ("-$(IDC) $(TARGET) /idl tmp\\" + targetfilename + ".idl -version " + version);
+	    t << "\n\t" << ("-$(IDL) tmp\\" + targetfilename + ".idl /nologo /o tmp\\" + targetfilename + ".midl /tlb tmp\\" + targetfilename + ".tlb /iid tmp\\dump.midl /dlldata tmp\\dump.midl /cstub tmp\\dump.midl /header tmp\\dump.midl /proxy tmp\\dump.midl /sstub tmp\\dump.midl");
+	    t << "\n\t" << ("-$(IDC) $(TARGET) /tlb tmp\\" + targetfilename + ".tlb");
+	    t << "\n\t" << ("regsvr32 /s " + targetfilename);
+	} else {
+	    t << "\n\t" << ("-$(TARGET) -dumpidl tmp\\" + targetfilename + ".idl -version " + version);
+	    t << "\n\t" << ("-$(IDL) tmp\\" + targetfilename + ".idl /nologo /o tmp\\" + targetfilename + ".midl /tlb tmp\\" + targetfilename + ".tlb /iid tmp\\dump.midl /dlldata tmp\\dump.midl /cstub tmp\\dump.midl /header tmp\\dump.midl /proxy tmp\\dump.midl /sstub tmp\\dump.midl");
+	    t << "\n\t" << ("-$(IDC) $(TARGET) /tlb tmp\\" + targetfilename + ".tlb");
+	    t << "\n\t" << "-$(TARGET) -regserver";
+	}
+    }
     t << endl << endl;
 
     if(!project->variables()["RC_FILE"].isEmpty()) {
@@ -188,12 +208,32 @@ NmakeMakefileGenerator::writeNmakeParts(QTextStream &t)
       << varGlue("UICDECLS" ,"\n\t-del ","\n\t-del ","")
       << varGlue("UICIMPLS" ,"\n\t-del ","\n\t-del ","")
       << varGlue("QMAKE_CLEAN","\n\t-del ","\n\t-del ","")
-      << varGlue("CLEAN_FILES","\n\t-del ","\n\t-del ","")
-      << varGlue("SRCIDC","\n\t-del ","\n\t-del ","")
-      << varGlue("IDCOUT","\n\t-del ","\n\t-del ","")
-      << varGlue("IDCTMP","\n\t-del ","\n\t-del ","");
+      << varGlue("CLEAN_FILES","\n\t-del ","\n\t-del ","");
+    if ( project->isActiveConfig("activeqt")) {
+	t << ("\n\t-del tmp\\" + targetfilename + ".*");
+	t << "\n\t-del tmp\\dump.*";
+    }
     if(!project->isEmpty("IMAGES"))
 	t << varGlue("QMAKE_IMAGE_COLLECTION", "\n\t-del ", "\n\t-del ", "");
+
+    // blasted user defined targets
+    QStringList &qut = project->variables()["QMAKE_EXTRA_WIN_TARGETS"];
+    for(QStringList::Iterator it = qut.begin(); it != qut.end(); ++it) {
+	QString targ = var((*it) + ".target"),
+		 cmd = var((*it) + ".commands"), deps;
+	if(targ.isEmpty())
+	    targ = (*it);
+	QStringList &depends = project->variables()[(*it) + ".depends"];
+	for(QStringList::Iterator dep_it = depends.begin(); dep_it != depends.end(); ++dep_it) {
+	    QString dep = var((*dep_it) + ".target");
+	    if(dep.isEmpty())
+		dep = (*dep_it);
+	    deps += " " + dep;
+	}
+	t << "\n\n" << targ << ":" << deps << "\n\t"
+	  << cmd;
+    }
+
     t << endl << endl;
 }
 
@@ -210,6 +250,14 @@ NmakeMakefileGenerator::init()
 	project->variables()["QMAKE_APP_FLAG"].append("1");
     else if(project->first("TEMPLATE") == "lib")
 	project->variables()["QMAKE_LIB_FLAG"].append("1");
+    else if(project->first("TEMPLATE") == "subdirs") {
+	MakefileGenerator::init();
+	if(project->variables()["MAKEFILE"].isEmpty())
+	    project->variables()["MAKEFILE"].append("Makefile");
+	if(project->variables()["QMAKE"].isEmpty())
+	    project->variables()["QMAKE"].append("qmake");
+	return;
+    }
 
     bool is_qt = (project->first("TARGET") == "qt"QTDLL_POSTFIX || project->first("TARGET") == "qt-mt"QTDLL_POSTFIX);
     project->variables()["QMAKE_ORIG_TARGET"] = project->variables()["TARGET"];
@@ -298,10 +346,8 @@ NmakeMakefileGenerator::init()
     if ( project->isActiveConfig("qt") ) {
 	project->variables()["CONFIG"].append("moc");
 	project->variables()["INCLUDEPATH"] +=	project->variables()["QMAKE_INCDIR_QT"];
-	if ( !project->isActiveConfig("debug") ) {
+	if ( !project->isActiveConfig("debug") ) 
 	    project->variables()[is_qt ? "PRL_EXPORT_DEFINES" : "DEFINES"].append("QT_NO_DEBUG");
-	    project->variables()[is_qt ? "PRL_EXPORT_DEFINES" : "DEFINES"].append("QT_NO_CHECK");
-	}
 	if ( is_qt && !project->variables()["QMAKE_LIB_FLAG"].isEmpty() ) {
 	    if ( !project->variables()["QMAKE_QT_DLL"].isEmpty()) {
 		project->variables()["DEFINES"].append("QT_MAKEDLL");
@@ -322,8 +368,14 @@ NmakeMakefileGenerator::init()
 			(*libit).replace(QRegExp("qt(-mt)?\\.lib"), ver);
 		}
 	    }
-	    if ( !project->isActiveConfig("dll") && !project->isActiveConfig("plugin") && !project->isActiveConfig("activeqt")) {
-		project->variables()["QMAKE_LIBS"] +=project->variables()["QMAKE_LIBS_QT_DLL"];
+	    if ( project->isActiveConfig( "activeqt" ) ) {
+		project->variables().remove("QMAKE_LIBS_QT_ENTRY");
+		project->variables()["QMAKE_LIBS_QT_ENTRY"] = "$(QTDIR)\\lib\\qaxserver.lib";
+		if ( project->isActiveConfig( "dll" ) )
+		    project->variables()["QMAKE_LIBS"] += project->variables()["QMAKE_LIBS_QT_ENTRY"];
+	    }
+	    if ( !project->isActiveConfig("dll") && !project->isActiveConfig("plugin") ) {
+		project->variables()["QMAKE_LIBS"] +=project->variables()["QMAKE_LIBS_QT_ENTRY"];
 	    }
 	}
     }
@@ -373,17 +425,6 @@ NmakeMakefileGenerator::init()
 	for(QStringList::Iterator inner = gdmf.begin(); inner != gdmf.end(); ++inner)
 	    (*inner) = Option::fixPathToTargetOS((*inner), FALSE);
     }
-    if ( project->isActiveConfig( "activeqt" ) ) {
-	project->variables()["QMAKE_LIBS"].append( "$(QTDIR)\\lib\\activeqt.lib" );
-	project->variables()["IDCOUT"].append( "tmp\\" + targetfilename + ".tlb" );
-	project->variables()["SRCIDC"].append( "tmp\\" + targetfilename + ".res" );
-	project->variables()["IDCTMP"].append( "tmp\\" + targetfilename + ".idl" );
-	project->variables()["IDCTMP"].append( "tmp\\" + targetfilename + ".rc" );
-	project->variables()["IDCTMP"].append( "tmp\\iid_i.c" );
-	project->variables()["IDCTMP"].append( "tmp\\dlldata.c" );
-	project->variables()["IDCTMP"].append( "tmp\\cstub.h" );
-	project->variables()["IDCTMP"].append( "tmp\\proxy.c" );
-    }
 
     if ( !project->variables()["DEF_FILE"].isEmpty() ) 
 	project->variables()["QMAKE_LFLAGS"].append(QString("/DEF:") + project->first("DEF_FILE"));
