@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/main.cpp   3.0.2   edited Jan 14 23:35 $
+** $Id:  qt/main.cpp   3.0.5   edited Jun 15 20:49 $
 **
 ** Definition of ________ class.
 **
@@ -158,7 +158,8 @@ int main(int argc, char **argv)
 		    }
 
 		    QFileInfo fi(Option::output);
-		    Option::output_dir = Option::fixPathToTargetOS(fi.dirPath());
+		    Option::output_dir = Option::fixPathToTargetOS(
+			    (fi.isSymLink() ? fi.readLink() : fi.dirPath()) );
 		    if(!Option::output.open(IO_WriteOnly | IO_Translate)) {
 			fprintf(stderr, "Failure to open file: %s\n",
 				Option::output.name().isEmpty() ? "(stdout)" : Option::output.name().latin1());
@@ -185,7 +186,7 @@ int main(int argc, char **argv)
 	if(Option::debug_level) {
 	    QMap<QString, QStringList> &vars = proj.variables();
 	    for(QMap<QString, QStringList>::Iterator it = vars.begin(); it != vars.end(); ++it) {
-		if(!it.data().isEmpty())
+		if(it.key().left(1) != "." && !it.data().isEmpty())
 		    debug_msg(1, "%s === %s", it.key().latin1(), it.data().join(" :: ").latin1());
 	    }
 	}
