@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/option.cpp   3.0.3   edited Mar 13 11:12 $
+** $Id:  qt/option.cpp   3.0.5   edited May 22 06:06 $
 **
 ** Definition of ________ class.
 **
@@ -66,6 +66,7 @@ QString Option::output_dir;
 QStringList Option::before_user_vars;
 QStringList Option::after_user_vars;
 QString Option::user_template;
+QString Option::user_template_prefix;
 #if defined(Q_OS_WIN32)
 Option::TARG_MODE Option::target_mode = Option::TARG_WIN_MODE;
 #elif defined(Q_OS_MAC9)
@@ -130,6 +131,7 @@ bool usage(const char *a0)
 	    "\t-macx          Run in Mac OS X mode\n"
 	    "\t-d             Increase debug level\n"
 	    "\t-t templ       Overrides TEMPLATE as templ\n"
+	    "\t-tp prefix     Overrides TEMPLATE so that prefix is prefixed into the value\n"
 	    "\t-help          This help\n"
 	    "\t-v             Version information\n"
 	    "\t-after         All variable assignments after this will be\n"
@@ -188,6 +190,8 @@ Option::parseCommandLine(int argc, char **argv)
 		before = FALSE;
 	    } else if(opt == "t" || opt == "template") {
 		Option::user_template = argv[++x];
+	    } else if(opt == "tp" || opt == "template_prefix") {
+		Option::user_template_prefix = argv[++x];
 	    } else if(opt == "mac9") {
 		Option::target_mode = TARG_MAC9_MODE;
 	    } else if(opt == "macx") {
@@ -246,7 +250,7 @@ Option::parseCommandLine(int argc, char **argv)
 		}
 	    }
 	} else {
-	    if(x == 1) 
+	    if(x == 1)
 		Option::qmake_mode = default_mode(argv[0]);
 
 	    QString arg = argv[x];
@@ -264,7 +268,7 @@ Option::parseCommandLine(int argc, char **argv)
 	    }
 	}
     }
-    if(Option::qmake_mode == Option::QMAKE_GENERATE_NOTHING) 
+    if(Option::qmake_mode == Option::QMAKE_GENERATE_NOTHING)
 	Option::qmake_mode = default_mode(argv[0]);
 
     //last chance for defaults
@@ -294,9 +298,9 @@ Option::parseCommandLine(int argc, char **argv)
 	if(Option::mkfile::project_files.isEmpty()) {
 	    QString proj = QDir::currentDirPath();
 	    proj = proj.right(proj.length() - (proj.findRev('/') + 1)) + ".pro";
-	    if(QFile::exists(proj)) 
+	    if(QFile::exists(proj))
 		Option::mkfile::project_files.append(proj);
-	    else 
+	    else
 		return usage(argv[0]);
 	}
     }
@@ -361,6 +365,7 @@ void fixEnvVariables(QString &x)
 {
     int rep;
     QRegExp reg_var("\\$\\(.*\\)");
+    reg_var.setMinimal( TRUE );
     while((rep = reg_var.search(x)) != -1)
 	x.replace(rep, reg_var.matchedLength(), QString(getenv(x.mid(rep + 2, reg_var.matchedLength() - 3).latin1())));
 }
@@ -383,12 +388,13 @@ static QString fixPath(QString x)
 
 
 QString
-Option::fixPathToTargetOS(const QString& in, bool fix_env)
+Option::fixPathToTargetOS(const QString& in, bool fix_env, bool canonical)
 {
     QString tmp(in);
     if(fix_env)
 	fixEnvVariables(tmp);
-    tmp = fixPath(tmp);
+    if(canonical)
+	tmp = fixPath(tmp);
     QString rep;
     if(Option::target_mode == TARG_MAC9_MODE)
 	rep = "[/\\\\]";
@@ -400,12 +406,13 @@ Option::fixPathToTargetOS(const QString& in, bool fix_env)
 }
 
 QString
-Option::fixPathToLocalOS(const QString& in, bool fix_env)
+Option::fixPathToLocalOS(const QString& in, bool fix_env, bool canonical)
 {
     QString tmp(in);
     if(fix_env)
 	fixEnvVariables(tmp);
-    tmp = fixPath(tmp);
+    if(canonical)
+	tmp = fixPath(tmp);
 #if defined(Q_OS_WIN32)
     return tmp.replace(QRegExp("/"), "\\");
 #else
