@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/option.h   3.0.3   edited Feb 12 10:52 $
+** $Id:  qt/option.h   3.0.5   edited May 22 06:06 $
 **
 ** Definition of ________ class.
 **
@@ -43,7 +43,7 @@
 #include <qfile.h>
 
 #define QMAKE_VERSION_MAJOR 1
-#define QMAKE_VERSION_MINOR 2
+#define QMAKE_VERSION_MINOR 3
 #define QMAKE_VERSION_PATCH 0
 const char *qmake_version();
 
@@ -77,8 +77,8 @@ struct Option
     static bool postProcessProject(QMakeProject *); 
 
     //and convenience functions    
-    static QString fixPathToLocalOS(const QString& in, bool fix_env=TRUE);
-    static QString fixPathToTargetOS(const QString& in, bool fix_env=TRUE);
+    static QString fixPathToLocalOS(const QString& in, bool fix_env=TRUE, bool canonical=TRUE);
+    static QString fixPathToTargetOS(const QString& in, bool fix_env=TRUE, bool canonical=TRUE);
 
     //global qmake mode, can only be in one mode per invocation!
     enum QMAKE_MODE { QMAKE_GENERATE_NOTHING, QMAKE_GENERATE_PROJECT, QMAKE_GENERATE_MAKEFILE, 
@@ -93,7 +93,7 @@ struct Option
     static QStringList before_user_vars, after_user_vars;
     enum TARG_MODE { TARG_UNIX_MODE, TARG_WIN_MODE, TARG_MACX_MODE, TARG_MAC9_MODE, TARG_QNX6_MODE };
     static TARG_MODE target_mode;
-    static QString user_template;
+    static QString user_template, user_template_prefix;
 
     //QMAKE_GENERATE_PROJECT options
     struct projfile {
