@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/project.cpp   3.0.2   edited Feb 12 10:52 $
+** $Id:  qt/project.cpp   3.0.5   edited Jun 17 20:35 $
 **
 ** Definition of ________ class.
 **
@@ -47,6 +47,12 @@
 # include <unistd.h>
 #endif
 
+#ifdef Q_OS_WIN32
+#define pOpen _popen
+#else
+#define pOpen popen
+#endif
+
 struct parser_info {
     QString file;
     int line_no;
@@ -65,6 +71,51 @@ static QString varMap(const QString &x)
     return ret;
 }
 
+static QStringList split_arg_list(const QString &params)
+{
+    QStringList args;
+    int last = 0, parens = 0;
+    QChar quote = 0;
+    for(int x = 0; x < (int)params.length(); x++) {
+	if(params[x] == ')') {
+	    parens--;
+	} else if(params[x] == '(') {
+	    parens++;
+	} else if(params[x] == quote) {
+	    quote = 0;
+	} else if(params[x] == '\'' || params[x] == '"') {
+	    quote = params[x];
+	} else if(!parens && !quote && params[x] == ',') {
+	    args << params.mid(last, x - last);
+	    last = x+1;
+	}
+    }
+    if(last != (int)params.length())
+	args << params.mid(last);
+    return args;
+}
+
+static QStringList split_value_list(const QString &vals, bool do_semicolon=FALSE)
+{
+    QStringList ret;
+    int last = 0;
+    QChar quote = 0;
+    for(int x = 0; x < (int)vals.length(); x++) {
+	if(vals[x] == quote) {
+	    quote = 0;
+	} else if(vals[x] == '\'' || vals[x] == '"') {
+	    quote = vals[x];
+	} else if(!quote && 
+		  ((do_semicolon && vals[x] == ';') ||  vals[x] == ' ')) {
+	    ret << vals.mid(last, x - last);
+	    last = x+1;
+	}
+    }
+    if(last != (int)vals.length())
+	ret << vals.mid(last);
+    return ret;
+}
+
 QMakeProject::QMakeProject()
 {
 }
@@ -78,19 +129,19 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
 	return TRUE;
 
     if(s.stripWhiteSpace().left(1) == "}") {
-	debug_msg(1, "Project Parser: %s:%d : Leaving block %d", parser.file.latin1(), 
+	debug_msg(1, "Project Parser: %s:%d : Leaving block %d", parser.file.latin1(),
 		  parser.line_no, scope_block);
 	test_status = ((scope_flag & (0x01 << scope_block)) ? TestFound : TestSeek);
 	scope_block--;
 	s = s.mid(1).stripWhiteSpace();
 	if(s.isEmpty())
 	    return TRUE;
-    } 
+    }
     if(!(scope_flag & (0x01 << scope_block))) {
 	/* adjust scope for each block which appears on a single line */
 	for(int i = (s.contains('{')-s.contains('}')); i; i--)
 	    scope_flag &= ~(0x01 << (++scope_block));
-	debug_msg(1, "Project Parser: %s:%d : Ignored due to block being false.", 
+	debug_msg(1, "Project Parser: %s:%d : Ignored due to block being false.",
 		  parser.file.latin1(), parser.line_no);
 	return TRUE;
     }
@@ -100,7 +151,7 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
 #define SKIP_WS(d) while(*d && (*d == ' ' || *d == '\t')) d++
     const char *d = s.latin1();
     SKIP_WS(d);
-    bool scope_failed = FALSE, else_line = FALSE;
+    bool scope_failed = FALSE, else_line = FALSE, or_op=FALSE;
     int parens = 0, scope_count=0;
     while(*d && *d != '=') {
 	if((*d == '+' || *d == '-' || *d == '*' || *d == '~')) {
@@ -122,23 +173,23 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
 	else if ( *d == ')' )
 	    --parens;
 
-	if(!parens && (*d == ':' || *d == '{' || *d == ')')) {
+	if(!parens && (*d == ':' || *d == '{' || *d == ')' || *d == '|')) {
 	    scope_count++;
 	    scope = var.stripWhiteSpace();
 	    if ( *d == ')' )
 		scope += *d; /* need this */
 	    var = "";
 
-	    bool test = FALSE;
-	    if(scope.lower() == "else" || scope == "|") {
+	    bool test = scope_failed;
+	    if(scope.lower() == "else") {
 		if(scope_count != 1 || test_status == TestNone) {
 		    qmake_error_msg("Unexpected " + scope + " ('" + s + "')");
 		    return FALSE;
-		} 
+		}
 		else_line = TRUE;
 		test = (test_status == TestSeek);
-		debug_msg(1, "Project Parser: %s:%d : Else%s %s.", parser.file.latin1(), parser.line_no, 
-			  scope == "else" ? "" : QString(" (" + scope + ")").latin1(), 
+		debug_msg(1, "Project Parser: %s:%d : Else%s %s.", parser.file.latin1(), parser.line_no,
+			  scope == "else" ? "" : QString(" (" + scope + ")").latin1(),
 			  test ? "considered" : "excluded");
 	    } else {
 		QString comp_scope = scope;
@@ -146,12 +197,12 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
 		if(invert_test)
 		    comp_scope = comp_scope.right(comp_scope.length()-1);
 		int lparen = comp_scope.find('(');
-		if(lparen != -1) { /* if there is an lparen in the scope, it IS a function */
-		    if(!scope_failed) {
+		if(or_op || !scope_failed) {
+		    if(lparen != -1) { /* if there is an lparen in the scope, it IS a function */
 			int rparen = comp_scope.findRev(')');
 			if(rparen == -1) {
 			    QCString error;
-			    error.sprintf("Function missing right paren: %s ('%s')", 
+			    error.sprintf("Function missing right paren: %s ('%s')",
 					  comp_scope.latin1(), s.latin1());
 			    qmake_error_msg(error);
 			    return FALSE;
@@ -164,24 +215,25 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
 			    test_status = (test ? TestFound : TestSeek);
 			    return TRUE;  /* assume we are done */
 			}
+		    } else {
+			test = isActiveConfig(comp_scope.stripWhiteSpace());
 		    }
-		} else {
-		    test = isActiveConfig(comp_scope.stripWhiteSpace());
+		    if(invert_test)
+			test = !test;
 		}
-		if(invert_test)
-		    test = !test;
 	    }
-	    if(!test && !scope_failed) {
-		debug_msg(1, "Project Parser: %s:%d : Test (%s) failed.", parser.file.latin1(), 
+	    if(!test && !scope_failed)
+		debug_msg(1, "Project Parser: %s:%d : Test (%s) failed.", parser.file.latin1(),
 			  parser.line_no, scope.latin1());
-		scope_failed = TRUE;
-	    }
+	    if(test == or_op)
+		scope_failed = !test;
+	    or_op = (*d == '|');
 	    if(*d == '{') { /* scoping block */
 		if(!scope_failed)
 		    scope_flag |= (0x01 << (++scope_block));
 		else
 		    scope_flag &= ~(0x01 << (++scope_block));
-		debug_msg(1, "Project Parser: %s:%d : Entering block %d (%d).", parser.file.latin1(), 
+		debug_msg(1, "Project Parser: %s:%d : Entering block %d (%d).", parser.file.latin1(),
 			  parser.line_no, scope_block, !scope_failed);
 	    }
 	} else {
@@ -189,7 +241,7 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
 	}
 	d++;
     }
-    if(!scope_count || (scope_count == 1 && else_line)) 
+    if(!scope_count || (scope_count == 1 && else_line))
 	test_status = TestNone;
     else if(!else_line || test_status != TestFound)
 	test_status = (scope_failed ? TestSeek : TestFound);
@@ -207,12 +259,16 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
 
     SKIP_WS(d);
     QString vals(d); /* vals now contains the space separated list of values */
-    if(vals.right(1) == "}") {
-	debug_msg(1, "Project Parser: %s:%d : Leaving block %d", parser.file.latin1(), 
+    int rbraces = vals.contains('}'), lbraces = vals.contains('{');
+    if(scope_block && rbraces - lbraces == 1) {
+	debug_msg(1, "Project Parser: %s:%d : Leaving block %d", parser.file.latin1(),
 		  parser.line_no, scope_block);
 	test_status = ((scope_flag & (0x01 << scope_block)) ? TestFound : TestSeek);
 	scope_block--;
 	vals.truncate(vals.length()-1);
+    } else if(rbraces != lbraces) {
+	warn_msg(WarnParser, "Possible braces mismatch {%s} %s:%d",
+		 vals.latin1(), parser.file.latin1(), parser.line_no);
     }
     doVariableReplace(vals, place);
 
@@ -229,28 +285,8 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
     }
     var = varMap(var); //backwards compatability
 
-    QStringList vallist;  /* vallist is the broken up list of values */
-    if((var == "DEPENDPATH" || var == "INCLUDEPATH") && vals.find(';') != -1) { 
-	QRegExp rp("([^;]*)[;$]");
-	for(int x = 0; (x = rp.search(vals, 0)) != -1; ) {
-	    vallist.append("\"" + rp.cap(1) + "\"");
-	    vals.remove(x, rp.matchedLength());
-	}
-	if(!vals.isEmpty()) {
-	    vallist.append("\"" + vals + "\"");
-	    vals = "";
-	}
-    }
-    if(vals.find('"') != -1) { //strip out quoted entities
-	QRegExp quoted("( |^)(\"[^\"]*\")( |$)");
-	for(int x = 0; (x = quoted.search(vals, 0)) != -1; ) {
-	    vallist.append(quoted.cap(2));
-	    vals.remove(x, quoted.matchedLength());
-	}
-    }
-
-    //now split on space
-    vallist += QStringList::split(' ', vals);
+    /* vallist is the broken up list of values */
+    QStringList vallist = split_value_list(vals, (var == "DEPENDPATH" || var == "INCLUDEPATH")); 
     if(!vallist.grep("=").isEmpty())
 	warn_msg(WarnParser, "Detected possible line continuation: {%s} %s:%d",
 		 var.latin1(), parser.file.latin1(), parser.line_no);
@@ -262,7 +298,7 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
     /* now do the operation */
     if(op == "~=") {
 	if(vallist.count() != 1) {
-	    qmake_error_msg("~= operator only accepts one right hand paramater ('" + 
+	    qmake_error_msg("~= operator only accepts one right hand paramater ('" +
 		s + "')");
 	    return FALSE;
 	}
@@ -275,7 +311,7 @@ QMakeProject::parse(QString t, QMap<QString, QStringList> &place)
 	QChar sep = val.at(1);
 	QStringList func = QStringList::split(sep, val, TRUE);
 	if(func.count() < 3 || func.count() > 4) {
-	    qmake_error_msg("~= operator only can handle s/// function ('" + 
+	    qmake_error_msg("~= operator only can handle s/// function ('" +
 		s + "')");
 	    return FALSE;
 	}
@@ -386,22 +422,46 @@ QMakeProject::read(QString project, QString)
 	}
 
 	/* parse mkspec */
+	QStringList mkspec_roots;
+	if(getenv("QTDIR"))
+	    mkspec_roots << getenv("QTDIR");
+#ifdef QT_INSTALL_PREFIX
+	mkspec_roots << QT_INSTALL_PREFIX;
+#endif
+#ifdef QT_INSTALL_DATA
+	mkspecs_roots << QT_INSTALL_DATA;
+#endif
 	if(Option::mkfile::qmakespec.isEmpty()) {
-	    if(getenv("QTDIR") &&
-	       !QFile::exists(Option::mkfile::qmakespec = QString(getenv("QTDIR")) +
-			      QDir::separator() + QString("mkspecs") +
-			      QDir::separator() + "default")) {
+	    for(QStringList::Iterator it = mkspec_roots.begin(); it != mkspec_roots.end(); ++it) {
+		QString mkspec = (*it) + QDir::separator() + QString("mkspecs") +
+				 QDir::separator() + "default";
+		if(QFile::exists(mkspec)) {
+		    Option::mkfile::qmakespec = mkspec;
+		    break;
+		}
+	    }
+	    if(Option::mkfile::qmakespec.isEmpty()) {
 		fprintf(stderr, "QMAKESPEC has not been set, so configuration cannot be deduced.\n");
 		return FALSE;
 	    }
 	}
+
 	if(QDir::isRelativePath(Option::mkfile::qmakespec)) {
-	    if(!getenv("QTDIR")) {
-		fprintf(stderr, "QTDIR has not been set, so mkspec cannot be deduced.\n");
+	    bool found_mkspec = FALSE;
+	    for(QStringList::Iterator it = mkspec_roots.begin(); it != mkspec_roots.end(); ++it) {
+		QString mkspec = (*it) + QDir::separator() + QString("mkspecs") +
+				 QDir::separator() + Option::mkfile::qmakespec;
+		if(QFile::exists(mkspec)) {
+		    found_mkspec = TRUE;
+		    Option::mkfile::qmakespec = mkspec;
+		    break;
+		}
+	    }
+	    if(!found_mkspec) {
+		fprintf(stderr, "Could not find mkspecs for your QMAKESPEC after trying:\n\t%s\n",
+			mkspec_roots.join("\n\t").latin1());
 		return FALSE;
 	    }
-	    Option::mkfile::qmakespec.prepend(QString(getenv("QTDIR")) +
-					      QDir::separator() + "mkspecs" + QDir::separator());
 	}
 	QString spec = Option::mkfile::qmakespec + QDir::separator() + "qmake.conf";
 	debug_msg(1, "QMAKESPEC conf: reading %s", spec.latin1());
@@ -461,6 +521,8 @@ QMakeProject::read(QString project, QString)
 	vars["TEMPLATE"].append(QString("app"));
     else
 	vars["TEMPLATE"].first().replace(QRegExp("\\.t$"), "");
+    if(!Option::user_template_prefix.isEmpty())
+	vars["TEMPLATE"].first().prepend(Option::user_template_prefix);
 
     if(vars["TARGET"].isEmpty()) {
 	QFileInfo fi(pfile);
@@ -543,33 +605,24 @@ QMakeProject::isActiveConfig(const QString &x)
 bool
 QMakeProject::doProjectTest(QString func, const QString &params, QMap<QString, QStringList> &place)
 {
-    QStringList args;
-    int last = 0;
-    QChar quote = 0;
-    for(int x = 0; x < (int)params.length(); x++) {
-	if(params[x] == quote) {
-	    quote = 0;
-	} else if(params[x] == '\'' || params[x] == '"') {
-	    quote = params[x];
-	} else if(!quote && params[x] == ',') {
-	    args << params.mid(last, x - last);
-	    last = x+1;
-	}
-    }
-    if(last != (int)params.length()) 
-	args << params.mid(last);
+    QStringList args = split_arg_list(params);
     for(QStringList::Iterator arit = args.begin(); arit != args.end(); ++arit) {
-	QString tmp = (*arit).stripWhiteSpace(); 
+	QString tmp = (*arit).stripWhiteSpace();
 	if((tmp[0] == '\'' || tmp[0] == '"') && tmp.right(1) == tmp.left(1))
 	    tmp = tmp.mid(1, tmp.length() - 2);
-	(*arit) = tmp.stripWhiteSpace();
     }
-    return doProjectTest(func, args, place);
+    return doProjectTest(func.stripWhiteSpace(), args, place);
 }
 
 bool
-QMakeProject::doProjectTest(QString func, const QStringList &args, QMap<QString, QStringList> &place)
+QMakeProject::doProjectTest(QString func, QStringList args, QMap<QString, QStringList> &place)
 {
+    for(QStringList::Iterator arit = args.begin(); arit != args.end(); ++arit) {
+	(*arit) = (*arit).stripWhiteSpace(); // blah, get rid of space
+	doVariableReplace((*arit), place);
+    }
+    debug_msg(1, "Running project test: %s( %s )", func.latin1(), args.join("::").latin1());
+
     if(func == "requires") {
 	return doProjectCheckReqs(args, place);
     } else if(func == "exists") {
@@ -606,7 +659,13 @@ QMakeProject::doProjectTest(QString func, const QStringList &args, QMap<QString,
 		    parser.line_no);
 	    return FALSE;
 	}
-	return vars[args[0]].findIndex(args[1]) != -1;
+	QRegExp regx(args[1]);
+	QStringList &l = place[args[0]];
+	for(QStringList::ConstIterator it = l.begin(); it != l.end(); ++it) {
+	    if(regx.exactMatch((*it))) 
+		return TRUE;
+	}
+	return FALSE;
     } else if(func == "infile") {
 	if(args.count() < 2 || args.count() > 3) {
 	    fprintf(stderr, "%s:%d: infile(file, var, val) requires at least 2 arguments.\n",
@@ -635,10 +694,18 @@ QMakeProject::doProjectTest(QString func, const QStringList &args, QMap<QString,
 	    QDir::setCurrent(oldpwd);
 	    return FALSE;
 	}
-	if(args.count() == 2 || proj.isEmpty(args[1]))
-	    ret = FALSE;
-	else
-	    ret = (proj.values(args[1]).findIndex(args[2]) != -1);
+	if(args.count() == 2) {
+	    ret = !proj.isEmpty(args[1]);
+	} else {
+	    QRegExp regx(args[2]);
+	    QStringList &l = proj.values(args[1]);
+	    for(QStringList::ConstIterator it = l.begin(); it != l.end(); ++it) {
+		if(regx.exactMatch((*it))) {
+		    ret = TRUE;
+		    break;
+		}
+	    }
+	}
 	QDir::setCurrent(oldpwd);
 	return ret;
     } else if(func == "count") {
@@ -731,7 +798,7 @@ QMakeProject::doProjectCheckReqs(const QStringList &deps, QMap<QString, QStringL
 	    test = !test;
 	}
 	if(!test) {
-	    debug_msg(1, "Project Parser: %s:%d Failed test: REQUIRES = %s", 
+	    debug_msg(1, "Project Parser: %s:%d Failed test: REQUIRES = %s",
 		      parser.file.latin1(), parser.line_no, chk.latin1());
 	    place["QMAKE_FAILED_REQUIREMENTS"].append(chk);
 	    ret = FALSE;
@@ -746,36 +813,49 @@ QMakeProject::doVariableReplace(QString &str, const QMap<QString, QStringList> &
 {
     for(int x = 0, rep; x < 5; x++) {
 	QRegExp reg_var;
+	reg_var.setMinimal(TRUE);
 	if( x == 0 ) //function blocked out by {}'s
-	    reg_var = QRegExp("\\$\\$\\{([a-zA-Z0-9_]*)\\(([^)]*)\\)\\}");
+	    reg_var = QRegExp("\\$\\$\\{([a-zA-Z0-9_]*)\\((\\(.|(.*)\\)*)\\)\\}");
 	else if( x == 1 ) //variables blocked out by {}'s
 	    reg_var = QRegExp("\\$\\$\\{([a-zA-Z0-9_\\.-]*)\\}");
 	else if(x == 2) //environment
 	    reg_var = QRegExp("\\$\\$\\(([a-zA-Z0-9_\\.-]*)\\)");
 	else if(x == 3) //function
-	    reg_var = QRegExp("\\$\\$([a-zA-Z0-9_]*)\\(([^)]*)\\)");
+	    reg_var = QRegExp("\\$\\$([a-zA-Z0-9_]*)\\((\\(.|(.*)\\)*)\\)");
 	else if(x == 4) //normal variable
 	    reg_var = QRegExp("\\$\\$([a-zA-Z0-9_\\.-]*)");
 	while((rep = reg_var.search(str)) != -1) {
 	    QString replacement;
 	    if(x == 2) {//environment
 		replacement = getenv(reg_var.cap(1));
-	    } else if(x == 0 || x == 3) { //function 
-		QStringList args = QStringList::split(',', reg_var.cap(2));
-		for(QStringList::Iterator arit = args.begin(); arit != args.end(); ++arit)
+	    } else if(x == 0 || x == 3) { //function
+		QStringList args = split_arg_list(reg_var.cap(2));
+		for(QStringList::Iterator arit = args.begin(); arit != args.end(); ++arit) {
 		    (*arit) = (*arit).stripWhiteSpace(); // blah, get rid of space
+		    doVariableReplace((*arit), place);
+		}
+		debug_msg(1, "Running function: %s( %s )", reg_var.cap(1).latin1(), args.join("::").latin1());
 		if(reg_var.cap(1).lower() == "member") {
 		    if(args.count() < 1 || args.count() > 2) {
-			fprintf(stderr, "%s:%d: member(var, place) requires two arguments.\n", 
+			fprintf(stderr, "%s:%d: member(var, place) requires two arguments.\n",
 				parser.file.latin1(), parser.line_no);
 		    } else {
 			uint pos = 0;
 			if(args.count() == 2)
 			    pos = args[1].toInt();
 			const QStringList &var = place[varMap(args.first())];
-			if(var.count() >= pos) 
+			if(var.count() >= pos)
 			    replacement = var[pos];
 		    }
+		} else if(reg_var.cap(1).lower() == "list") {
+		    if(args.count() != 1) {
+			fprintf(stderr, "%s:%d: list(vals) requires one"
+				"argument.\n", parser.file.latin1(), parser.line_no);
+		    } else {
+			static int x = 0;
+			replacement.sprintf(".QMAKE_INTERNAL_TMP_VAR_%d", x++);
+			(*((QMap<QString, QStringList>*)&place))[replacement] = split_value_list(args.first());
+		    }
 		} else if(reg_var.cap(1).lower() == "join") {
 		    if(args.count() < 1 || args.count() > 4) {
 			fprintf(stderr, "%s:%d: join(var, glue, before, after) requires four"
@@ -794,12 +874,12 @@ QMakeProject::doVariableReplace(QString &str, const QMap<QString, QStringList> &
 		    }
 		} else if(reg_var.cap(1).lower() == "find") {
 		    if(args.count() != 2) {
-			fprintf(stderr, "%s:%d find(var, str) requires two arguments\n", 
+			fprintf(stderr, "%s:%d find(var, str) requires two arguments\n",
 				parser.file.latin1(), parser.line_no);
 		    } else {
 			QRegExp regx = QRegExp(args[1]);
 			const QStringList &var = place[varMap(args.first())];
-			for(QStringList::ConstIterator vit = var.begin(); 
+			for(QStringList::ConstIterator vit = var.begin();
 			    vit != var.end(); ++vit) {
 			    if(regx.match(*vit) != -1) {
 				if(!replacement.isEmpty())
@@ -808,18 +888,39 @@ QMakeProject::doVariableReplace(QString &str, const QMap<QString, QStringList> &
 			    }
 			}
 		    }
+		} else if(reg_var.cap(1).lower() == "system") {
+		    if(args.count() != 1) {
+			fprintf(stderr, "%s:%d system(execut) requires one argument\n",
+				parser.file.latin1(), parser.line_no);
+		    } else {
+			char buff[256];
+			FILE *proc = pOpen(args.join(" ").latin1(), "r");
+			while(proc && !feof(proc)) {
+			    int read_in = fread(buff, 1, 255, proc);
+			    if(!read_in)
+				break;
+			    for(int i = 0; i < read_in; i++) {
+				if(buff[i] == '\n' || buff[i] == '\t')
+				    buff[i] = ' ';
+			    }
+			    buff[read_in] = '\0';
+			    replacement += buff;
+			}
+		    }
 		} else {
-		    fprintf(stderr, "%s:%d: Unknown replace function: %s\n", 
-			    parser.file.latin1(), parser.line_no, reg_var.cap(1).latin1());		    
+		    fprintf(stderr, "%s:%d: Unknown replace function: %s\n",
+			    parser.file.latin1(), parser.line_no, reg_var.cap(1).latin1());
 		}
 	    } else { //variable
-		if(reg_var.cap(1) == "LITERAL_WHITESPACE") 
+		if(reg_var.cap(1).left(1) == ".")
+		    replacement = "";
+		else if(reg_var.cap(1) == "LITERAL_WHITESPACE")
 		    replacement = "\t";
 		else
 		    replacement = place[varMap(reg_var.cap(1))].join(" ");
 	    }
 	    debug_msg(2, "Project parser: %d (%s) :: %s -> %s", x, str.latin1(),
-		   reg_var.cap(0).latin1(), replacement.latin1());
+		      reg_var.capturedTexts().join("::").latin1(), replacement.latin1());
 	    str.replace(rep, reg_var.matchedLength(), replacement);
 	}
     }
