@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qcolordialog.cpp   3.0.2   edited Jan 9 13:27 $
+** $Id:  qt/qcolordialog.cpp   3.0.5   edited Jun 7 16:44 $
 **
 ** Implementation of QColorDialog class
 **
@@ -79,6 +79,7 @@ public:
     int selectedColumn() const { return selCol; }
     int selectedRow() const { return selRow; }
 
+    virtual void setCurrent( int row, int col );
     virtual void setSelected( int row, int col );
 
     QSize sizeHint() const;
@@ -91,7 +92,6 @@ signals:
 
 protected:
     void dimensionChange( int oldRows, int oldCols );
-    virtual void setCurrent( int row, int col );
 
     virtual void paintCell( QPainter *, int row, int col );
     virtual void paintCellContents( QPainter *, int row, int col, const QRect& );
@@ -337,7 +337,7 @@ void QWellArray::focusInEvent( QFocusEvent* )
 
 /*!
   Sets the size of the well array to be \a rows cells by \a cols.
-  Resets any brush info set by setCellBrush().
+  Resets any brush information set by setCellBrush().
  */
 void QWellArray::dimensionChange( int, int )
 {
@@ -430,6 +430,7 @@ void QWellArray::keyPressEvent( QKeyEvent* e )
 static bool initrgb = FALSE;
 static QRgb stdrgb[6*8];
 static QRgb cusrgb[2*8];
+static bool customSet = FALSE;
 
 
 static void initRGB()
@@ -483,6 +484,7 @@ void QColorDialog::setCustomColor( int i, QRgb c )
 #endif
 	return;
     }
+    customSet = TRUE;
     cusrgb[i] = c;
 }
 
@@ -748,7 +750,7 @@ void QColorLuminancePicker::paintEvent( QPaintEvent * )
     }
     QPainter p(this);
     p.drawPixmap( 1, coff, *pix );
-    QColorGroup g = colorGroup();
+    const QColorGroup &g = colorGroup();
     qDrawShadePanel( &p, r, g, TRUE );
     p.setPen( g.foreground() );
     p.setBrush( g.foreground() );
@@ -1211,18 +1213,19 @@ public:
     void setCurrentAlpha( int a ) { cs->setCurrentAlpha( a ); }
     void showAlpha( bool b ) { cs->showAlpha( b ); }
 
-private slots:
+public slots:
     void addCustom();
 
     void newHsv( int h, int s, int v );
     void newColorTypedIn( QRgb rgb );
     void newCustom( int, int );
     void newStandard( int, int );
+public:
+    QWellArray *custom;
+    QWellArray *standard;
 private:
     QColorPicker *cp;
     QColorLuminancePicker *lp;
-    QWellArray *custom;
-    QWellArray *standard;
     QColorShower *cs;
     int nextCust;
     bool compact;
@@ -1381,32 +1384,37 @@ void QColorDialogPrivate::addCustom()
 
 
 /*!
-  \class QColorDialog qcolordialog.h
-  \ingroup dialogs
-  \ingroup graphics
-  \mainclass
-  \brief The QColorDialog class provides a dialog widget for specifying colors.
+    \class QColorDialog qcolordialog.h
+    \ingroup dialogs
+    \ingroup graphics
+    \mainclass
+    \brief The QColorDialog class provides a dialog widget for specifying colors.
 
-  The color dialog's function is to allow users to choose colors - for
-  instance, you might use this in a drawing program to allow the user
-  to set the brush color.
+    The color dialog's function is to allow users to choose colors -
+    for instance, you might use this in a drawing program to allow the
+    user to set the brush color.
 
-  This version of Qt provides only modal color dialogs. The static
-  getColor() function shows the dialog and allows the user to specify
-  a color, whereas getRgba() does the same but allows the user to
-  specify a color with an alpha channel (transparency) value.
+    The static functions provide modal color dialogs.
+    \omit
+    If you require a modeless dialog, use the QColorDialog constructor.
+    \endomit
 
-  The user can store customCount() different custom colors. The custom
-  colors are shared by all color dialogs, and remembered during the
-  execution of the program. Use setCustomColor() to set the custom
-  colors, and use customColor() to get them.
+    The static getColor() function shows the dialog and allows the
+    user to specify a color. The getRgba() function does the same but
+    also allows the user to specify a color with an alpha channel
+    (transparency) value.
 
-  <img src=qcolordlg-w.png>
+    The user can store customCount() different custom colors. The
+    custom colors are shared by all color dialogs, and remembered
+    during the execution of the program. Use setCustomColor() to set
+    the custom colors, and use customColor() to get them.
+
+    <img src=qcolordlg-w.png>
 */
 
-/*!  Constructs a default color dialog with parent \a parent called \a
- name. If \a modal is TRUE the dialog will be modal. Use setColor() for
- setting an initial value.
+/*!  Constructs a default color dialog with parent \a parent and called \a
+ name. If \a modal is TRUE the dialog will be modal. Use setColor() to
+ set an initial value.
 
   \sa getColor()
 */
@@ -1416,12 +1424,16 @@ QColorDialog::QColorDialog(QWidget* parent, const char* name, bool modal) :
 {
     setSizeGripEnabled( FALSE );
     d = new QColorDialogPrivate( this );
-    QSettings settings;
-    for ( int i = 0; i < 2*8; ++i ) {
-	bool ok = FALSE;
-	QRgb rgb = (QRgb)settings.readNumEntry( "/qt/customColors/" + QString::number( i ) + "/", 0, &ok );
-	if ( ok )
-	    cusrgb[i] = rgb;
+
+    if ( !customSet ) {
+	QSettings settings;
+	settings.insertSearchPath( QSettings::Windows, "/Trolltech" );
+	for ( int i = 0; i < 2*8; ++i ) {
+	    bool ok = FALSE;
+	    QRgb rgb = (QRgb)settings.readNumEntry( "/Qt/customColors/" + QString::number( i ), 0, &ok );
+	    if ( ok )
+		cusrgb[i] = rgb;
+	}
     }
 }
 
@@ -1453,6 +1465,7 @@ QColor QColorDialog::getColor( const QColor& initial, QWidget *parent,
     dlg->setCaption( QColorDialog::tr( "Select color" ) );
 #endif
     dlg->setColor( initial );
+    dlg->selectColor( initial );
     int resultCode = dlg->exec();
     QColor::leaveAllocContext();
     QColor result;
@@ -1466,11 +1479,12 @@ QColor QColorDialog::getColor( const QColor& initial, QWidget *parent,
 
 /*!
   Pops up a modal color dialog to allow the user to choose a color and
-  an alpha channel value. The color+alpha is initially set to \a
-  initial. The dialog is a child of \a parent and called \a name.
+  an alpha channel (transparency) value. The color+alpha is initially
+  set to \a initial. The dialog is a child of \a parent and called \a
+  name.
 
-  If \a ok is non-null, \c *ok is set to TRUE if the user clicked OK,
-  and FALSE if the user clicked Cancel.
+  If \a ok is non-null, \e *\a ok is set to TRUE if the user clicked OK,
+  and to FALSE if the user clicked Cancel.
 
   If the user clicks Cancel, the \a initial value is returned.
 */
@@ -1485,6 +1499,7 @@ QRgb QColorDialog::getRgba( QRgb initial, bool *ok,
     int allocContext = QColor::enterAllocContext();
     QColorDialog *dlg = new QColorDialog( parent, name, TRUE );  //modal
     dlg->setColor( initial );
+    dlg->selectColor( initial );
     dlg->setSelectedAlpha( qAlpha(initial) );
     int resultCode = dlg->exec();
     QColor::leaveAllocContext();
@@ -1524,9 +1539,12 @@ QColor QColorDialog::color() const
 
 QColorDialog::~QColorDialog()
 {
-    QSettings settings;
-    for ( int i = 0; i < 2*8; ++i )
-	settings.writeEntry( "/qt/customColors/" + QString::number( i ) + "/", (int)cusrgb[i] );
+    if ( !customSet ) {
+	QSettings settings;
+	settings.insertSearchPath( QSettings::Windows, "/Trolltech" );
+	for ( int i = 0; i < 2*8; ++i )
+	    settings.writeEntry( "/Qt/customColors/" + QString::number( i ), (int)cusrgb[i] );
+    }
 }
 
 
@@ -1545,7 +1563,7 @@ void QColorDialog::setColor( const QColor& c )
 
 
 /*!
-  Sets the initial alpha channel value to \a a, and show the alpha channel
+  Sets the initial alpha channel value to \a a, and shows the alpha channel
   entry box.
 */
 
@@ -1565,6 +1583,39 @@ int QColorDialog::selectedAlpha() const
     return d->currentAlpha();
 }
 
+/*!
+  Sets focus to the corresponding button, if any.
+*/
+bool QColorDialog::selectColor( const QColor& col )
+{
+    QRgb color = col.rgb();
+    int i = 0, j = 0;
+    // Check standard colors
+    for ( i = 0; i < 6; i++ ) {
+	for ( j = 0; j < 8; j++ ) {
+	    if ( color == stdrgb[i + j*6] ) {
+		d->newStandard( i, j );
+		d->standard->setCurrent( i, j );
+		d->standard->setSelected( i, j );
+		d->standard->setFocus();
+		return TRUE;
+	    }
+	}
+    }
+    // Check custom colors
+    for ( i = 0; i < 2; i++ ) {
+	for ( j = 0; j < 8; j++ ) {
+	    if ( color == cusrgb[i + j*2] ) {
+		d->newCustom( i, j );
+		d->custom->setCurrent( i, j );
+		d->custom->setSelected( i, j );
+		d->custom->setFocus();
+		return TRUE;
+	    }
+	}
+    }
+    return FALSE;
+}
 
 #include "qcolordialog.moc"
 
