@@ -1,13 +1,13 @@
 /****************************************************************************
-** $Id:  qt/qdialog.cpp   3.0.2   edited Jan 25 01:29 $
+** $Id$
 **
 ** Implementation of QDialog class
 **
 ** Created : 950502
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
 **
-** This file is part of the kernel module of the Qt GUI Toolkit.
+** This file is part of the dialogs module of the Qt GUI Toolkit.
 **
 ** This file may be distributed under the terms of the Q Public License
 ** as defined by Trolltech AS of Norway and appearing in the file
@@ -40,6 +40,7 @@
 #ifndef QT_NO_DIALOG
 
 #include "qpushbutton.h"
+#include "qfocusdata.h"
 #include "qapplication.h"
 #include "qobjectlist.h"
 #include "qwidgetlist.h"
@@ -47,6 +48,7 @@
 #include "qsizegrip.h"
 #include "qwhatsthis.h"
 #include "qpopupmenu.h"
+#include "qcursor.h"
 #if defined(QT_ACCESSIBILITY_SUPPORT)
 #include "qaccessible.h"
 #endif
@@ -62,20 +64,23 @@
   \ingroup abstractwidgets
   \mainclass
 
-  A dialog window is a top-level window mostly used for short-term tasks
-  and brief communications with the user. QDialogs may be modal or
-  modeless. QDialogs can have \link #default default buttons\endlink,
-  support \link #extensibility extensibility\endlink and may provide a
-  \link #return return value\endlink. QDialogs can have a QSizeGrip in
-  their lower-right corner, using setSizeGripEnabled().
+  A dialog window is a top-level window mostly used for short-term
+  tasks and brief communications with the user. QDialogs may be modal
+  or modeless. QDialogs support \link #extensibility
+  extensibility\endlink and can provide a \link #return return
+  value\endlink. They can have \link #default default buttons\endlink.
+  QDialogs can also have a QSizeGrip in their lower-right corner,
+  using setSizeGripEnabled().
 
-    Note that QDialog uses the parent widget slightly differently from
-    other classes in Qt.  A dialog is always a top-level widget, but if
-    it has a parent, its default location is centered on top of the
-    parent. It will also share the parent's taskbar entry, for example.
+  Note that QDialog uses the parent widget slightly differently from
+  other classes in Qt. A dialog is always a top-level widget, but if
+  it has a parent, its default location is centered on top of the
+  parent. It will also share the parent's taskbar entry.
 
   There are three kinds of dialog that are useful:
-    \list 1
+
+  \list 1
+
   \i A <b>modal</b> dialog is a dialog that blocks input to other visible
   windows in the same application: users must finish interacting
   with the dialog and close it before they can access any other window
@@ -90,28 +95,32 @@
   return the appropriate value. Alternatively you can connect to the
   done() slot, passing it \c Accepted or \c Rejected.
 
-  \i A <b>non-modal</b> dialog is a dialog that operates independently of
-  other windows in the same application.  Find and replace dialogs in
+  \i A <b>modeless</b> dialog is a dialog that operates independently of
+  other windows in the same application. Find and replace dialogs in
   word-processors are often modeless to allow the user to interact with
   both the application's main window and the dialog. Call show() to
-  display a non-modal dialog. show() returns immediately so the flow of
+  display a modeless dialog. show() returns immediately so the flow of
   control will continue in the calling code. In practice you will often
   call show() and come to the end of the function in which show() is
   called with control returning to the main event loop.
 
-  \i <a name="semimodal">A "<b>semi-modal</b>" dialog is a modal dialog
-  that returns control to the caller immediately. Semi-modal dialogs do
-  not have their own event loop, so you will need to call
-  QApplication::processEvents() periodically to give the semi-modal
-  dialog the opportunity to process its events. A progress dialog
-  (e.g. QProgressDialog) is an example, where you only want the user to
-  be able to interact with the progress dialog, e.g. to cancel a long
-  running operation, but need to actually carry out the operation.
-  Semi-modal dialogs are displayed by setting the modal flag to TRUE and
-  calling the \l show() function.
+  \i
+  \target semimodal
+  A "<b>semi-modal</b>" dialog is a modal dialog that returns control
+  to the caller immediately. Semi-modal dialogs do not have their own
+  event loop, so you will need to call QApplication::processEvents()
+  periodically to give the semi-modal dialog the opportunity to
+  process its events. A progress dialog (e.g. QProgressDialog) is an
+  example, where you only want the user to be able to interact with
+  the progress dialog, e.g. to cancel a long running operation, but
+  need to actually carry out the operation. Semi-modal dialogs are
+  displayed by setting the modal flag to TRUE and calling the \l
+  show() function.
   \endlist
 
-    <a name="default"><b>Default button</b><br>
+  \target default
+  \section1 Default button
+
   A dialog's "default" button is the button that's pressed when the user
   presses Enter or Return. This button is used to signify that the user
   accepts the dialog's settings and wishes to close the dialog. Use
@@ -119,7 +128,9 @@
   QPushButton::autoDefault() to set and control the dialog's default
   button.
 
-    <a name="extensibility"><b>Extensibility</b><br>
+  \target extensibility
+  \section1 Extensibility
+
   Extensibility is the ability to show the dialog in two ways: a partial
   dialog that shows the most commonly used options, and a full dialog
   that shows all the options. Typically an extensible dialog
@@ -128,40 +139,43 @@
   appear. Extensibility is controlled with setExtension(),
   setOrientation() and showExtension().
 
-    <a name="return"><b>Return value (modal dialogs)</b><br>
-    Modal dialogs are often used in situations where a return value is
-    required; for example to indicate whether the user pressed OK or
-    Cancel. A dialog can be closed by calling the accept() or the
-    reject() slots, and exec() will return \c Accepted or \c Rejected as
-    appropriate. After the exec() call has returned the result is
-    available from result(). Note that if the WDestructiveClose flag
-    is set, then when accept() returns the dialog is deleted.
+  \target return
+  \section1 Return value (modal dialogs)
 
+  Modal dialogs are often used in situations where a return value is
+  required; for example to indicate whether the user pressed "OK" or
+  "Cancel". A dialog can be closed by calling the accept() or the
+  reject() slots, and exec() will return \c Accepted or \c Rejected as
+  appropriate. The exec() call returns the result of the dialog. The
+  result is also available from result() if the dialog has not been
+  destroyed. If the \c WDestructiveClose flag is set, then when exec()
+  returns the dialog is deleted.
 
-    <a name="examples"><b>Examples</b><br>
+  \target examples
+  \section1 Examples
 
-    A modal dialog.
+  A modal dialog.
 
-    \quotefile network/networkprotocol/view.cpp
-    \skipto QFileDialog *dlg
-    \printuntil return
+  \quotefile network/networkprotocol/view.cpp
+  \skipto QFileDialog *dlg
+  \printuntil return
 
-    A modeless dialog. After the show() call, control returns to the main
-    event loop.
-    \quotefile life/main.cpp
-    \skipto argv
-    \printuntil QApplication
-    \skipto scale
-    \printline
-    \skipto LifeDialog
-    \printuntil show
-    \skipto exec
-    \printuntil }
+  A modeless dialog. After the show() call, control returns to the main
+  event loop.
+  \quotefile life/main.cpp
+  \skipto argv
+  \printuntil QApplication
+  \skipto scale
+  \printline
+  \skipto LifeDialog
+  \printuntil show
+  \skipto exec
+  \printuntil }
 
-    See the \l QProgressDialog documentation for an example of a
-    semi-modal dialog.
+  See the \l QProgressDialog documentation for an example of a
+  semi-modal dialog.
 
-    \sa QTabDialog QWidget QProgressDialog
+  \sa QTabDialog QWidget QProgressDialog
   \link guibooks.html#fowler GUI Design Handbook: Dialogs, Standard\endlink
 */
 
@@ -179,7 +193,7 @@
   \brief whether the size grip is enabled
 
   A QSizeGrip is placed in the bottom right corner of the dialog when this
-  property is enabled.  By default, the size grip is disabled.
+  property is enabled. By default, the size grip is disabled.
 */
 
 class QDialogPrivate : public Qt
@@ -211,12 +225,12 @@ public:
   If \a modal is FALSE (the default), the dialog is modeless and should
   be displayed with show(). If \a modal is TRUE and the dialog is
   displayed with exec(), the dialog is modal, i.e. blocks input to other
-  windows. If \a modal is TRUE and the dialog is displayed show(), the
-  dialog is semi-modal.
+  windows in this application. If \a modal is TRUE and the dialog is
+  displayed using show(), the dialog is semi-modal.
 
   The widget flags \a f are passed on to the QWidget constructor.
 
-  If, for example, you don't want a What's this button in the titlebar
+  If, for example, you don't want a What's This button in the titlebar
   of the dialog, pass WStyle_Customize | WStyle_NormalBorder |
   WStyle_Title | WStyle_SysMenu in \a f.
 
@@ -306,6 +320,9 @@ void QDialog::hideDefault()
   \fn int  QDialog::result() const
 
   Returns the modal dialog's result code, \c Accepted or \c Rejected.
+
+  Do not call this function if the dialog was constructed with the \c
+  WDestructiveClose flag. (exec() returns the result code anyway.)
 */
 
 /*!
@@ -373,7 +390,7 @@ void QDialog::done( int r )
     setResult( r );
 
     // We cannot use close() here, as close() calls closeEvent() calls
-    // reject() calls close().  But we can at least keep the
+    // reject() calls close(). But we can at least keep the
     // mainWidget() and WDestructiveClose semantics. There should not
     // be much of a difference whether the users types Alt-F4 or
     // Escape. Without that, destructive-close dialogs were more or
@@ -382,7 +399,7 @@ void QDialog::done( int r )
 	qApp->quit();
 
     if ( testWFlags(WDestructiveClose) )
-	delete this;
+	deleteLater();
 }
 
 /*!
@@ -435,9 +452,9 @@ void QDialog::contextMenuEvent( QContextMenuEvent *e )
 /*! \reimp */
 void QDialog::keyPressEvent( QKeyEvent *e )
 {
-    //   Calls reject() if Escape is pressed.  Simulates a button
-    //   click for the default button if Enter is pressed.  Move focus
-    //   for the arrow keys.  Ignore the rest.
+    //   Calls reject() if Escape is pressed. Simulates a button
+    //   click for the default button if Enter is pressed. Move focus
+    //   for the arrow keys. Ignore the rest.
     if ( e->state() == 0 || ( e->state() & Keypad && e->key() == Key_Enter ) ) {
 	switch ( e->key() ) {
 	case Key_Enter:
@@ -537,44 +554,55 @@ void QDialog::show()
     if ( !did_resize )
 	adjustSize();
     if ( has_relpos ) {
-	if ( parentWidget() )
-	    adjustPositionInternal( parentWidget(), TRUE );
+	adjustPositionInternal( parentWidget() ? parentWidget() : qApp->mainWidget(), TRUE );
     } else if ( !did_move ) {
-	adjustPositionInternal( parentWidget() );
+	adjustPositionInternal( parentWidget() ? parentWidget() : qApp->mainWidget() );
     }
     QWidget::show();
 #ifndef QT_NO_PUSHBUTTON
     QWidget *fw = focusWidget();
-    if ( !d->mainDef ) {
+    QFocusData *fd = focusData();
+
+    /*
+      The following block is to handle a special case, and does not really follow
+      propper logic in concern of autoDefault and TAB order. However, it's here to
+      ease usage for the users. If a dialog has a default QPushButton, and first
+      widget in the TAB order also is a QPushButton, then we give focus to the
+      main default QPushButton. This simplifies code for the developers, and
+      actually catches most cases... If not, then they simply have to use
+      [widget*]->setFocus() them selfs...
+    */
+    if ( !fw ) {
+	fd->home(); // Skip main form
+	QWidget *first = fd->next(); // Get first main widget
+	if ( d->mainDef &&
+	     first != d->mainDef &&
+	     first->inherits("QPushButton") )
+	    d->mainDef->setFocus();
+    }
+    // -- [End special case block] --
+
+    if ( !d->mainDef && isTopLevel() ) {
 	if ( !fw ) {
 	    focusNextPrevChild( TRUE );
 	    fw = focusWidget();
 	}
-
-	QObjectList *pbs = queryList( "QPushButton" );
-	if ( pbs && !pbs->isEmpty() ) {
-	    QObjectListIt it( *pbs );
-	    QPushButton *champion = 0;
-	    QPushButton *challenger;
-	    while ( (challenger = (QPushButton *) it.current()) ) {
-		++it;
-		if ( challenger->topLevelWidget() == this &&
-		     challenger->autoDefault() ) {
-		    if ( (QWidget *) challenger == fw ) {
-			champion = challenger;
-			break;
+        if ( fw ) {
+	    fd = focusData();
+	    QWidget *home = fd->home();
+	    QWidget *candidate = home;
+	    Q_ASSERT( candidate == fw );
+	    do {
+                if ( candidate->inherits("QPushButton") ) {
+		    QPushButton *pb = (QPushButton *)candidate;
+		    if ( pb->autoDefault() ) {
+                        pb->setDefault( TRUE );
+                        break;
 		    }
-		    if ( champion == 0 ) {
-			champion = challenger;
-			if ( fw == 0 )
-			    break;
-		    }
-		}
-	    }
-	    if ( champion )
-		champion->setDefault( TRUE );
-	}
-	delete pbs;
+                }
+                candidate = fd->next();
+	    } while ( candidate != home );
+        }
     }
     if ( fw ) {
 	QFocusEvent e( QEvent::FocusIn );
@@ -582,7 +610,7 @@ void QDialog::show()
 	QApplication::sendEvent( fw, &e );
 	QFocusEvent::resetReason();
     }
-    
+
 #endif
 #if defined(QT_ACCESSIBILITY_SUPPORT)
     QAccessible::updateAccessibility( this, 0, QAccessible::DialogStart );
@@ -605,28 +633,31 @@ void QDialog::adjustPositionInternal( QWidget*w, bool useRelPos)
     QApplication::sendPostedEvents(this, QEvent::Resize);
 
     QPoint p( 0, 0 );
-    int extraw = 0, extrah = 0;
+    int extraw = 0, extrah = 0, scrn = 0;
     if ( w )
 	w = w->topLevelWidget();
-    QWidget *relative = w ? w : qApp->mainWidget();
     QRect desk;
-    if ( relative )
-	desk = QApplication::desktop()->screenGeometry( QApplication::desktop()->screenNumber( w ? w : qApp->mainWidget() ) );
+    if ( w )
+	scrn =  QApplication::desktop()->screenNumber( w );
     else
-	desk = QApplication::desktop()->screenGeometry( QApplication::desktop()->screenNumber( QCursor::pos() ) );
+	scrn = QApplication::desktop()->screenNumber( QCursor::pos() );
+    desk = QApplication::desktop()->screenGeometry( scrn );
 
     QWidgetList  *list = QApplication::topLevelWidgets();
     QWidgetListIt it( *list );
     while ( (extraw == 0 || extrah == 0) &&
 	    it.current() != 0 ) {
-	int w, h;
+	int framew, frameh;
 	QWidget * current = it.current();
 	++it;
-	w = current->geometry().x() - current->x();
-	h = current->geometry().y() - current->y();
+	if ( ! current->isVisibleTo( 0 ) )
+	    continue;
 
-	extraw = QMAX( extraw, w );
-	extrah = QMAX( extrah, h );
+	framew = current->geometry().x() - current->x();
+	frameh = current->geometry().y() - current->y();
+
+	extraw = QMAX( extraw, framew );
+	extrah = QMAX( extrah, frameh );
     }
     delete list;
 
@@ -637,7 +668,6 @@ void QDialog::adjustPositionInternal( QWidget*w, bool useRelPos)
 
     if ( useRelPos ) {
 	p = w->pos() + d->relPos;
-
     } else {
 	if ( w ) {
 	    // Use mapToGlobal rather than geometry() in case w might
@@ -841,20 +871,25 @@ void QDialog::showExtension( bool showIt )
 	if ( layout() )
 	    layout()->setEnabled( FALSE );
 #endif
-	QSize s( d->extension->sizeHint() );
+	QSize s( d->extension->sizeHint()
+		 .expandedTo( d->extension->minimumSize() )
+		 .boundedTo( d->extension->maximumSize() ) );
 	if ( d->orientation == Horizontal ) {
-	    d->extension->setGeometry( width(), 0, s.width(), height() );
-	    setFixedSize( width() + s.width(), height() );
+	    int h = QMAX( height(), s.height() );
+	    d->extension->setGeometry( width(), 0, s.width(), h );
+	    setFixedSize( width() + s.width(), h );
 	} else {
-	    d->extension->setGeometry( 0, height(), width(), s.height() );
-	    setFixedSize( width(), height() + s.height() );
+	    int w = QMAX( width(), s.width() );
+	    d->extension->setGeometry( 0, height(), w, s.height() );
+	    setFixedSize( w, height() + s.height() );
 	}
 	d->extension->show();
     } else {
 	if ( !d->extension->isVisible() )
 	    return;
 	d->extension->hide();
-	setMinimumSize( d->min );
+	// workaround for CDE window manager that won't shrink with (-1,-1)
+	setMinimumSize( d->min.expandedTo( QSize( 1, 1 ) ) );
 	setMaximumSize( d->max );
 	resize( d->size );
 #ifndef QT_NO_LAYOUT
