@@ -63,12 +63,14 @@
   \brief The QFontDialog class provides a dialog widget for selecting a font.
 
   The usual way to use this class is to call one of the static convenience
-  functions, getFont(), e.g.
+  functions, e.g. getFont().
 
   Examples:
+
   \code
     bool ok;
-    QFont font = QFontDialog::getFont( &ok, QFont( "Helvetica [Cronyx]", 10 ), this );
+    QFont font = QFontDialog::getFont(
+		    &ok, QFont( "Helvetica [Cronyx]", 10 ), this );
     if ( ok ) {
 	// font is set to the font the user selected
     } else {
@@ -79,10 +81,10 @@
 
     The dialog can also be used to set a widget's font directly:
   \code
-    aWidget.setFont( QFontDialog::getFont( 0, aWidget.font() ) );
+    myWidget.setFont( QFontDialog::getFont( 0, myWidget.font() ) );
   \endcode
-  If the user clicks OK the font they chose will be used for aWidget,
-  and if they click cancel the original font is kept.
+  If the user clicks OK the font they chose will be used for myWidget,
+  and if they click Cancel the original font is used.
 
   \sa QFont QFontInfo QFontMetrics
 
@@ -140,12 +142,13 @@ public:
 
 
 /*!
+  \internal
   Constructs a standard font dialog.
 
-  Use setFont() for setting the initial font attributes.
+  Use setFont() to set the initial font attributes.
 
-    The \a parent, \a name, \a modal and \a f parameters are passed to
-    the QDialog constructor.
+  The \a parent, \a name, \a modal and \a f parameters are passed to
+  the QDialog constructor.
 
   \sa getFont()
 */
@@ -317,7 +320,10 @@ QFontDialog::QFontDialog( QWidget *parent, const char *name,
     d->familyEdit->setFocus();
 }
 
-/*! Destroys the font dialog and frees up its storage. */
+/*!
+  \internal
+ Destroys the font dialog and frees up its storage.
+*/
 
 QFontDialog::~QFontDialog()
 {
@@ -331,8 +337,8 @@ QFontDialog::~QFontDialog()
   If the user clicks OK, the selected font is returned. If the user
   clicks Cancel, the \a initial font is returned.
 
-  The dialog has parent \a parent and is called \a name.
-  \a initial is the initial selected font.
+  The dialog is called \a name, with the parent \a parent.
+  \a initial is the initially selected font.
   If the \a ok parameter is not-null, \e *\a ok is set to TRUE if the
   user clicked OK, and set to FALSE if the user clicked Cancel.
 
@@ -356,7 +362,7 @@ QFontDialog::~QFontDialog()
     myWidget.setFont( QFontDialog::getFont( 0, myWidget.font() ) );
   \endcode
   In this example, if the user clicks OK the font they chose will be
-  used, and if they click cancel the original font is kept.
+  used, and if they click Cancel the original font is used.
 */
 QFont QFontDialog::getFont( bool *ok, const QFont &initial,
 			    QWidget *parent, const char* name)
@@ -372,9 +378,9 @@ QFont QFontDialog::getFont( bool *ok, const QFont &initial,
   If the user clicks OK, the selected font is returned. If the user
   clicks Cancel, the Qt default font is returned.
 
-  The dialog has parent \a parent and is called \a name.
-  If the \a ok parameter is not-null, \e * \a ok is set to TRUE if the user
-  clicked OK, and FALSE if the user clicked Cancel.
+  The dialog is called \a name, with parent \a parent.
+  If the \a ok parameter is not-null, \e *\a ok is set to TRUE if the
+  user clicked OK, and FALSE if the user clicked Cancel.
 
   This static function is less functional than the full QFontDialog
   object, but is convenient and easy to use.
@@ -423,7 +429,8 @@ QFont QFontDialog::getFont( bool *ok, const QFont *def,
 }
 
 /*!
-    Returns a pointer to the "font family" list box.  This is mainly
+    \internal
+    Returns a pointer to the "font family" list box. This is mainly
     useful if you reimplement updateFontFamilies();
 */
 
@@ -433,7 +440,8 @@ QListBox * QFontDialog::familyListBox() const
 }
 
 /*!
-    Returns a pointer to the "font style" list box.  This is mainly
+    \internal
+    Returns a pointer to the "font style" list box. This is mainly
     useful if you reimplement updateFontStyles();
 */
 
@@ -443,8 +451,9 @@ QListBox * QFontDialog::styleListBox() const
 }
 
 /*!
-    Returns a pointer to the "font style" list box.  This is mainly
-    useful if you reimplement updateFontStyles();
+    \internal
+    Returns a pointer to the "scripts combo" list box. This is mainly
+    useful if you reimplement updateScripts();
 */
 
 QComboBox * QFontDialog::scriptCombo() const
@@ -453,7 +462,8 @@ QComboBox * QFontDialog::scriptCombo() const
 }
 
 /*!
-    Returns a pointer to the "font size" list box.  This is mainly
+    \internal
+    Returns a pointer to the "font size" list box. This is mainly
     useful if you reimplement updateFontSizes();
 */
 
@@ -463,6 +473,7 @@ QListBox * QFontDialog::sizeListBox() const
 }
 
 /*!
+    \internal
     This slot is called if the user changes the font size.
     The size is passed in the \a s argument as a \e string.
 */
@@ -481,6 +492,7 @@ void QFontDialog::sizeChanged( const QString &s )
 
 
 /*!
+    \internal
     An event filter to make the Up, Down, PageUp and PageDown keys work
     correctly in the line edits. The source of the event is the object
     \a o and the event is \a e.
@@ -585,7 +597,9 @@ void QListBoxFontText::paint( QPainter *painter )
 
 #endif
 
-/*!  Updates the contents of the "font family" list box.  This
+/*!
+  \internal
+    Updates the contents of the "font family" list box. This
   function can be reimplemented if you have special requirements.
 */
 
@@ -619,7 +633,9 @@ void QFontDialog::updateFamilies()
 #endif
 }
 
-/*!  Updates the contents of the "font script" combo box.  This
+/*!
+    \internal
+    Updates the contents of the "font script" combo box. This
   function can be reimplemented if you have special requirements.
 */
 
@@ -652,7 +668,9 @@ void QFontDialog::updateScripts()
 	d->scriptCombo->insertItem( *it );
 }
 
-/*!  Updates the contents of the "font style" list box.  This
+/*!
+    \internal
+    Updates the contents of the "font style" list box. This
   function can be reimplemented if you have special requirements.
 */
 
@@ -673,7 +691,9 @@ void QFontDialog::updateStyles()
     d->styleList->insertStringList( styles );
 }
 
-/*!  Updates the contents of the "font size" list box.  This
+/*!
+    \internal
+    Updates the contents of the "font size" list box. This
   function can be reimplemented if you have special requirements.
 */
 
@@ -703,7 +723,7 @@ void QFontDialog::updateSizes()
 }
 
 /*!
-
+    \internal
 */
 
 void QFontDialog::familyHighlighted( const QString &s )
@@ -725,7 +745,7 @@ void QFontDialog::familyHighlighted( int i )
 }
 
 /*!
-
+    \internal
 */
 
 void QFontDialog::scriptHighlighted( int index )
@@ -753,7 +773,7 @@ void QFontDialog::scriptHighlighted( const QString &s )
 }
 
 /*!
-
+    \internal
 */
 
 void QFontDialog::styleHighlighted( const QString &s )
@@ -785,7 +805,7 @@ void QFontDialog::styleHighlighted( const QString &s )
 
 
 /*!
-
+    \internal
 */
 
 void QFontDialog::sizeHighlighted( const QString &s )
@@ -802,7 +822,8 @@ void QFontDialog::sizeHighlighted( const QString &s )
 enum match_t { MATCH_NONE=0, MATCH_LAST_RESORT=1, MATCH_DEFAULT=2, MATCH_FAMILY=3 };
 
 /*!
-  Sets the font the QFontDialog highlights to font \a f.
+  \internal
+  Sets the font highlighted in the QFontDialog to font \a f.
 
   \sa font()
 */
@@ -882,13 +903,14 @@ void QFontDialog::setFont( const QFont &f )
     }
 
     if ( d->sizeList->count() != 0 ) {
-	int pSize = f.pointSize();
+	int pSize = QFontInfo(f).pointSize();
 	for ( i = 0 ; i < (int)d->sizeList->count() - 1 ; i++ ) {
 	    QString tmp = d->sizeList->text(i);
 	    if ( tmp.toInt() >= pSize )
 		break;
 	}
 	d->sizeList->setCurrentItem( i );
+	d->sizeEdit->setText( QString::number( pSize ) );
     }
 
     d->strikeout->setChecked( f.strikeOut() );
@@ -898,6 +920,7 @@ void QFontDialog::setFont( const QFont &f )
 }
 
 /*!
+  \internal
   Returns the font which the user has chosen.
 
   \sa setFont()
@@ -928,6 +951,7 @@ void QFontDialog::emitSelectedFont()
 
 /*!
   \fn void QFontDialog::fontSelected( const QFont & font )
+  \internal
 
   This signal is emitted when the user has chosen a font and clicked OK.
   The font that was selected is passed in \a font.
@@ -935,6 +959,7 @@ void QFontDialog::emitSelectedFont()
 
 /*!
   \fn void QFontDialog::fontHighlighted( const QFont & font )
+  \internal
 
   This signal is emitted when the user changed a setting in the dialog.
   The font that is highlighted is passed in \a font.
