@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qcolor_x11.cpp   3.0.2   edited Jan 28 18:53 $
+** $Id:  qt/qcolor_x11.cpp   3.0.5   edited Apr 9 19:14 $
 **
 ** Implementation of QColor class for X11
 **
@@ -146,8 +146,8 @@ static int highest_bit( uint v )
  *****************************************************************************/
 
 /*!
-  Returns the maximum number of colors supported by the underlying window
-  system.
+    Returns the maximum number of colors supported by the underlying
+    window system.
 */
 
 int QColor::maxColors()
@@ -156,11 +156,12 @@ int QColor::maxColors()
 }
 
 /*!
-  Returns the number of color bit planes for the underlying window system.
+    Returns the number of color bit planes for the underlying window
+    system.
 
-  The returned values is equal to the default pixmap depth;
+    The returned value is equal to the default pixmap depth.
 
-  \sa QPixmap::defaultDepth()
+    \sa QPixmap::defaultDepth()
 */
 
 int QColor::numBitPlanes()
@@ -170,9 +171,10 @@ int QColor::numBitPlanes()
 
 
 /*!
-  Internal initialization required for QColor.
-  This function is called from the QApplication constructor.
-  \sa cleanup()
+    Internal initialization required for QColor.
+    This function is called from the QApplication constructor.
+
+    \sa cleanup()
 */
 
 void QColor::initialize()
@@ -295,9 +297,10 @@ void QColor::initialize()
 }
 
 /*!
-  Internal clean up required for QColor.
-  This function is called from the QApplication destructor.
-  \sa initialize()
+    Internal clean up required for QColor.
+    This function is called from the QApplication destructor.
+
+    \sa initialize()
 */
 
 void QColor::cleanup()
@@ -327,16 +330,17 @@ void QColor::cleanup()
  *****************************************************************************/
 
 /*!
-  Allocates the RGB color and returns the pixel value.
+    Allocates the RGB color and returns the pixel value.
 
-  Allocating a color means to obtain a pixel value from the RGB
-  specification.  The pixel value is an index into the global color
-  table, but should be considered an arbitrary platform-dependent value.
+    Allocating a color means to obtain a pixel value from the RGB
+    specification. The pixel value is an index into the global color
+    table, but should be considered to be an arbitrary
+    platform-dependent value.
 
-  The pixel() function calls alloc() if necessary, so in general you
-  don't need to call this function.
+    The pixel() function calls alloc() if necessary, so in general you
+    don't need to call this function.
 
-  \sa enterAllocContext()
+    \sa enterAllocContext()
 */
 
 uint QColor::alloc()
@@ -527,12 +531,17 @@ void QColor::setSystemNamedColor( const QString& name )
 	qWarning( "QColor::setSystemNamedColor: Cannot perform this operation "
 		  "because QApplication does not exist" );
 #endif
+	// set color to invalid
+	*this = QColor();
     } else {
 	XColor col, hw_col;
 	if ( XLookupColor(QPaintDevice::x11AppDisplay(),
 			  QPaintDevice::x11AppColormap(), name.latin1(),
 			  &col, &hw_col) ) {
 	    setRgb( col.red>>8, col.green>>8, col.blue>>8 );
+	} else {
+	    // set color to invalid
+	    *this = QColor();
 	}
     }
 }
@@ -553,16 +562,17 @@ static void init_context_stack()
 
 
 /*!
-  Enters a color allocation context and returns a nonzero unique identifier.
+    Enters a color allocation context and returns a non-zero unique
+    identifier.
 
-  Color allocation contexts are useful for programs that need to
-  allocate many colors and throw them away later, like image viewers.
-  The allocation context functions work for true color displays as
-  well as colormap display, except that QColor::destroyAllocContext()
-  does nothing for true color.
+    Color allocation contexts are useful for programs that need to
+    allocate many colors and throw them away later, like image
+    viewers. The allocation context functions work for true color
+    displays as well as for colormap displays, except that
+    QColor::destroyAllocContext() does nothing for true color.
 
-  Example:
-  \code
+    Example:
+    \code
     QPixmap loadPixmap( QString fileName )
     {
 	static int alloc_context = 0;
@@ -573,40 +583,40 @@ static void init_context_stack()
 	QColor::leaveAllocContext();
 	return pm;
     }
-  \endcode
+    \endcode
 
-  The example code loads a pixmap from file. It frees up all colors
-  that were allocated the last time loadPixmap() was called.
+    The example code loads a pixmap from file. It frees up all colors
+    that were allocated the last time loadPixmap() was called.
 
-  The initial/default context is 0. Qt keeps a list of colors
-  associated with their allocation contexts. You can call
-  destroyAllocContext() to get rid of all colors that were allocated
-  in a specific context.
+    The initial/default context is 0. Qt keeps a list of colors
+    associated with their allocation contexts. You can call
+    destroyAllocContext() to get rid of all colors that were allocated
+    in a specific context.
 
-  Calling enterAllocContext() enters an allocation context. The
-  allocation context lasts until you call leaveAllocContext(). QColor
-  has an internal stack of allocation contexts. Each call to
-  enterAllocContex() must have a corresponding leaveAllocContext().
+    Calling enterAllocContext() enters an allocation context. The
+    allocation context lasts until you call leaveAllocContext().
+    QColor has an internal stack of allocation contexts. Each call to
+    enterAllocContex() must have a corresponding leaveAllocContext().
 
-  \code
-      // context 0 active
-    int c1 = QColor::enterAllocContext();	// enter context c1
-      // context c1 active
-    int c2 = QColor::enterAllocContext();	// enter context c2
-      // context c2 active
-    QColor::leaveAllocContext();		// leave context c2
-      // context c1 active
-    QColor::leaveAllocContext();		// leave context c1
-      // context 0 active
-      // Now, free all colors that were allocated in context c2
+    \code
+	// context 0 active
+    int c1 = QColor::enterAllocContext();    // enter context c1
+	// context c1 active
+    int c2 = QColor::enterAllocContext();    // enter context c2
+	// context c2 active
+    QColor::leaveAllocContext();             // leave context c2
+	// context c1 active
+    QColor::leaveAllocContext();             // leave context c1
+	// context 0 active
+	// Now, free all colors that were allocated in context c2
     QColor::destroyAllocContext( c2 );
-  \endcode
+    \endcode
 
-  You may also want to set the application's color specification.
-  See QApplication::setColorSpec() for more information.
+    You may also want to set the application's color specification.
+    See QApplication::setColorSpec() for more information.
 
-  \sa leaveAllocContext(), currentAllocContext(), destroyAllocContext(),
-  QApplication::setColorSpec()
+    \sa leaveAllocContext(), currentAllocContext(), destroyAllocContext(),
+    QApplication::setColorSpec()
 */
 
 int QColor::enterAllocContext()
@@ -625,11 +635,11 @@ int QColor::enterAllocContext()
 
 
 /*!
-  Leaves a color allocation context.
+    Leaves a color allocation context.
 
-  See enterAllocContext() for a detailed explanation.
+    See enterAllocContext() for a detailed explanation.
 
-  \sa enterAllocContext(), currentAllocContext()
+    \sa enterAllocContext(), currentAllocContext()
 */
 
 void QColor::leaveAllocContext()
@@ -646,11 +656,11 @@ void QColor::leaveAllocContext()
 
 
 /*!
-  Returns the current color allocation context.
+    Returns the current color allocation context.
 
-  The default context is 0.
+    The default context is 0.
 
-  \sa enterAllocContext(), leaveAllocContext()
+    \sa enterAllocContext(), leaveAllocContext()
 */
 
 int QColor::currentAllocContext()
@@ -660,19 +670,17 @@ int QColor::currentAllocContext()
 
 
 /*!
-  Destroys a color allocation context, \e context.
+    Destroys a color allocation context, \e context.
 
-  This function deallocates all colors that were allocated in the
-  specified \a context.
-  If \a context == -1, it frees up all colors
-  that the application has allocated.
-  If \a context == -2, it frees up all colors
-  that the application has allocated, except those in the
-  default context.
+    This function deallocates all colors that were allocated in the
+    specified \a context. If \a context == -1, it frees up all colors
+    that the application has allocated. If \a context == -2, it frees
+    up all colors that the application has allocated, except those in
+    the default context.
 
-  The function does nothing for true color displays.
+    The function does nothing for true color displays.
 
-  \sa enterAllocContext(), alloc()
+    \sa enterAllocContext(), alloc()
 */
 
 void QColor::destroyAllocContext( int context )
