@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qiconset.cpp   3.0.2   edited Jan 25 16:12 $
+** $Id:  qt/qiconset.cpp   3.0.5   edited May 13 14:58 $
 **
 ** Implementation of QIconSet class
 **
@@ -67,7 +67,7 @@ public:
 	bool generated;
     };
 
-    QIconSetPrivate() { instantiated = TRUE; }
+    QIconSetPrivate() {}
     Variant vsmall;
     Variant vlarge;
     Variant smallActive;
@@ -86,7 +86,6 @@ public:
 
     static QSize *large_size;
     static QSize *small_size;
-    static bool instantiated; // detect instantiation of QIconSets
 
 #if defined(Q_FULL_TEMPLATE_INSTANTIATION)
     bool operator==( const QIconSetPrivate& ) const { return FALSE; }
@@ -188,6 +187,8 @@ public:
   the function, or when it is the currently selected item. If the widget
   can be toggled, the "On" mode might be used to draw a different icon.
 
+  \img iconset.png QIconSet
+
   \sa QPixmap QLabel QToolButton QPopupMenu QMainWindow::setUsesBigPixmaps()
       \link guibooks.html#fowler GUI Design Handbook: Iconic Label \endlink
       \link http://cgl.microsoft.com/clipgallerylive/cgl30/eula.asp?nInterface=0
@@ -587,7 +588,7 @@ QPixmap QIconSet::pixmap( Size size, Mode mode, State state ) const
 			p->largeDisabled.pm
 			    = new QPixmap( p->vlarge.pm->width() + 1,
 					   p->vlarge.pm->height() + 1 );
-			QColorGroup dis( QApplication::palette().disabled() );
+			const QColorGroup &dis = QApplication::palette().disabled();
 			p->largeDisabled.pm->fill( dis.background() );
 			QPainter painter( p->largeDisabled.pm );
 			painter.setPen( dis.base() );
@@ -671,7 +672,7 @@ QPixmap QIconSet::pixmap( Size size, Mode mode, State state ) const
 			p->smallDisabled.pm
 			    = new QPixmap( p->vsmall.pm->width() + 1,
 					   p->vsmall.pm->height() + 1);
-			QColorGroup dis( QApplication::palette().disabled() );
+			const QColorGroup &dis = QApplication::palette().disabled();
 			p->smallDisabled.pm->fill( dis.background() );
 			QPainter painter( p->smallDisabled.pm );
 			painter.setPen( dis.base() );
@@ -771,7 +772,7 @@ QPixmap QIconSet::pixmap( Size size, Mode mode, State state ) const
 			p->on_largeDisabled.pm
 			    = new QPixmap( p->on_vlarge.pm->width() + 1,
 					   p->on_vlarge.pm->height() + 1);
-			QColorGroup dis( QApplication::palette().disabled() );
+			const QColorGroup &dis = QApplication::palette().disabled();
 			p->on_largeDisabled.pm->fill( dis.background() );
 			QPainter painter( p->on_largeDisabled.pm );
 			painter.setPen( dis.base() );
@@ -868,7 +869,7 @@ QPixmap QIconSet::pixmap( Size size, Mode mode, State state ) const
 			p->on_smallDisabled.pm
 			    = new QPixmap( p->on_vsmall.pm->width() + 1,
 					   p->on_vsmall.pm->height() + 1);
-			QColorGroup dis( QApplication::palette().disabled() );
+			const QColorGroup &dis = QApplication::palette().disabled();
 			p->on_smallDisabled.pm->fill( dis.background() );
 			QPainter painter( p->on_smallDisabled.pm );
 			painter.setPen( dis.base() );
@@ -1049,7 +1050,6 @@ void QIconSet::detach()
 
 QSize *QIconSetPrivate::small_size = 0;
 QSize *QIconSetPrivate::large_size = 0;
-bool   QIconSetPrivate::instantiated = FALSE;
 
 QCleanupHandler<QSize> qt_iconset_sizes_cleanup;
 
@@ -1061,15 +1061,13 @@ QCleanupHandler<QSize> qt_iconset_sizes_cleanup;
 
   Note that cached icons will not be regenerated, so it is recommended
   that you set the preferred icon sizes before generating any icon sets.
-
+  Also note that the preferred icon sizes will be ignored for icon sets
+  that have been created using both small and large pixmaps.
+  
   \sa iconSize()
 */
 void QIconSet::setIconSize( Size s, const QSize & size )
 {
-    if ( QIconSetPrivate::instantiated )
-	qWarning( "QIconSet: setIconSize() is called after QIconSets have "
-		  "been instantiated." );
-
     if ( !QIconSetPrivate::small_size ) {
 	QIconSetPrivate::small_size = new QSize( 22, 22 ); // default small size
 	QIconSetPrivate::large_size = new QSize( 32, 32 ); // default large size
