@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qpicture.cpp   3.0.2   edited Oct 18 18:30 $
+** $Id:  qt/qpicture.cpp   3.0.5   edited Apr 24 14:07 $
 **
 ** Implementation of QPicture class
 **
@@ -51,51 +51,51 @@
 #endif
 
 /*!
-  \class QPicture qpicture.h
-  \brief The QPicture class is a paint device that records and replays QPainter
-  commands.
+    \class QPicture qpicture.h
+    \brief The QPicture class is a paint device that records and
+    replays QPainter commands.
 
-  \ingroup graphics
-  \ingroup images
-  \ingroup shared
+    \ingroup graphics
+    \ingroup images
+    \ingroup shared
 
-  A picture serializes painter commands to an IO device in a
-  platform-independent format.	A picture created under Windows
-  can be read on a Sun SPARC.
+    A picture serializes painter commands to an IO device in a
+    platform-independent format. For example, a picture created under
+    Windows can be read on a Sun SPARC.
 
-  Pictures are called meta-files on some platforms.
+    Pictures are called meta-files on some platforms.
 
-  Qt pictures use a proprietary binary format.	Unlike native picture
-  (meta-file) formats on many window systems, Qt pictures have no
-  limitations regarding their contents.  Everything that can be painted can
-  also be stored in a picture, e.g. fonts, pixmaps, regions, transformed
-  graphics, etc.
+    Qt pictures use a proprietary binary format. Unlike native picture
+    (meta-file) formats on many window systems, Qt pictures have no
+    limitations regarding their contents. Everything that can be
+    painted can also be stored in a picture, e.g. fonts, pixmaps,
+    regions, transformed graphics, etc.
 
-  QPicture is an \link shclass.html implicitely shared\endlink class.
+    QPicture is an \link shclass.html implicitly shared\endlink class.
 
-  Example of how to record a picture:
-\code
-QPicture  pic;
-QPainter  p;
-p.begin( &pic );               // paint in picture
-p.drawEllipse( 10,20, 80,70 ); // draw an ellipse
-p.end();                       // painting done
-pic.save( "drawing.pic" );     // save picture
-\endcode
+    Example of how to record a picture:
+    \code
+    QPicture  pic;
+    QPainter  p;
+    p.begin( &pic );               // paint in picture
+    p.drawEllipse( 10,20, 80,70 ); // draw an ellipse
+    p.end();                       // painting done
+    pic.save( "drawing.pic" );     // save picture
+    \endcode
 
-  Example of how to replay a picture:
-\code
-QPicture  pic;
-pic.load( "drawing.pic" );     // load picture
-QPainter  p;
-p.begin( &myWidget );          // paint in myWidget
-p.drawPicture( pic );          // draw the picture
-p.end();                       // painting done
-\endcode
+    Example of how to replay a picture:
+    \code
+    QPicture  pic;
+    pic.load( "drawing.pic" );     // load picture
+    QPainter  p;
+    p.begin( &myWidget );          // paint in myWidget
+    p.drawPicture( pic );          // draw the picture
+    p.end();                       // painting done
+    \endcode
 
-Pictures can also be drawn using play(). Some basic data about a
-picture is available, for example, size(), isNull() and
-boundingRect().
+    Pictures can also be drawn using play(). Some basic data about a
+    picture is available, for example, size(), isNull() and
+    boundingRect().
 
 */
 
@@ -106,23 +106,24 @@ static const Q_UINT16 mfhdr_min = 0;		// minor version #
 
 
 /*!
-  Constructs an empty picture.
+    Constructs an empty picture.
 
-  The \a formatVersion parameter may be used to \e create a QPicture that can
-  be read by applications that are compiled with earlier versions of Qt.
-  \list
-  \i \a formatVersion == 1 is binary compatible with Qt 1.x and later.
-  \i \a formatVersion == 2 is binary compatible with Qt 2.0.x and later.
-  \i \a formatVersion == 3 is binary compatible with Qt 2.1.x and later.
-  \i \a formatVersion == 4 is binary compatible with Qt 3.x.
-  \endlist
+    The \a formatVersion parameter may be used to \e create a QPicture
+    that can be read by applications that are compiled with earlier
+    versions of Qt.
+    \list
+    \i \a formatVersion == 1 is binary compatible with Qt 1.x and later.
+    \i \a formatVersion == 2 is binary compatible with Qt 2.0.x and later.
+    \i \a formatVersion == 3 is binary compatible with Qt 2.1.x and later.
+    \i \a formatVersion == 4 is binary compatible with Qt 3.x.
+    \endlist
 
-  Note that the default formatVersion is -1 which signifies the
-  current release, i.e. for Qt 3.0 a formatVersion of 4 is the same as
-  the default formatVersion of -1.
+    Note that the default formatVersion is -1 which signifies the
+    current release, i.e. for Qt 3.0 a formatVersion of 4 is the same
+    as the default formatVersion of -1.
 
-  Reading pictures generated by earlier versions of Qt is supported and
-  needs no special coding; the format is automatically detected.
+    Reading pictures generated by earlier versions of Qt is supported
+    and needs no special coding; the format is automatically detected.
 */
 
 QPicture::QPicture( int formatVersion )
@@ -148,8 +149,7 @@ QPicture::QPicture( int formatVersion )
 }
 
 /*!
-  Constructs a
-  \link shclass.html shallow copy\endlink of \a pic.
+    Constructs a \link shclass.html shallow copy\endlink of \a pic.
 */
 
 QPicture::QPicture( const QPicture &pic )
@@ -160,7 +160,7 @@ QPicture::QPicture( const QPicture &pic )
 }
 
 /*!
-  Destroys the picture.
+    Destroys the picture.
 */
 QPicture::~QPicture()
 {
@@ -170,28 +170,35 @@ QPicture::~QPicture()
 
 
 /*!
-  \fn bool QPicture::isNull() const
-  Returns TRUE if the picture contains no data; otherwise returns FALSE.
+    \fn bool QPicture::isNull() const
+
+    Returns TRUE if the picture contains no data; otherwise returns
+    FALSE.
 */
 
 /*!
-  \fn uint QPicture::size() const
-  Returns the size of the picture data.
-  \sa data()
+    \fn uint QPicture::size() const
+
+    Returns the size of the picture data.
+
+    \sa data()
 */
 
 /*!
-  \fn const char* QPicture::data() const
-  Returns a pointer to the picture data. The pointer is only valid
-  until the next non-const function is called on this picture. The
-  returned pointer is null if the picture contains no data.
-  \sa size(), isNull()
+    \fn const char* QPicture::data() const
+
+    Returns a pointer to the picture data. The pointer is only valid
+    until the next non-const function is called on this picture. The
+    returned pointer is 0 if the picture contains no data.
+
+    \sa size(), isNull()
 */
 
 /*!
-  Sets the picture data directly from \a data and \a size. This function
-  copies the input data.
-  \sa data(), size()
+    Sets the picture data directly from \a data and \a size. This
+    function copies the input data.
+
+    \sa data(), size()
 */
 
 void QPicture::setData( const char* data, uint size )
@@ -205,20 +212,20 @@ void QPicture::setData( const char* data, uint size )
 
 
 /*!
-  Loads a picture from the file specified by \a fileName and returns TRUE
-  if successful; otherwise returns FALSE.
+    Loads a picture from the file specified by \a fileName and returns
+    TRUE if successful; otherwise returns FALSE.
 
-  By default, the file will be interpreted as being in the native
-  QPicture format. Specifying the \a format string is optional and is
-  only needed for importing picture data stored in a different
-  format.
+    By default, the file will be interpreted as being in the native
+    QPicture format. Specifying the \a format string is optional and
+    is only needed for importing picture data stored in a different
+    format.
 
-  Currently, the only external format supported is the
-  \link http://www.w3.org/Graphics/SVG/ W3C SVG \endlink format which requires
-  the \link xml.html Qt XML module \endlink. The corresponding \a format
-  string is "svg".
+    Currently, the only external format supported is the \link
+    http://www.w3.org/Graphics/SVG/ W3C SVG \endlink format which
+    requires the \link xml.html Qt XML module \endlink. The
+    corresponding \a format string is "svg".
 
-  \sa save()
+    \sa save()
 */
 
 bool QPicture::load( const QString &fileName, const char *format )
@@ -230,10 +237,10 @@ bool QPicture::load( const QString &fileName, const char *format )
 }
 
 /*!
-  \overload
+    \overload
 
-  \a dev is the device to use for loading.
- */
+    \a dev is the device to use for loading.
+*/
 
 bool QPicture::load( QIODevice *dev, const char *format )
 {
@@ -260,20 +267,20 @@ bool QPicture::load( QIODevice *dev, const char *format )
 }
 
 /*!
-  Saves a picture to the file specified by \a fileName and returns TRUE
-  if successful; otherwise returns FALSE.
+    Saves a picture to the file specified by \a fileName and returns
+    TRUE if successful; otherwise returns FALSE.
 
-  Specifying the file \a format string is optional. It's not recommended
-  unless you intend to export the picture data for the use in a 3rd party
-  reader. By default the data will be saved in the native QPicture file
-  format.
+    Specifying the file \a format string is optional. It's not
+    recommended unless you intend to export the picture data for
+    use by a third party reader. By default the data will be saved in
+    the native QPicture file format.
 
-  Currently, the only external format supported is the
-  \link http://www.w3.org/Graphics/SVG/ W3C SVG \endlink format which requires
-  the \link xml.html Qt XML module \endlink. The corresponding \a format
-  string is "svg".
+    Currently, the only external format supported is the \link
+    http://www.w3.org/Graphics/SVG/ W3C SVG \endlink format which
+    requires the \link xml.html Qt XML module \endlink. The
+    corresponding \a format string is "svg".
 
-  \sa load()
+    \sa load()
 */
 
 bool QPicture::save( const QString &fileName, const char *format )
@@ -296,10 +303,10 @@ bool QPicture::save( const QString &fileName, const char *format )
 }
 
 /*!
-  \overload
+    \overload
 
-  \a dev is the device to use for saving.
- */
+    \a dev is the device to use for saving.
+*/
 
 bool QPicture::save( QIODevice *dev, const char *format )
 {
@@ -323,8 +330,8 @@ bool QPicture::save( QIODevice *dev, const char *format )
 }
 
 /*!
-  Returns the picture's bounding rectangle or an invalid rectangle if the
-  picture contains no data.
+    Returns the picture's bounding rectangle or an invalid rectangle
+    if the picture contains no data.
 */
 
 QRect QPicture::boundingRect() const
@@ -335,11 +342,11 @@ QRect QPicture::boundingRect() const
 }
 
 /*!
-  Replays the picture using \a painter, and returns TRUE if successful or
-  FALSE if the internal picture data is inconsistent.
+    Replays the picture using \a painter, and returns TRUE if
+    successful; otherwise returns FALSE.
 
-  This function does exactly the same as QPainter::drawPicture() with
-  (x, y) = (0, 0).
+    This function does exactly the same as QPainter::drawPicture()
+    with (x, y) = (0, 0).
 */
 
 bool QPicture::play( QPainter *painter )
@@ -893,14 +900,15 @@ bool QPicture::QPicturePrivate::cmd( int c, QPainter *pt, QPDevCmdParam *p )
 
 
 /*!
-  Internal implementation of the virtual QPaintDevice::metric() function.
+    Internal implementation of the virtual QPaintDevice::metric()
+    function.
 
-  Use the QPaintDeviceMetrics class instead.
+    Use the QPaintDeviceMetrics class instead.
 
-  A picture has the following hard-coded values: dpi=72,
-  numcolors=16777216 and depth=24.
+    A picture has the following hard-coded values: dpi=72,
+    numcolors=16777216 and depth=24.
 
-  \a m is the metric to get.
+    \a m is the metric to get.
 */
 
 int QPicture::metric( int m ) const
@@ -944,12 +952,12 @@ int QPicture::metric( int m ) const
 }
 
 /*!
-  Detaches from shared picture data and makes sure that this picture is the
-  only one referring to the data.
+    Detaches from shared picture data and makes sure that this picture
+    is the only one referring to the data.
 
-  If multiple pictures share common data, this picture makes a copy of the
-  data and detaches itself from the sharing mechanism.	Nothing is
-  done if there is just a single reference.
+    If multiple pictures share common data, this picture makes a copy
+    of the data and detaches itself from the sharing mechanism.
+    Nothing is done if there is just a single reference.
 */
 
 void QPicture::detach()
@@ -959,8 +967,7 @@ void QPicture::detach()
 }
 
 /*!
-  Returns a
-  \link shclass.html deep copy\endlink of the picture.
+    Returns a \link shclass.html deep copy\endlink of the picture.
 */
 
 QPicture QPicture::copy() const
@@ -985,10 +992,10 @@ QPicture QPicture::copy() const
  *****************************************************************************/
 
 /*!
-  Replays the picture \a pic translated by ( \a x, \a y ).
+    Replays the picture \a pic translated by (\a x, \a y).
 
-  This function does exactly the same as QPicture::play() when called with
-  (\a x, \a y) = (0, 0).
+    This function does exactly the same as QPicture::play() when
+    called with (\a x, \a y) = (0, 0).
 */
 
 void QPainter::drawPicture( int x, int y, const QPicture &pic )
@@ -1000,8 +1007,9 @@ void QPainter::drawPicture( int x, int y, const QPicture &pic )
 }
 
 /*!
-  \overload void QPainter::drawPicture( const QPoint &p, const QPicture &pic )
-  Draws picture \a pic at point \a p.
+    \overload void QPainter::drawPicture( const QPoint &p, const QPicture &pic )
+
+    Draws picture \a pic at point \a p.
 */
 
 void QPainter::drawPicture( const QPoint &p, const QPicture &pic )
@@ -1022,9 +1030,8 @@ void QPainter::drawPicture( const QPicture &pic )
 }
 
 /*!
-  Assigns a
-  \link shclass.html shallow copy\endlink
-  of \a p to this picture and returns a reference to this picture.
+    Assigns a \link shclass.html shallow copy\endlink of \a p to this
+    picture and returns a reference to this picture.
 */
 
 QPicture& QPicture::operator= (const QPicture& p)
@@ -1061,6 +1068,10 @@ bool QPicture::QPicturePrivate::checkFormat()
 {
     resetFormat();
 
+    // can't check anything in an empty buffer
+    if ( pictb.size() == 0 )
+	return FALSE;
+
     pictb.open( IO_ReadOnly );			// open buffer device
     QDataStream s;
     s.setDevice( &pictb );			// attach data stream to buffer
@@ -1130,9 +1141,10 @@ bool QPicture::QPicturePrivate::checkFormat()
  *****************************************************************************/
 
 /*!
-  \relates QPicture
+    \relates QPicture
 
-  Writes picture, \a r to the stream \a s and returns a reference to the stream.
+    Writes picture, \a r to the stream \a s and returns a reference to
+    the stream.
 */
 
 QDataStream &operator<<( QDataStream &s, const QPicture &r )
@@ -1144,10 +1156,10 @@ QDataStream &operator<<( QDataStream &s, const QPicture &r )
 }
 
 /*!
-  \relates QPicture
+    \relates QPicture
 
-  Reads a picture from the stream \a s into picture \a r and returns a
-  reference to the stream.
+    Reads a picture from the stream \a s into picture \a r and returns
+    a reference to the stream.
 */
 
 QDataStream &operator>>( QDataStream &s, QPicture &r )
