@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qpngio.cpp   3.0.2   edited Feb 11 06:49 $
+** $Id:  qt/qpngio.cpp   3.0.5   edited Jun 13 04:41 $
 **
 ** Implementation of PNG QImage IOHandler
 **
@@ -391,11 +391,11 @@ bool QPNGImageWriter::writeImage(const QImage& image, int off_x, int off_y)
     return writeImage(image, -1, off_x, off_y);
 }
 
-bool QPNGImageWriter::writeImage(const QImage& image, int quality, int off_x, int off_y)
+bool QPNGImageWriter::writeImage(const QImage& image, int quality_in, int off_x_in, int off_y_in)
 {
     QPoint offset = image.offset();
-    off_x += offset.x();
-    off_y += offset.y();
+    int off_x = off_x_in + offset.x();
+    int off_y = off_y_in + offset.y();
 
     png_structp png_ptr;
     png_infop info_ptr;
@@ -419,6 +419,7 @@ bool QPNGImageWriter::writeImage(const QImage& image, int quality, int off_x, in
 	return FALSE;
     }
 
+    int quality = quality_in;
     if (quality >= 0) {
 	if (quality > 9) {
 #if defined(QT_CHECK_RANGE)
@@ -484,7 +485,7 @@ bool QPNGImageWriter::writeImage(const QImage& image, int quality, int off_x, in
 		copy_trans[i] = trans[i];
 	    png_set_tRNS(png_ptr, info_ptr, copy_trans, num_trans, 0);
 	}
-	delete trans;
+	delete [] trans;
     }
 
     if ( image.hasAlphaBuffer() ) {
@@ -595,28 +596,29 @@ void write_png_image(QImageIO* iio)
 }
 
 /*!
-  \class QPNGImagePacker qpngio.h
-  \ingroup images
-  \ingroup graphics
-  \brief The QPNGImagePacker class creates well-compressed PNG animations.
+    \class QPNGImagePacker qpngio.h
+    \brief The QPNGImagePacker class creates well-compressed PNG animations.
 
-  By using transparency, QPNGImagePacker allows you to build a PNG image
-  from a sequence of QImages.
+    \ingroup images
+    \ingroup graphics
 
-  Images are added using packImage().
+    By using transparency, QPNGImagePacker allows you to build a PNG
+    image from a sequence of QImages.
+
+    Images are added using packImage().
 */
 
 
 /*!
-  Creates an image packer that writes PNG data to IO device \a iod using a
-  \a storage_depth bit encoding (use 8 or 32, depending on the
-  desired quality and compression requirements).
+    Creates an image packer that writes PNG data to IO device \a iod
+    using a \a storage_depth bit encoding (use 8 or 32, depending on
+    the desired quality and compression requirements).
 
     If the image needs to be modified to fit in a lower-resolution
-    result (eg. converting from 32-bit to 8-bit), use the \a
+    result (e.g. converting from 32-bit to 8-bit), use the \a
     conversionflags to specify how you'd prefer this to happen.
 
-  \sa Qt::ImageConversionFlags
+    \sa Qt::ImageConversionFlags
 */
 QPNGImagePacker::QPNGImagePacker(QIODevice* iod, int storage_depth,
 	int conversionflags) :
@@ -628,9 +630,10 @@ QPNGImagePacker::QPNGImagePacker(QIODevice* iod, int storage_depth,
 }
 
 /*!
-  Aligns pixel differences to \a x pixels.  For example, using 8 can
-  improve playback on certain hardware.  Normally the default of 1-pixel
-  alignment (i.e. no alignment) gives better compression and performance.
+    Aligns pixel differences to \a x pixels. For example, using 8 can
+    improve playback on certain hardware. Normally the default of
+    1-pixel alignment (i.e. no alignment) gives better compression and
+    performance.
 */
 void QPNGImagePacker::setPixelAlignment(int x)
 {
@@ -638,8 +641,9 @@ void QPNGImagePacker::setPixelAlignment(int x)
 }
 
 /*!
-  Adds the image \a img to the PNG animation, analyzing the differences
-  between this and the previous image to improve compression.
+    Adds the image \a img to the PNG animation, analyzing the
+    differences between this and the previous image to improve
+    compression.
 */
 bool QPNGImagePacker::packImage(const QImage& img)
 {
@@ -777,8 +781,8 @@ public:
     void row(png_structp png_ptr, png_bytep new_row,
 		png_uint_32 row_num, int pass);
     void end(png_structp png_ptr, png_infop info);
-#ifdef PNG_USER_CHUNK_SUPPORTED
-    int user_chunk(png_structp png_ptr, png_infop info,
+#ifdef PNG_USER_CHUNKS_SUPPORTED
+    int user_chunk(png_structp png_ptr,
 	    png_bytep data, png_uint_32 length);
 #endif
 
@@ -817,7 +821,7 @@ class QPNGFormatType : public QImageFormatType
   This subclass of QImageFormat decodes PNG format images,
   including animated PNGs.
 
-  Animated PNG images are standard PNG images.  The PNG standard
+  Animated PNG images are standard PNG images. The PNG standard
   defines two extension chunks that are useful for animations:
 
   \list
@@ -831,10 +835,10 @@ class QPNGFormatType : public QImageFormatType
 
   The subimages usually contain a offset chunk (oFFs) but need not.
 
-  The first image defines the "screen" size.  Any subsequent image that
+  The first image defines the "screen" size. Any subsequent image that
   doesn't fit is clipped.
 */
-/* ###TODO: decide on this point.  gIFg gives disposal types, so it can be done.
+/* ###TODO: decide on this point. gIFg gives disposal types, so it can be done.
   All images paste (\e not composite, just place all-channel copying)
   over the previous image to produce a subsequent frame.
 */
@@ -849,7 +853,7 @@ class QPNGFormatType : public QImageFormatType
   \ingroup io
 
   This subclass of QImageFormatType recognizes PNG format images, creating
-  a QPNGFormat when required.  An instance of this class is created
+  a QPNGFormat when required. An instance of this class is created
   automatically before any other factories, so you should have no need for
   such objects.
 */
@@ -902,13 +906,13 @@ end_callback(png_structp png_ptr, png_infop info)
     that->end(png_ptr,info);
 }
 
-#ifdef PNG_USER_CHUNK_SUPPORTED
+#ifdef PNG_USER_CHUNKS_SUPPORTED
 static int
-user_chunk_callback(png_structp png_ptr, png_infop info,
-	    png_bytep data, png_uint_32 length)
+user_chunk_callback(png_structp png_ptr,
+         png_unknown_chunkp chunk)
 {
     QPNGFormat* that = (QPNGFormat*)png_get_progressive_ptr(png_ptr);
-    return that->user_chunk(png_ptr,info,data,length);
+    return that->user_chunk(png_ptr,chunk->data,chunk->size);
 }
 #endif
 
@@ -918,7 +922,7 @@ user_chunk_callback(png_structp png_ptr, png_infop info,
 
 
 /*!
-  Constructs a QPNGFormat object.
+    Constructs a QPNGFormat object.
 */
 QPNGFormat::QPNGFormat()
 {
@@ -932,7 +936,7 @@ QPNGFormat::QPNGFormat()
 
 
 /*!
-  Destroys a QPNGFormat object.
+    Destroys a QPNGFormat object.
 */
 QPNGFormat::~QPNGFormat()
 {
@@ -942,9 +946,9 @@ QPNGFormat::~QPNGFormat()
 
 
 /*!
-  This function decodes some data into image changes.
+    This function decodes some data into image changes.
 
-  Returns the number of bytes consumed.
+    Returns the number of bytes consumed.
 */
 int QPNGFormat::decode(QImage& img, QImageConsumer* cons,
 	const uchar* buffer, int length)
@@ -979,8 +983,11 @@ int QPNGFormat::decode(QImage& img, QImageConsumer* cons,
 	png_set_progressive_read_fn(png_ptr, (void *)this,
 	                            info_callback, row_callback, end_callback);
 
-#ifdef PNG_USER_CHUNK_SUPPORTED
-	png_set_user_chunk_fn(png_ptr, user_chunk_callback);
+#ifdef PNG_USER_CHUNKS_SUPPORTED
+	// Can't do this yet. libpng has a crash bug with unknown (user) chunks.
+	// Warwick has sent them a patch.
+	// png_set_read_user_chunk_fn(png_ptr, 0, user_chunk_callback);
+	// png_set_keep_unknown_chunks(png_ptr, 2/*HANDLE_CHUNK_IF_SAFE*/, 0, 0);
 #endif
 
 	if ( state != MovieStart && *buffer != 0211 ) {
@@ -1052,12 +1059,14 @@ void QPNGFormat::end(png_structp png, png_infop info)
 #endif
     QRect r(0,0,image->width(),image->height());
     consumer->frameDone(QPoint(offx,offy),r);
+    consumer->end();
     state = FrameStart;
     unused_data = (int)png->buffer_size; // Since libpng doesn't tell us
 }
 
-#ifdef PNG_USER_CHUNK_SUPPORTED
+#ifdef PNG_USER_CHUNKS_SUPPORTED
 
+/*
 #ifndef QT_NO_IMAGE_TEXT
 static bool skip(png_uint_32& max, png_bytep& data)
 {
@@ -1072,8 +1081,9 @@ static bool skip(png_uint_32& max, png_bytep& data)
     return TRUE;
 }
 #endif
+*/
 
-int QPNGFormat::user_chunk(png_structp png, png_infop,
+int QPNGFormat::user_chunk(png_structp png,
 	    png_bytep data, png_uint_32 length)
 {
 #if 0 // NOT SUPPORTED: experimental PNG animation.
@@ -1098,6 +1108,11 @@ int QPNGFormat::user_chunk(png_structp png, png_infop,
 #endif
 
 #ifndef QT_NO_IMAGE_TEXT
+    /*
+
+    libpng now supports this chunk.
+
+
     if ( 0==qstrcmp((char*)png->chunk_name, "iTXt") && length>=6 ) {
 	const char* keyword = (const char*)data;
 	if ( !skip(length,data) ) return 0;
@@ -1118,6 +1133,7 @@ int QPNGFormat::user_chunk(png_structp png, png_infop,
 	    return 1;
 	}
     }
+    */
 #endif
 
     return 0;
