@@ -112,6 +112,8 @@ QFtp::QFtp()
 	     this, SLOT( dataReadyRead() ) );
     connect( dataSocket, SIGNAL( bytesWritten( int ) ),
 	     this, SLOT( dataBytesWritten( int ) ) );
+    connect( dataSocket, SIGNAL( error( int ) ),
+	     this, SLOT( error( int ) ) );
 }
 
 /*!
@@ -137,6 +139,7 @@ void QFtp::operationListChildren( QNetworkOperation *op )
 {
     op->setState( StInProgress );
     errorInListChildren = FALSE;
+    passiveMode = FALSE;
 #if defined(QFTP_DEBUG)
     qDebug( "QFtp: switch command socket to passive mode!" );
 #endif
@@ -401,6 +404,16 @@ void QFtp::parseDir( const QString &buffer, QUrlInfo &info )
     QDate date = QDate::fromString( dateStr );
     info.setLastModified( QDateTime( date, time ) );
 
+    if ( lst[ 7 ].contains( ":" ) ) {
+	if( info.lastModified() > QDateTime::currentDateTime() ) {
+	    QDateTime dt = info.lastModified();
+	    QDate d = dt.date();
+	    d.setYMD(d.year()-1, d.month(), d.day());
+	    dt.setDate(d);
+	    info.setLastModified(dt);
+	}
+    }
+
     // name
     if ( info.isSymLink() )
 	info.setName( lst[ 8 ].stripWhiteSpace() );
@@ -457,42 +470,52 @@ void QFtp::closed()
 
 void QFtp::readyRead()
 {
-    QCString s;
-    int bytesAvailable = commandSocket->bytesAvailable();
-    s.resize( bytesAvailable + 1 );
-    commandSocket->readBlock( s.data(), bytesAvailable );
-    s[ bytesAvailable ] = '\0';
+    while ( commandSocket->canReadLine() ) {
+	// read line with respect to line continuation
+	static QCString s;
+	QCString line = commandSocket->readLine().utf8();
+	if ( s.isEmpty() )
+	    s = line.left( 3 ) + " "; // add reply code for the first line
+	while ( !(line[0]==s[0] && line[1]==s[1] && line[1]==s[1] && line[3]==' ') ) {
+	    s += line.mid( 4 ); // strip reply codes
+	    if ( !commandSocket->canReadLine() )
+		return;
+	    line = commandSocket->readLine().utf8();
+	}
+	s += line.mid( 4 );
 
-    if ( !url() )
-	return;
+	if ( !url() )
+	    return;
 
-    bool ok = FALSE;
-    int code = s.left( 3 ).toInt( &ok );
-    if ( !ok )
-	return;
+	bool ok = FALSE;
+	int code = s.left( 3 ).toInt( &ok );
+	if ( !ok )
+	    return;
 
 #if defined(QFTP_DEBUG)
-    if ( s.size() < 400 )
-	qDebug( "QFtp: readyRead; %s", s.data() );
+	if ( s.size() < 400 )
+	    qDebug( "QFtp: readyRead; %s", s.data() );
 #endif
 #if defined(QFTP_COMMANDSOCKET_DEBUG)
-    if ( s.size() < 400 )
-	qDebug( "QFtp R: %s", s.data() );
-    else
-	qDebug( "QFtp R: More than 400 bytes received. Not printing." );
+	if ( s.size() < 400 )
+	    qDebug( "QFtp R: %s", s.data() );
+	else
+	    qDebug( "QFtp R: More than 400 bytes received. Not printing." );
 #endif
 
-    if ( s.left( 1 ) == "1" )
-	okButTryLater( code, s );
-    else if ( s.left( 1 ) == "2" )
-	okGoOn( code, s );
-    else if ( s.left( 1 ) == "3" )
-	okButNeedMoreInfo( code, s );
-    else if ( s.left( 1 ) == "4" )
-	errorForNow( code, s );
-    else if ( s.left( 1 ) == "5" )
-	errorForgetIt( code, s );
-    // else strange things happen...
+	if ( s.left( 1 ) == "1" )
+	    okButTryLater( code, s );
+	else if ( s.left( 1 ) == "2" )
+	    okGoOn( code, s );
+	else if ( s.left( 1 ) == "3" )
+	    okButNeedMoreInfo( code, s );
+	else if ( s.left( 1 ) == "4" )
+	    errorForNow( code, s );
+	else if ( s.left( 1 ) == "5" )
+	    errorForgetIt( code, s );
+
+	s = "";
+    }
 }
 
 /*
@@ -527,6 +550,7 @@ void QFtp::okGoOn( int code, const QCString &data )
 		s = s.simplifyWhiteSpace();
 		getTotalSize = s.toInt();
 		operationInProgress()->setState( StInProgress );
+		startGetOnFail = FALSE;
 #if defined(QFTP_COMMANDSOCKET_DEBUG)
 		qDebug( "QFtp S: PASV" );
 #endif
@@ -583,6 +607,12 @@ void QFtp::okGoOn( int code, const QCString &data )
 	QCString s = data;
 	int i = s.find( "(" );
 	int i2 = s.find( ")" );
+	if ( i<0 || i2<0 ) {
+#if defined(QFTP_DEBUG)
+	    qDebug( "QFtp: bad 227 response -- address and port information missing" );
+#endif
+	    break;
+	}
 	s = s.mid( i + 1, i2 - i - 1 );
 	if ( dataSocket->isOpen() )
 	    dataSocket->close();
@@ -643,7 +673,15 @@ void QFtp::okGoOn( int code, const QCString &data )
 	    }
 	}
     } break;
-    case 226: // listing directory (in passive mode) finished and data socket closing
+    case 226:
+	if ( !passiveMode && operationInProgress() && !errorInListChildren
+		&& operationInProgress()->operation() == OpPut )
+	{
+	    // data socket closing
+	    operationInProgress()->setState( StDone );
+	    emit finished( operationInProgress() );
+	}
+	// else just listing directory (in passive mode) finished
 	break;
     case 257: { // mkdir worked
 	if ( operationInProgress() && operationInProgress()->operation() == OpMkDir ) {
@@ -691,8 +729,37 @@ void QFtp::okButNeedMoreInfo( int code, const QCString & )
   Handles error messages from the server.
 */
 
-void QFtp::errorForNow( int, const QCString & )
+void QFtp::errorForNow( int, const QCString &data )
 {
+    QString msg( data.mid( 4 ) );
+    msg = msg.simplifyWhiteSpace();
+    QNetworkOperation *op = operationInProgress();
+    if ( op ) {
+	op->setProtocolDetail( msg );
+	op->setState( StFailed );
+	switch ( op->operation() ) {
+	    case OpListChildren:
+		op->setErrorCode( (int)ErrListChildren );
+		break;
+	    case OpMkDir:
+		op->setErrorCode( (int)ErrMkDir );
+		break;
+	    case OpRemove:
+		op->setErrorCode( (int)ErrRemove );
+		break;
+	    case OpRename:
+		op->setErrorCode( (int)ErrRename );
+		break;
+	    case OpGet:
+		op->setErrorCode( (int)ErrGet );
+		break;
+	    case OpPut:
+		op->setErrorCode( (int)ErrPut );
+		break;
+	}
+	emit finished( op );
+    }
+    reinitCommandSocket();
 }
 
 /*
@@ -751,6 +818,10 @@ void QFtp::errorForgetIt( int code, const QCString &data )
 	reinitCommandSocket();
 	emit finished( op );
     } break;
+    default: {
+	// other permanent failure (we don't know the details)
+	errorForNow( code, data );
+    } break;
     }
 }
 
@@ -830,20 +901,24 @@ void QFtp::dataConnected()
 
 void QFtp::dataClosed()
 {
+    if ( operationInProgress() ) {
+	if ( operationInProgress()->operation() == OpPut )
+	    return;
+
+	passiveMode = FALSE;
+	if ( !errorInListChildren ) {
+	    operationInProgress()->setState( StDone );
+	    emit finished( operationInProgress() );
+	}
+    }
+
     // switch back to ASCII mode
 #if defined(QFTP_COMMANDSOCKET_DEBUG)
-	qDebug( "QFtp S: TYPE A" );
+    qDebug( "QFtp S: TYPE A" );
 #endif
     commandSocket->writeBlock( "TYPE A\r\n", 8 );
 
-    passiveMode = FALSE;
-
     reinitCommandSocket();
-
-    if ( !errorInListChildren && operationInProgress() ) {
-	operationInProgress()->setState( StDone );
-	emit finished( operationInProgress() );
-    }
 }
 
 /*!
