@@ -48,23 +48,24 @@ static QGLFormat* qgl_default_overlay_format = 0;
 static QCleanupHandler<QGLFormat> qgl_cleanup_format;
 
 
-/*! \class QGL qgl.h
+/*!
+    \class QGL qgl.h
+    \brief The QGL class is a namespace for miscellaneous identifiers
+    in the Qt OpenGL module.
+
+    \module OpenGL
     \ingroup graphics
     \ingroup images
-  \brief The QGL class is a namespace for miscellaneous identifiers
-  in the Qt OpenGL module.
 
-  \module OpenGL
+    Normally you can ignore this class. QGLWidget and the other
+    OpenGL<sup>*</sup> module classes inherit it, so when you make your
+    own QGLWidget subclass you can use the identifiers in the QGL
+    namespace without qualification.
 
-  Normally you can ignore this class. QGLWidget and the other
-  OpenGL<sup>*</sup> module classes inherit it, so when you make your
-  own QGLWidget subclass you can use the identifiers in the QGL
-  namespace without qualification.
-
-  However, you may occasionally find yourself in situations where you
-  need to refer to these identifiers from outside the QGL namespace's
-  scope, e.g. in static functions. In such cases, simply write e.g. \c
-  QGL::DoubleBuffer instead of just \c DoubleBuffer.
+    However, you may occasionally find yourself in situations where you
+    need to refer to these identifiers from outside the QGL namespace's
+    scope, e.g. in static functions. In such cases, simply write e.g. \c
+    QGL::DoubleBuffer instead of just \c DoubleBuffer.
 
     <sup>*</sup> OpenGL is a trademark of Silicon Graphics, Inc. in the
     United States and other countries.
@@ -726,6 +727,8 @@ QGLContext* QGLContext::currentCtx = 0;
   If you're using double buffering you can swap the screen contents with
   the off-screen buffer using swapBuffers().
 
+  Please note that QGLContext is not thread safe.
+
     <sup>*</sup> OpenGL is a trademark of Silicon Graphics, Inc. in the
     United States and other countries.
 
@@ -1937,7 +1940,7 @@ just like any other Qt widget, except that it opens an OpenGL display
 buffer where you can use the OpenGL API to render the contents.
 
 The Qt OpenGL module is implemented as a platform-independent
-Qt/C++ wrapper around the platform-dependent GLX and WGL C APIs. The
+Qt/C++ wrapper around the platform-dependent GLX, WGL, or AGL C APIs. The
 functionality provided is very similar to Mark Kilgard's GLUT library,
 but with much more non-OpenGL-specific GUI functionality, i.e. the whole
 Qt API.
@@ -1949,7 +1952,9 @@ OpenGL headers and libraries are installed on your system, and if so, it
 will include the Qt OpenGL module in the Qt library. (If your OpenGL
 headers or libraries are placed in a non-standard directory, you may need
 to change the SYSCONF_CXXFLAGS_OPENGL and/or SYSCONF_LFLAGS_OPENGL in the
-config file for your system).
+config file for your system). Some configurations require threading to
+be enabled for OpenGL, so if OpenGL is not detected, try \c{configure
+-thread}.
 
 When you install Qt for Windows, the Qt OpenGL module is always included.
 
