@@ -40,9 +40,16 @@
 #include <qregexp.h>
 #include <qdatetime.h>
 #include <qpointarray.h>
+#undef DEBUG // the PostgreSQL headers redefines this
 #include <postgres.h>
 #include <libpq/libpq-fs.h>
+#if defined(Q_CC_MSVC)
+#pragma warning(disable: 4273) // '_errno' : inconsistent dll linkage.  dllexport assumed
+#endif
 #include <catalog/pg_type.h>
+#if defined(Q_CC_MSVC)
+#pragma warning(default: 4273)
+#endif
 #ifndef Q_WS_MAC
 #include <utils/geo_decls.h>
 #endif
@@ -51,9 +58,10 @@
 class QPSQLPrivate
 {
 public:
-  QPSQLPrivate():connection(0), result(0){}
+  QPSQLPrivate():connection(0), result(0), isUtf8(FALSE) {}
     PGconn	*connection;
     PGresult	*result;
+    bool        isUtf8;
 };
 
 QSqlError qMakeError( const QString& err, int type, const QPSQLPrivate* p )
@@ -93,6 +101,11 @@ QVariant::Type qDecodePSQLType( int t )
     // Postgres 6.x datetime workaround.
     // DATETIMEOID == TIMESTAMPOID (only the names have changed)
     case DATETIMEOID    :
+#endif
+#ifdef TIMESTAMPTZOID
+    // Postgres 7.2 workaround
+    // TIMESTAMPTZOID == TIMESTAMPOID == DATETIMEOID
+    case TIMESTAMPTZOID :
 #endif
 	type = QVariant::DateTime;
 	break;
@@ -232,7 +245,12 @@ QTime qTimeFromDouble( double tm )
 QVariant QPSQLResult::data( int i )
 {
     QVariant::Type type = qFieldType( d, i );
-    QString val( PQgetvalue( d->result, at(), i ) );
+    QString val;
+    if ( d->isUtf8 ) {
+	val = QString::fromUtf8( PQgetvalue( d->result, at(), i ) );
+    } else {
+	val = QString::fromLocal8Bit( PQgetvalue( d->result, at(), i ) );
+    }
     switch ( type ) {
     case QVariant::Bool:
 	{
@@ -240,7 +258,11 @@ QVariant QPSQLResult::data( int i )
 	    return ( b );
 	}
     case QVariant::String:
-	return QVariant( val );
+	if ( PQgetisnull( d->result, at(), i ) ) {
+	    return QVariant( QString() );
+	} else {
+	    return QVariant( val );
+	}
     case QVariant::Int:
 	return QVariant( val.toInt() );
     case QVariant::Double:
@@ -370,7 +392,11 @@ bool QPSQLResult::reset ( const QString& query )
     setAt( QSql::BeforeFirst );
     if ( d->result )
 	PQclear( d->result );
-    d->result = PQexec( d->connection, (const char*)query );
+    if ( d->isUtf8 ) {
+	d->result = PQexec( d->connection, query.utf8().data() );
+    } else {
+	d->result = PQexec( d->connection, query.local8Bit().data() );
+    }
     int status =  PQresultStatus( d->result );
     if ( status == PGRES_COMMAND_OK || status == PGRES_TUPLES_OK ) {
 	setSelect( (status == PGRES_TUPLES_OK) );
@@ -389,7 +415,7 @@ int QPSQLResult::size()
 
 int QPSQLResult::numRowsAffected()
 {
-    return QString( PQcmdTuples( d->result ) ).toInt();
+    return isSelect() ? size() : QString( PQcmdTuples( d->result ) ).toInt();
 }
 
 ///////////////////////////////////////////////////////////////////
@@ -438,7 +464,7 @@ static QPSQLDriver::Protocol getPSQLVersion( PGconn* connection )
     int status =  PQresultStatus( result );
     if ( status == PGRES_COMMAND_OK || status == PGRES_TUPLES_OK ) {
 	QString val( PQgetvalue( result, 0, 0 ) );
-	PQclear( result );	
+	PQclear( result );
 	QRegExp rx( "(\\d*)\\.(\\d*)" );
 	rx.setMinimal ( TRUE ); // enforce non-greedy RegExp
         if ( rx.search( val ) != -1 ) {
@@ -479,6 +505,7 @@ bool QPSQLDriver::open( const QString & db,
 			const QString & host,
 			int port )
 {
+    int status;
     if ( isOpen() )
 	close();
     QString connectString;
@@ -499,6 +526,15 @@ bool QPSQLDriver::open( const QString & db,
 	return FALSE;
     }
 
+// Unicode support is only working if the client library has been compiled with
+// multibyte support.
+#ifdef MULTIBYTE
+    status = PQsetClientEncoding( d->connection, "UNICODE" );
+    if ( status == 0 ) {
+	d->isUtf8 = TRUE;
+    }
+#endif
+
     pro = getPSQLVersion( d->connection );
 
     PGresult* dateResult = 0;
@@ -512,7 +548,7 @@ bool QPSQLDriver::open( const QString & db,
 	break;
     }
 #ifdef QT_CHECK_RANGE
-    int status =  PQresultStatus( dateResult );
+    status =  PQresultStatus( dateResult );
     if ( status != PGRES_COMMAND_OK )
 	qWarning( PQerrorMessage( d->connection ) );
 #endif
@@ -847,6 +883,12 @@ QString QPSQLDriver::formatValue( const QSqlField* field,
 	    else
 		r = "FALSE";
 	    break;
+	case QVariant::ByteArray:
+#ifdef QT_CHECKRANGE
+	    // bytearrays cannot be inserted directly into postgresql
+	    qWarning( "QPSQLDriver::formatValue: cannot format ByteArray." );
+#endif
+	    break;
 	default:
 	    r = QSqlDriver::formatValue( field );
 	    break;
