@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qmotifplusstyle.cpp   3.0.2   edited Jan 11 14:48 $
+** $Id:  qt/qmotifplusstyle.cpp   3.0.5   edited May 27 22:19 $
 **
 ** Implementation of QMotifPlusStyle class
 **
@@ -140,7 +140,7 @@ static void drawMotifPlusShade(QPainter *p,
 /*!
   Constructs a QMotifPlusStyle
 
-  If \a hoveringHighlight is FALSE (the default), then the style will not
+  If \a hoveringHighlight is TRUE (the default), then the style will not
   highlight push buttons, checkboxes, radiobuttons, comboboxes, scrollbars
   or sliders.
  */
@@ -152,7 +152,6 @@ QMotifPlusStyle::QMotifPlusStyle(bool hoveringHighlight) : QMotifStyle(TRUE)
         singleton->ref++;
 
     useHoveringHighlight = hoveringHighlight;
-    useHoveringHighlight = TRUE;
 }
 
 /*! \reimp */
