@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qmotifstyle.cpp   3.0.2   edited Feb 14 13:47 $
+** $Id:  qt/qmotifstyle.cpp   3.0.5   edited Jun 12 16:42 $
 **
 ** Implementation of Motif-like style class
 **
@@ -42,7 +42,6 @@
 #include "qpopupmenu.h"
 #include "qapplication.h"
 #include "qpainter.h"
-#include "qpalette.h"
 #include "qdrawutil.h"
 #include "qpixmap.h"
 #include "qpalette.h"
@@ -800,21 +799,23 @@ void QMotifStyle::drawControl( ControlElement element,
     case CE_TabBarTab:
 	{
 #ifndef QT_NO_TABBAR
-	    if ( !widget || !widget->parentWidget() )
+	    if ( !widget || !widget->parentWidget() || !opt.tab() )
 		break;
 
 	    const QTabBar * tb = (const QTabBar *) widget;
+	    const QTab * t = opt.tab();
+	
 	    int dfw = pixelMetric( PM_DefaultFrameWidth, tb );
 	    bool selected = flags & Style_Selected;
 	    int o =  dfw > 1 ? 1 : 0;
-	    bool lastIsCurrent = FALSE;
-
-	    if ( styleHint( SH_TabBar_Alignment, tb ) == AlignRight &&
-		 tb->currentTab() == tb->indexOf(tb->count()-1) )
-		lastIsCurrent = TRUE;
+	    bool lastTab = FALSE;
 
 	    QRect r2( r );
-	    if ( tb->shape()  == QTabBar::RoundedAbove ) {
+	    if ( tb->shape() == QTabBar::RoundedAbove ) {
+		if ( styleHint( SH_TabBar_Alignment, tb ) == AlignRight &&
+		     tb->indexOf( t->identifier() ) == tb->count()-1 )
+		    lastTab = TRUE;
+
 		if ( o ) {
 		    p->setPen( tb->colorGroup().light() );
 		    p->drawLine( r2.left(), r2.bottom(), r2.right(), r2.bottom() );
@@ -862,10 +863,13 @@ void QMotifStyle::drawControl( ControlElement element,
 		    p->drawPoint( r2.right() - 1, r2.top() + 1 );
 		    p->drawLine( r2.right(), r2.top() + 2, r2.right(),
 				 r2.bottom() -
-				 (selected ? (lastIsCurrent ? 0:1):1+o));
+				 (selected ? (lastTab ? 0:1):1+o));
 		    p->drawPoint( r2.right() - 1, r2.top() + 1 );
 		}
 	    } else if ( tb->shape()  == QTabBar::RoundedBelow ) {
+		if ( styleHint( SH_TabBar_Alignment, tb ) == AlignLeft &&
+		     tb->indexOf( t->identifier() ) == tb->count()-1 )
+		    lastTab = TRUE;
 		if ( selected ) {
 		    p->fillRect( QRect( r2.left()+1, r2.top(), r2.width()-3, 1),
 				 tb->palette().active().brush( QColorGroup::Background ));
@@ -876,6 +880,9 @@ void QMotifStyle::drawControl( ControlElement element,
 		} else {
 		    p->setPen( tb->colorGroup().dark() );
 		    p->drawLine( r2.left(), r2.top(), r2.right(), r2.top() );
+		    p->drawLine( r2.left() + 1, r2.top() + 1,
+				 r2.right() - (lastTab ? 0 : 2),
+				 r2.top() + 1 );
 		    r2.setRect( r2.left() + 2, r2.top(),
 				r2.width() - 4, r2.height() - 2 );
 		}
@@ -896,8 +903,10 @@ void QMotifStyle::drawControl( ControlElement element,
 		}
 
 		p->setPen( tb->colorGroup().light() );
-		p->drawLine( r2.left(), r2.top(),
+		p->drawLine( r2.left(), r2.top() + (selected ? 0 : 2),
 			     r2.left(), r2.bottom() - 2 );
+		p->drawLine( r2.left() + 1, r2.top() + (selected ? 0 : 2),
+			     r2.left() + 1, r2.bottom() - 3 );
 
 	    } else {
 		QCommonStyle::drawControl( element, p, widget, r, cg, flags, opt );
@@ -1332,11 +1341,15 @@ void QMotifStyle::drawComplexControl( ComplexControl control,
 
 		    // paint stuff in the magical area
 		    QListView* v = item->listView();
-		    int lh = QMAX( p->fontMetrics().height() + 2 * v->itemMargin(),
-				   QApplication::globalStrut().height() );
-		    if ( lh % 2 > 0 )
-			lh++;
 		    while ( child && y < r.height() ) {
+			int lh;
+			if ( !item->multiLinesEnabled() )
+			    lh = child ? child->height() : 0;
+			else
+			    lh = p->fontMetrics().height() + 2 * v->itemMargin();
+			lh = QMAX( lh, QApplication::globalStrut().height() );
+			if ( lh % 2 > 0 )
+			    lh++;
 			linebot = y + lh/2;
 			if ( (child->isExpandable() || child->childCount()) &&
 			     (child->height() > 0) ) {
@@ -1371,8 +1384,11 @@ void QMotifStyle::drawComplexControl( ComplexControl control,
 			child = child->nextSibling();
 		    }
 
-		    if ( child ) // there's a child, so move linebot to edge of rectangle
+		    // Expand line height to edge of rectangle if there's a
+		    // child, and it's visible
+		    if ( child && (child->height() > 0) ) { 
 			linebot = r.height();
+		    }
 
 		    if ( linetop < linebot ) {
 			dotlines[c++] = QPoint( bx, linetop );
@@ -1504,7 +1520,7 @@ QRect QMotifStyle::querySubControlMetrics( ComplexControl control,
 	    bs.setHeight( widget->height()/2 );
 	    if ( bs.height() < 8 )
 		bs.setHeight( 8 );
-	    bs.setWidth( bs.height() * 8 / 5 ); // 1.6 -approximate golden mean
+	    bs.setWidth( QMIN( bs.height() * 8 / 5, widget->width() / 4 ) ); // 1.6 -approximate golden mean
 	    bs = bs.expandedTo( QApplication::globalStrut() );
 	    int y = 0;
 	    int x, lx, rx;
@@ -1772,7 +1788,7 @@ QRect QMotifStyle::subRect( SubRect r, const QWidget *widget ) const
     switch ( r ) {
     case SR_SliderFocusRect:
 	rect = QCommonStyle::subRect( r, widget );
-	rect.addCoords( 2, 2, -2, -3 ); // ### fix this!
+	rect.addCoords( 2, 2, -2, -2 );
 	break;
 
     case SR_ComboBoxFocusRect:
