@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qwindowsstyle.cpp   3.0.2   edited Jan 16 12:23 $
+** $Id:  qt/qwindowsstyle.cpp   3.0.5   edited Jun 27 11:34 $
 **
 ** Implementation of Windows-like style class
 **
@@ -470,20 +470,18 @@ void QWindowsStyle::drawControl( ControlElement element,
 #ifndef QT_NO_TABBAR
     case CE_TabBarTab:
 	{
-	    if ( !widget || !widget->parentWidget() )
+	    if ( !widget || !widget->parentWidget() || !opt.tab() )
 		break;
 
 	    const QTabBar * tb = (const QTabBar *) widget;
-	    bool lastIsCurrent = FALSE;
+	    const QTab * t = opt.tab();
 	    bool selected = flags & Style_Selected;
-
-	    if ( styleHint( SH_TabBar_Alignment, tb ) == AlignRight &&
-		 tb->currentTab() == tb->indexOf(tb->count()-1) )
-		lastIsCurrent = TRUE;
-
+	    bool lastTab = (tb->indexOf( t->identifier() ) == tb->count()-1) ?
+			   TRUE : FALSE;
 	    QRect r2( r );
 	    if ( tb->shape()  == QTabBar::RoundedAbove ) {
 		p->setPen( cg.midlight() );
+
 		p->drawLine( r2.left(), r2.bottom(), r2.right(), r2.bottom() );
 		p->setPen( cg.light() );
 		p->drawLine( r2.left(), r2.bottom()-1, r2.right(), r2.bottom()-1 );
@@ -531,39 +529,55 @@ void QWindowsStyle::drawControl( ControlElement element,
 		p->drawPoint( x2, r2.top() + 1 );
 		x2++;
 		p->drawLine( x2, r2.top() + 2, x2, r2.bottom() -
-			     (selected ? (lastIsCurrent ? 0:1) :2));
+			     (selected ? (lastTab ? 0:1) :2));
 	    } else if ( tb->shape() == QTabBar::RoundedBelow ) {
+		bool rightAligned = styleHint( SH_TabBar_Alignment, tb ) == AlignRight;
+		bool firstTab = tb->indexOf( t->identifier() ) == 0;
 		if ( selected ) {
 		    p->fillRect( QRect( r2.left()+1, r2.top(), r2.width()-3, 1),
-				 tb->palette().active().brush( QColorGroup::Background ));
+				 cg.brush( QColorGroup::Background ));
 		    p->setPen( cg.background() );
 		    p->drawLine( r2.left()+1, r2.top(), r2.left()+1, r2.bottom()-2 );
 		    p->setPen( cg.dark() );
 		} else {
+ 		    p->setPen( cg.shadow() );
+		    p->drawLine( r2.left() +
+				 (rightAligned && firstTab ? 0 : 1),
+				 r2.top() + 1,
+				 r2.right() - (lastTab ? 0 : 2),
+				 r2.top() + 1 );
+
+		    if ( rightAligned && lastTab )
+			p->drawPoint( r2.right(), r2.top() );
 		    p->setPen( cg.dark() );
-		    p->drawLine( r2.left(), r2.top(), r2.right(), r2.top() );
+		    p->drawLine( r2.left(), r2.top(), r2.right() - 1,
+				 r2.top() );
 		    r2.setRect( r2.left() + 2, r2.top(),
-			       r2.width() - 4, r2.height() - 2 );
+				r2.width() - 4, r2.height() - 2 );
 		}
 
-		p->drawLine( r2.right() - 1, r2.top(),
+		p->drawLine( r2.right() - 1, r2.top() + (selected ? 0: 2),
 			     r2.right() - 1, r2.bottom() - 2 );
 		p->drawPoint( r2.right() - 2, r2.bottom() - 2 );
 		p->drawLine( r2.right() - 2, r2.bottom() - 1,
 			     r2.left() + 1, r2.bottom() - 1 );
-		p->drawPoint( r2.left() + 1, r2.bottom() - 2 );
+
+		p->setPen( cg.midlight() );
+ 		p->drawLine( r2.left() + 1, r2.bottom() - 2,
+ 			     r2.left() + 1, r2.top() + (selected ? 0 : 2) );
 
 		p->setPen( cg.shadow() );
-		p->drawLine( r2.right(), r2.top(),
+		p->drawLine( r2.right(),
+			     r2.top() + (lastTab && rightAligned &&
+					 selected) ? 0 : 1,
 			     r2.right(), r2.bottom() - 1 );
 		p->drawPoint( r2.right() - 1, r2.bottom() - 1 );
 		p->drawLine( r2.right() - 1, r2.bottom(),
 			     r2.left() + 2, r2.bottom() );
 
 		p->setPen( cg.light() );
-		p->drawLine( r2.left(), r2.top(),
+		p->drawLine( r2.left(), r2.top() + (selected ? 0 : 2),
 			     r2.left(), r2.bottom() - 2 );
-
 	    } else {
 		QCommonStyle::drawControl(element, p, widget, r, cg, flags, opt);
 	    }
@@ -857,9 +871,9 @@ int QWindowsStyle::pixelMetric(PixelMetric metric, const QWidget *widget) const
 #if defined(Q_WS_WIN)
     case PM_TitleBarHeight:
 	if ( widget && ( widget->testWFlags( WStyle_Tool ) || widget->inherits( "QDockWindow" ) ) ) {
-	    ret = GetSystemMetrics( SM_CYSMCAPTION );
+	    ret = GetSystemMetrics( SM_CYSMCAPTION ) - 1; // MS always use one less than they say
 	} else {
-	    ret = GetSystemMetrics( SM_CYCAPTION );
+	    ret = GetSystemMetrics( SM_CYCAPTION ) - 1;
 	}
 	break;
 #endif
@@ -895,15 +909,14 @@ QSize QWindowsStyle::sizeFromContents( ContentsType contents,
 	    sz = QCommonStyle::sizeFromContents(contents, widget, contentsSize, opt);
 	    int w = sz.width(), h = sz.height();
 
-	    if (button->isDefault() || button->autoDefault()) {
-		if (w < 85 && ! button->pixmap())
-		    w = 80;
-		if (h < 25)
-		    h = 25;
-	    } else {
-		if (h < 23)
-		    h = 23;
-	    }
+	    int defwidth = 0;
+	    if (button->isDefault() || button->autoDefault())
+		defwidth = 2*pixelMetric( PM_ButtonDefaultIndicator, widget );
+
+	    if (w < 80+defwidth && !button->pixmap())
+		w = 80+defwidth;
+	    if (h < 23+defwidth)
+		h = 23+defwidth;
 
 	    sz = QSize(w, h);
 #endif
@@ -944,10 +957,14 @@ QSize QWindowsStyle::sizeFromContents( ContentsType contents,
 			     2*windowsItemFrame);
 	    }
 
-	    if (! mi->text().isNull() && mi->text().find('\t') >= 0)
-		w += windowsTabSpacing;
-	    else if (mi->popup())
+	    if (! mi->text().isNull() && mi->text().find('\t') >= 0) {
+		if ( use2000style )
+		    w += 20;
+		else
+		    w += windowsTabSpacing;
+	    } else if (mi->popup()) {
 		w += 2*windowsArrowHMargin;
+	    }
 
 	    if (use2000style) {
 		if (checkable && maxpmw < 20)
@@ -956,8 +973,6 @@ QSize QWindowsStyle::sizeFromContents( ContentsType contents,
 		if (checkable && maxpmw < windowsCheckMarkWidth)
 		    w += windowsCheckMarkWidth - maxpmw;
 	    }
-	    if (maxpmw)
-		w += maxpmw + 6;
 	    if (checkable || maxpmw > 0)
 		w += windowsCheckMarkHMargin;
 	    if (use2000style)
@@ -1011,16 +1026,16 @@ static const char * const qt_maximize_xpm[]={
 "# c #000000",
 ". c None",
 "............",
+".#########..",
+".#########..",
+".#.......#..",
+".#.......#..",
+".#.......#..",
+".#.......#..",
+".#.......#..",
+".#.......#..",
+".#########..",
 "............",
-".##########.",
-".##########.",
-".#........#.",
-".#........#.",
-".#........#.",
-".#........#.",
-".#........#.",
-".#........#.",
-".##########.",
 "............"};
 
 
@@ -1035,46 +1050,27 @@ static const char * const qt_minimize_xpm[] = {
 "............",
 "............",
 "............",
-"...######...",
-"...######...",
 "............",
+"..######....",
+"..######....",
 "............",
 "............"};
 
-#if 0 // ### not used???
-static const char * const qt_normalize_xpm[] = {
-"12 12 2 1",
-"# c #000000",
-". c None",
-"............",
-"...#######..",
-"...#######..",
-"...#.....#..",
-".#######.#..",
-".#######.#..",
-".#.....#.#..",
-".#.....###..",
-".#.....#....",
-".#.....#....",
-".#######....",
-"............"};
-#endif
-
 static const char * const qt_normalizeup_xpm[] = {
 "12 12 2 1",
 "# c #000000",
 ". c None",
 "............",
-"...#######..",
-"...#######..",
-"...#.....#..",
-".#######.#..",
-".#######.#..",
-".#.....#.#..",
-".#.....###..",
-".#.....#....",
-".#.....#....",
-".#######....",
+"....######..",
+"....######..",
+"....#....#..",
+"..######.#..",
+"..######.#..",
+"..#....###..",
+"..#....#....",
+"..#....#....",
+"..######....",
+"............",
 "............"};
 
 
@@ -1116,13 +1112,13 @@ static const char * dock_window_close_xpm[] = {
 "8 8 2 1",
 "# c #000000",
 ". c None",
-"##....##",
+"........",
 ".##..##.",
 "..####..",
 "...##...",
 "..####..",
 ".##..##.",
-"##....##",
+"........",
 "........"};
 
 // Message box icons, from page 210 of the Windows style guide.
@@ -1315,7 +1311,7 @@ void QWindowsStyle::drawComplexControl( ComplexControl ctrl, QPainter *p,
 
 		int y = r.y();
 		int c;
-		int dotoffset;
+		int dotoffset = 0;
 		QPointArray dotlines;
 		if ( subActive == SC_All && sub == SC_ListViewExpand ) {
 		    c = 2;
@@ -1339,11 +1335,15 @@ void QWindowsStyle::drawComplexControl( ComplexControl ctrl, QPainter *p,
 
 		    // paint stuff in the magical area
 		    QListView* v = item->listView();
-		    int lh = QMAX( p->fontMetrics().height() + 2 * v->itemMargin(),
-				   QApplication::globalStrut().height() );
-		    if ( lh % 2 > 0 )
-			lh++;
 		    while ( child && y < r.height() ) {
+		        int lh;
+		        if ( !item->multiLinesEnabled() )
+			    lh = child ? child->height() : 0;
+		        else
+			    lh = p->fontMetrics().height() + 2 * v->itemMargin();
+		        lh = QMAX( lh, QApplication::globalStrut().height() );
+		        if ( lh % 2 > 0 )
+			    lh++;
 			linebot = y + lh/2;
 			if ( (child->isExpandable() || child->childCount()) &&
 			     (child->height() > 0) ) {
@@ -1358,7 +1358,7 @@ void QWindowsStyle::drawComplexControl( ComplexControl ctrl, QPainter *p,
 			    // dotlinery
 			    p->setPen( cg.mid() );
 			    dotlines[c++] = QPoint( bx, linetop );
-			    dotlines[c++] = QPoint( bx, linebot - 5 );
+			    dotlines[c++] = QPoint( bx, linebot - 4 );
 			    dotlines[c++] = QPoint( bx + 5, linebot );
 			    dotlines[c++] = QPoint( r.width(), linebot );
 			    linetop = linebot + 5;
@@ -1372,15 +1372,18 @@ void QWindowsStyle::drawComplexControl( ComplexControl ctrl, QPainter *p,
 			child = child->nextSibling();
 		    }
 
-		    if ( child ) // there's a child, so move linebot to edge of rectangle
+		    // Expand line height to edge of rectangle if there's a
+		    // child, and it's visible
+		    if ( child && (child->height() > 0) ) { 
 			linebot = r.height();
+		    }
 
 		    if ( linetop < linebot ) {
 			dotlines[c++] = QPoint( bx, linetop );
 			dotlines[c++] = QPoint( bx, linebot );
 		    }
 		}
-		p->setPen( cg.dark() );
+		p->setPen( cg.text() );
 
 		static QBitmap *verticalLine = 0, *horizontalLine = 0;
 		static QCleanupHandler<QBitmap> qlv_cleanup_bitmap;
@@ -1582,17 +1585,17 @@ void QWindowsStyle::drawComplexControl( ComplexControl ctrl, QPainter *p,
 
 		p->fillRect( x, y, wi, he, cg.brush( QColorGroup::Background ) );
 
+		if ( sl->hasFocus() ) {
+		    QRect re = subRect( SR_SliderFocusRect, sl );
+		    drawPrimitive( PE_FocusRect, p, re, cg );
+		}
+
 		if ( (tickAbove && tickBelow) || (!tickAbove && !tickBelow) ) {
 		    qDrawWinButton( p, QRect(x,y,wi,he), cg, FALSE,
 				    &cg.brush( QColorGroup::Button ) );
 		    return;
 		}
 
-		if ( sl->hasFocus() ) {
-		    QRect re = subRect( SR_SliderFocusRect, sl );
-		    drawPrimitive( PE_FocusRect, p, re, cg );
-		}
-
 		QSliderDirection dir;
 
 		if ( orient == Horizontal )
