@@ -86,13 +86,17 @@ static QString getFmtString( const QString& f, const QTime* dt = 0, const QDate*
 
     if ( dt ) {
 	if ( f == "h" ) {
-	    if ( ( am_pm ) && ( dt->hour() >= 12 ) )
+	    if ( ( am_pm ) && ( dt->hour() > 12 ) )
 		buf = QString::number( dt->hour() - 12 );
+	    else if ( ( am_pm ) && ( dt->hour() == 0 ) )
+		buf = "12";
 	    else
 		buf = QString::number( dt->hour() );
         } else if ( f == "hh" ) {
-	    if ( ( am_pm ) && ( dt->hour() >= 12 ) )
+	    if ( ( am_pm ) && ( dt->hour() > 12 ) )
 		buf = QString::number( dt->hour() - 12 ).rightJustify( 2, '0', TRUE );
+	    else if ( ( am_pm ) && ( dt->hour() == 0 ) )
+		buf = "12";
 	    else
 		buf = QString::number( dt->hour() ).rightJustify( 2, '0', TRUE );
 	} else if ( f == "m" ) {
@@ -248,7 +252,8 @@ static QString fmtDateTime( const QString& f, const QTime* dt = 0, const QDate*
     \enum Qt::DateFormat
 
     \value TextDate (default) Qt format
-    \value ISODate ISO 8601 format
+    \value ISODate ISO 8601 extended format (YYYY-MM-DD, or with time,
+    YYYY-MM-DDTHH:MM:SS)
     \value LocalDate locale dependent format
 */
 
@@ -489,7 +494,7 @@ QString QDate::longMonthName( int month )
 	    return QString::fromLocal8Bit( buf );
     }
 #endif
-    
+
     return QString::null;
 }
 
@@ -607,7 +612,7 @@ QString QDate::longDayName( int weekday )
   format of the string.
 
   If \a f is Qt::TextDate, the string format is "Sat May 20 1995" (using
-  the shortDayName() and shortMonthName() functions to generate the string).
+  the shortDayName() and shortMonthName() functions to generate the string which are locale specific).
 
   If \a f is Qt::ISODate, the string format corresponds to the ISO
   8601 specification for representations of dates, which is YYYY-MM-DD
@@ -828,7 +833,7 @@ QDate QDate::addMonths( int nmonths ) const
     }
 
     QDate tmp(y,m,1);
-    
+
     if( d > tmp.daysInMonth() )
 	d = tmp.daysInMonth();
 
@@ -1238,8 +1243,8 @@ int QTime::msec() const
   second before midnight would be "23:59:59".
 
   If \a f is Qt::ISODate, the string format corresponds to the ISO
-  8601 specification for representations of dates, which is also
-  HH:MM:SS.
+  8601 extended specification for representations of dates, which is
+  also HH:MM:SS.
 
   If \a f is Qt::LocalDate, the string format depends on the locale
   settings of the system.
@@ -1826,8 +1831,8 @@ void QDateTime::setTime_t( uint secsSince1Jan1970UTC )
   QTime::toString() to generate the string).
 
   If \a f is Qt::ISODate, the string format corresponds to the ISO
-  8601 specification for representations of dates and times, which is
-  YYYY-MM-DDTHH:MM:SS.
+  8601 extended specification for representations of dates and times,
+  which is YYYY-MM-DDTHH:MM:SS.
 
   If \a f is Qt::LocalDate, the string format depends on the locale
   settings of the system.
