@@ -1,13 +1,13 @@
 /****************************************************************************
-** $Id:  qt/qlibrary.cpp   3.0.3   edited Jan 30 23:03 $
+** $Id$
 **
 ** Implementation of QLibrary class
 **
 ** Created : 2000-01-01
 **
-** Copyright (C) 2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
 **
-** This file is part of the kernel module of the Qt GUI Toolkit.
+** This file is part of the tools module of the Qt GUI Toolkit.
 **
 ** This file may be distributed under the terms of the Q Public License
 ** as defined by Trolltech AS of Norway and appearing in the file
@@ -51,6 +51,10 @@
 # endif
 #endif
 
+#if defined(QT_DEBUG_COMPONENT)
+#include <qfile.h>
+#endif
+
 // KAI C++ has at the moment problems with unloading the Qt plugins. So don't
 // unload them as a workaround for now.
 #if defined(Q_CC_KAI) || defined(Q_OS_MAC) || defined(Q_OS_HPUX)
@@ -260,7 +264,7 @@ bool QLibrary::unload()
 #if !defined(QT_NO_LIBRARY_UNLOAD)
     if ( !d->freeLibrary() ) {
 #if defined(QT_DEBUG_COMPONENT)
-	qWarning( "%s could not be unloaded.", library().latin1() );
+	qWarning( "%s could not be unloaded.", (const char*) QFile::encodeName(library()) );
 #endif
 	return FALSE;
 #else
@@ -270,7 +274,7 @@ bool QLibrary::unload()
     }
 
 #if defined(QT_DEBUG_COMPONENT) && QT_DEBUG_COMPONENT == 2
-    qWarning( "%s has been unloaded.", library().latin1() );
+    qWarning( "%s has been unloaded.", (const char*) QFile::encodeName(library()) );
 #endif
 
     d->pHnd = 0;
