@@ -314,7 +314,7 @@ public:
 
 };
 
-class QComboBoxPopupItem : public QCustomMenuItem 
+class QComboBoxPopupItem : public QCustomMenuItem
 {
     QListBoxItem *li;
 public:
@@ -322,7 +322,7 @@ public:
     virtual bool fullSpan() const { return TRUE; }
     virtual void paint( QPainter*, const QColorGroup&, bool, bool, int, int, int, int);
     virtual QSize sizeHint() { return QSize(li->width(li->listBox()), QMAX(25, li->height(li->listBox()))); }
-};    
+};
 void QComboBoxPopupItem::paint( QPainter* p, const QColorGroup&, bool,
 				bool, int x, int y, int, int)
 {
@@ -350,7 +350,7 @@ public:
     void setListBox( QListBox *l ) { lBox = l ; usingLBox = TRUE;
 				l->setMouseTracking( TRUE );}
 
-    void setPopupMenu( QComboBoxPopup * pm, bool isPopup=TRUE ) 
+    void setPopupMenu( QComboBoxPopup * pm, bool isPopup=TRUE )
 	{ pop = pm; if(isPopup) usingLBox = FALSE; }
 
     int		current;
@@ -442,7 +442,7 @@ QComboBox::QComboBox( QWidget *parent, const char *name )
     : QWidget( parent, name, WResizeNoErase )
 {
     d = new QComboBoxData( this );
-    if ( !style().styleHint(QStyle::SH_ComboBox_Popup) || 
+    if ( !style().styleHint(QStyle::SH_ComboBox_Popup) ||
 	 style().styleHint(QStyle::SH_GUIStyle) == Qt::MotifStyle) {
 	setUpListBox();
     } else {
@@ -490,6 +490,8 @@ QComboBox::QComboBox( bool rw, QWidget *parent, const char *name )
     d = new QComboBoxData( this );
     setUpListBox();
 
+    if(d->popup() && style().styleHint(QStyle::SH_ComboBox_Popup))
+	d->popup()->setItemChecked(d->current, FALSE);
     d->current = 0;
     d->maxCount = INT_MAX;
     setSizeLimit(10);
@@ -773,9 +775,9 @@ void QComboBox::removeItem( int index )
 	    d->updateLinedGeometry();
 	}
 	else {
-	    if ( d->usingListBox() )
+	    if ( d->usingListBox() ) {
 		d->current = d->listBox()->currentItem();
-	    else {
+	    } else {
 		if (d->current > count()-1 && d->current > 0)
 		    d->current--;
 	    }
@@ -808,6 +810,8 @@ void QComboBox::clear()
 	d->popup()->clear();
     }
 
+    if(d->popup() && style().styleHint(QStyle::SH_ComboBox_Popup))
+	d->popup()->setItemChecked(d->current, FALSE);
     d->current = 0;
     if ( d->ed ) {
 	d->ed->setText( QString::fromLatin1("") );
@@ -953,13 +957,16 @@ void QComboBox::setCurrentItem( int index )
     if ( d->usingListBox() && !( listBox()->item(index) && listBox()->item(index)->isSelectable() ) )
 	return;
 
+    if(d->popup() && style().styleHint(QStyle::SH_ComboBox_Popup))
+	d->popup()->setItemChecked(d->current, FALSE);
     d->current = index;
     d->completeAt = 0;
     if ( d->ed ) {
 	d->ed->setText( text( index ) );
 	d->updateLinedGeometry();
     }
-    if ( d->poppedUp && d->usingListBox() && d->listBox() ) {
+    // ### We want to keep ListBox's currentItem in sync, even if NOT popuped...
+    if ( d->usingListBox() && d->listBox() ) {
 	d->listBox()->setCurrentItem( index );
     } else {
 	internalHighlight( index );
@@ -992,53 +999,28 @@ QSize QComboBox::sizeHint() const
 	return d->sizeHint;
 
     constPolish();
-    int i, w, h;
+    int i, w;
     QFontMetrics fm = fontMetrics();
 
     int maxW = count() ? 18 : 7 * fm.width(QChar('x')) + 18;
-    int maxH = QMAX( fm.lineSpacing() + 2, 12 );
+    int maxH = QMAX( fm.lineSpacing(), 14 ) + 2;
 
-    for( i = 0; i < count(); i++ ) {
-	if ( d->usingListBox() ) {
-	    w = d->listBox()->item( i )->width( d->listBox() );
-	    h = d->listBox()->item( i )->height( d->listBox() );
-	}
-	else {
-	    h = d->popup()->itemHeight( i );
-	    w = d->popup()->sizeHint().width() - 2* d->popup()->frameWidth();
-	}
+    if ( !d->usingListBox() ) {
+	w = d->popup()->sizeHint().width() - 2* d->popup()->frameWidth();
 	if ( w > maxW )
 	    maxW = w;
-	if ( h > maxH )
-	    maxH = h;
+    } else {
+	for( i = 0; i < count(); i++ ) {
+	    w = d->listBox()->item( i )->width( d->listBox() );
+	    if ( w > maxW )
+		maxW = w;
+	}
     }
 
-
     d->sizeHint = (style().sizeFromContents(QStyle::CT_ComboBox, this,
 					    QSize(maxW, maxH)).
 		   expandedTo(QApplication::globalStrut()));
 
-//     if ( maxH <= 20 && style() == WindowsStyle || parentWidget() &&
-// 	 ( parentWidget()->inherits( "QToolBar" ) ||
-// 	   parentWidget()->inherits( "QDialog" ) && d->ed ) )
-// 	maxH = 12;
-
-//     int sw, sh;
-//     if ( d->usingListBox() ) {
-// 	sw = 4 + 4 + maxW;
-// 	sh = 5 + 5 + maxH;
-// 	QRect cr = style().comboButtonRect( 0, 0, sw, sh );
-// 	sw += sw - cr.width();
-// 	sw += sh - cr.height();
-//     } else {
-// 	//hardcoded values for motif 1.x style
-// 	int extraW = 20+5;
-// 	sw = 4 + 4 + maxW + extraW;
-// 	sh = 5 + 5 + maxH;
-//     }
-
-//     d->sizeHint = QSize( sw, sh ).expandedTo( QApplication::globalStrut() );
-
     return d->sizeHint;
 }
 
@@ -1053,6 +1035,8 @@ void QComboBox::internalActivate( int index )
 {
     if ( d->current != index ) {
 	if ( !d->usingListBox() || listBox()->item( index )->isSelectable() ) {
+	    if(d->popup() && style().styleHint(QStyle::SH_ComboBox_Popup))
+		d->popup()->setItemChecked(d->current, FALSE);
 	    d->current = index;
 	    currentChanged();
 	}
@@ -1106,10 +1090,14 @@ void QComboBox::internalClickTimeout()
 void QComboBox::setPalette( const QPalette &palette )
 {
     QWidget::setPalette( palette );
-    if ( d->usingListBox() )
-	d->listBox()->setPalette( palette );
-    else
-	d->popup()->setPalette( palette );
+    if( d ) {
+	if ( d->usingListBox() ) {
+	    if(d->listBox())
+		d->listBox()->setPalette( palette );
+	} else if(d->popup()) {
+	    d->popup()->setPalette( palette );
+	}
+    }
 }
 
 /*!
@@ -1280,7 +1268,15 @@ void QComboBox::mousePressEvent( QMouseEvent *e )
 	d->discardNextMousePress = FALSE;
 	return;
     }
-    if ( count() ) {
+    QRect arrowRect = style().querySubControlMetrics( QStyle::CC_ComboBox, this,
+						      QStyle::SC_ComboBoxArrow);
+    arrowRect = QStyle::visualRect(arrowRect, this);
+
+    // Correction for motif style, where arrow is smaller
+    // and thus has a rect that doesn't fit the button.
+    arrowRect.setHeight( QMAX(  height() - (2 * arrowRect.y()), arrowRect.height() ) );
+
+    if ( count() && ( !editable() || arrowRect.contains( e->pos() ) ) ) {
 	d->arrowPressed = FALSE;
 
 	if ( d->usingListBox() ) {
@@ -1288,9 +1284,6 @@ void QComboBox::mousePressEvent( QMouseEvent *e )
 	    qApp->sendEvent( listBox(), e ); // trigger the listbox's autoscroll
 	    listBox()->blockSignals( FALSE );
 	    popup();
-	    QRect arrowRect = style().querySubControlMetrics( QStyle::CC_ComboBox, this,
-							      QStyle::SC_ComboBoxArrow);
-	    arrowRect = QStyle::visualRect(arrowRect, this);
 	    if ( arrowRect.contains( e->pos() ) ) {
 		d->arrowPressed = TRUE;
 		d->arrowDown    = TRUE;
@@ -1374,7 +1367,7 @@ void QComboBox::keyPressEvent( QKeyEvent *e )
     c = currentItem();
     if ( !text( c ).isNull() )
 	emit activated( text( c ) );
-    emit highlighted( c );
+    //emit highlighted( c ); ###VOHI when doing this, we emit the signal twice, previously in setCurrentItem
     emit activated( c );
 }
 
@@ -1417,18 +1410,20 @@ void QComboBox::popup()
     if( !d->usingListBox() || style().styleHint(QStyle::SH_ComboBox_Popup) ) {
 	if(d->usingListBox()) {
 	    if(!d->popup()) {
-		d->setPopupMenu( new QComboBoxPopup( this, "in-combo" ), FALSE );
-		d->popup()->setFont( font() );
-		connect( d->popup(), SIGNAL(activated(int)),
-			 SLOT(internalActivate(int)) );
-		connect( d->popup(), SIGNAL(highlighted(int)),
-			 SLOT(internalHighlight(int)) );
+		QComboBoxPopup *p = new QComboBoxPopup( this, "in-combo" );
+		d->setPopupMenu( p, FALSE );
+		p->setFont( font() );
+		connect( p, SIGNAL(activated(int)), SLOT(internalActivate(int)) );
+		connect( p, SIGNAL(highlighted(int)), SLOT(internalHighlight(int)) );
+		p->setFrameStyle( QFrame::Panel | QFrame::Raised );
 	    }
 	    d->popup()->clear();
-	    for(unsigned int i = 0; i < d->listBox()->count(); i++) 
+	    for(unsigned int i = 0; i < d->listBox()->count(); i++)
 		d->popup()->insertItem(new QComboBoxPopupItem(d->listBox()->item(i)), i, i);
 	}
 	d->popup()->installEventFilter( this );
+	if(d->popup() && style().styleHint(QStyle::SH_ComboBox_Popup))
+	    d->popup()->setItemChecked(this->d->current, TRUE);
 	d->popup()->popup( mapToGlobal( QPoint(0,0) ), this->d->current );
     } else {
 	// Send all listbox events to eventFilter():
@@ -1691,7 +1686,7 @@ bool QComboBox::eventFilter( QObject *object, QEvent *event )
 	default:
 	    break;
 	}
-    } else if ( (!d->usingListBox() || style().styleHint(QStyle::SH_ComboBox_Popup)) && 
+    } else if ( (!d->usingListBox() || style().styleHint(QStyle::SH_ComboBox_Popup)) &&
 		object == d->popup() ) {
 	QMouseEvent *e = (QMouseEvent*)event;
 	switch ( event->type() ) {
@@ -1802,11 +1797,8 @@ void QComboBox::returnPressed()
 {
     QString s( d->ed->text() );
 
-    if ( s.isEmpty() ) {
-	d->ed->setText( text( currentItem() ) );
-	d->ed->selectAll();
+    if ( s.isEmpty() )
 	return;
-    }
 
     int c = 0;
     bool doInsert = TRUE;
@@ -1928,6 +1920,7 @@ void QComboBox::setListBox( QListBox * newListBox )
     newListBox->reparent( this, WType_Popup, QPoint(0,0), FALSE );
     d->setListBox( newListBox );
     d->listBox()->setFont( font() );
+    d->listBox()->setPalette( palette() );
     d->listBox()->setVScrollBarMode(QScrollView::AlwaysOff);
     d->listBox()->setHScrollBarMode(QScrollView::AlwaysOff);
     d->listBox()->setFrameStyle( QFrame::Box | QFrame::Plain );
@@ -2055,6 +2048,7 @@ void QComboBox::setUpListBox()
 {
     d->setListBox( new QListBox( this, "in-combo", WType_Popup ) );
     d->listBox()->setFont( font() );
+    d->listBox()->setPalette( palette() );
     d->listBox()->setVScrollBarMode( QListBox::AlwaysOff );
     d->listBox()->setHScrollBarMode( QListBox::AlwaysOff );
     d->listBox()->setFrameStyle( QFrame::Box | QFrame::Plain );
