@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qdockarea.cpp   3.0.2   edited Jan 29 15:19 $
+** $Id:  qt/qdockarea.cpp   3.0.5   edited Jun 14 15:56 $
 **
 ** Implementation of the QDockArea class
 **
@@ -344,12 +344,14 @@ int QDockAreaLayout::layoutItems( const QRect &rect, bool testonly )
     QValueList<DockData> lastLine;
     int tbstrut = -1;
     int maxsize = size_extent( rect.size(), orientation() );
+    int visibleWindows = 0;
 
     // go through all widgets in the dock
     while ( ( dw = it.current() ) != 0 ) {
 	++it;
 	if ( !dw->isVisibleTo( parentWidget ) )
 	    continue;
+	++visibleWindows;
 	// find position for the widget: This is the maximum of the
 	// end of the previous widget and the offset of the widget. If
 	// the position + the width of the widget dosn't fit into the
@@ -417,7 +419,7 @@ int QDockAreaLayout::layoutItems( const QRect &rect, bool testonly )
 	if ( !dw->isVisibleTo( parentWidget ) )
 	    continue;
 	hadResizable = hadResizable || dw->isResizeEnabled();
-	dw->updateSplitterVisibility( dockWindows->count() > 1 ); //!dw->area()->isLastDockWindow( dw ) );
+	dw->updateSplitterVisibility( visibleWindows > 1 ); //!dw->area()->isLastDockWindow( dw ) );
     }
     return sectionpos + linestrut;
 }
@@ -598,7 +600,15 @@ void QDockArea::moveDockWindow( QDockWindow *w, int index )
 	setSizePolicy( QSizePolicy( orientation() == Horizontal ? QSizePolicy::Expanding : QSizePolicy::Minimum,
 				    orientation() == Vertical ? QSizePolicy::Expanding : QSizePolicy::Minimum ) );
 	dockWindows->append( w );
+    } else {
+        if ( w->parent() != this )
+	    w->reparent( this, QPoint( 0, 0 ), TRUE );
+        if ( index == - 1 ) {
+	    dockWindows->removeRef( w );
+	    dockWindows->append( w );
+        }
     }
+
     w->dockArea = this;
     w->curPlace = QDockWindow::InDock;
     w->updateGui();
@@ -661,8 +671,12 @@ void QDockArea::moveDockWindow( QDockWindow *w, const QPoint &p, const QRect &r,
 	else
 	    mse = QMAX( QMAX( dw->fixedExtent().height(), dw->height() ), mse );
     }
-    if ( !hasResizable && w->isResizeEnabled() )
-	mse = 200;
+    if ( !hasResizable && w->isResizeEnabled() ) {
+	if ( orientation() != Qt::Horizontal )
+	    mse = QMAX( w->fixedExtent().width(), mse );
+	else
+	    mse = QMAX( w->fixedExtent().height(), mse );
+    }
 
     QDockWindow *dockWindow = 0;
     int dockWindowIndex = findDockWindow( w );
@@ -879,8 +893,6 @@ void QDockArea::removeDockWindow( QDockWindow *w, bool makeFloating, bool swap,
     QPtrList<QDockWindow> lineStarts = layout->lineStarts();
     if ( fixNewLines && lineStarts.findRef( dockWindow ) != -1 && i < (int)dockWindows->count() )
 	dockWindows->at( i )->setNewLine( TRUE );
-    w->setFixedExtentWidth( -1 );
-    w->setFixedExtentHeight( -1 );
     if ( makeFloating )
 	dockWindow->reparent( topLevelWidget(), WType_Dialog | WStyle_Customize | WStyle_NoBorder, QPoint( 0, 0 ), FALSE );
     if ( swap )
@@ -1109,8 +1121,12 @@ int QDockArea::maxSpace( int hint, QDockWindow *dw )
 	return dw->height();
     }
 
-    QDockWindow *w = dockWindows->at( index + 1 );
-    if ( !w->isResizeEnabled() ) {
+    QDockWindow *w = 0;
+    int i = 0;
+    do
+	w = dockWindows->at( index + (++i) );
+    while ( i + 1 < (int)dockWindows->count() && ( !w || w->isHidden() ) );
+    if ( !w || !w->isResizeEnabled() || i >= (int)dockWindows->count() ) {
 	if ( orientation() == Horizontal )
 	    return dw->width();
 	return dw->height();
