@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qdockwindow.cpp   3.0.2   edited Feb 8 18:14 $
+** $Id:  qt/qdockwindow.cpp   3.0.5   edited May 22 18:27 $
 **
 ** Implementation of the QDockWindow class
 **
@@ -544,7 +544,7 @@ QDockWindowTitleBar::QDockWindowTitleBar( QDockWindow *dw )
     setWFlags( getWFlags() | WStyle_Tool );
     ctrlDown = FALSE;
     setMouseTracking( TRUE );
-    setFixedHeight( style().pixelMetric( QStyle::PM_TitleBarHeight, dockWindow ) );
+    setFixedHeight( style().pixelMetric( QStyle::PM_TitleBarHeight, this ) );
     connect( this, SIGNAL(doClose()), dockWindow, SLOT(hide()) );
 }
 
@@ -578,18 +578,29 @@ void QDockWindowTitleBar::mousePressEvent( QMouseEvent *e )
 
     ctrlDown = ( e->state() & ControlButton ) == ControlButton;
     oldFocus = qApp->focusWidget();
+// setFocus activates the window, which deactivates the main window
+// not what we want, and not required anyway on Windows
+#ifndef Q_WS_WIN
     setFocus();
+#endif
+
     e->ignore();
     if ( e->button() != LeftButton )
 	return;
     if ( e->y() < 3 )
 	return;
     e->accept();
+    bool oldPressed = mousePressed;
     mousePressed = TRUE;
     hadDblClick = FALSE;
     offset = e->pos();
     dockWindow->startRectDraw( mapToGlobal( e->pos() ), !opaque );
-    grabMouse();
+// grabMouse resets the Windows mouse press count, so we never receive a double click on Windows
+// not required on Windows, and did work on X11, too, but no problem there in the first place
+#ifndef Q_WS_WIN
+    if(!oldPressed && dockWindow->opaqueMoving())
+	grabMouse();
+#endif
 }
 
 void QDockWindowTitleBar::mouseMoveEvent( QMouseEvent *e )
@@ -615,7 +626,8 @@ void QDockWindowTitleBar::mouseReleaseEvent( QMouseEvent *e )
     qApp->removeEventFilter( dockWindow );
     if ( oldFocus )
 	oldFocus->setFocus();
-    releaseMouse();
+    if(dockWindow->opaqueMoving())
+	releaseMouse();
     if ( !mousePressed )
 	return;
     dockWindow->endRectDraw( !opaque );
@@ -889,6 +901,8 @@ QDockWindow::QDockWindow( Place p, QWidget *parent, const char *name, WFlags f )
     setFrameStyle( QFrame::StyledPanel | QFrame::Raised );
     setLineWidth( 2 );
 
+    if ( parent )
+	parent->installEventFilter( this );
     QWidget *mw = parent;
     if ( parent && parent->inherits( "QDockArea" ) ) {
 	QDockArea* da = (QDockArea*)parent;
@@ -897,8 +911,22 @@ QDockWindow::QDockWindow( Place p, QWidget *parent, const char *name, WFlags f )
 	mw = da->parentWidget();
     }
     if ( mw && mw->inherits( "QMainWindow" ) ) {
-	if ( place() == InDock )
-	    ( (QMainWindow*)mw )->addDockWindow( this, Qt::DockTop );
+	if ( place() == InDock ) {
+	    Dock myDock = Qt::DockTop;
+	    // make sure we put the window in the correct dock.
+	    if ( dockArea ) {
+		QMainWindow *mainw = (QMainWindow*)mw;
+		// I'm not checking if it matches the top because I've
+		// done the assignment to it above.
+		if ( dockArea == mainw->leftDock() )
+		    myDock = Qt::DockLeft;
+		else if ( dockArea == mainw->rightDock() )
+		    myDock = Qt::DockRight;
+		else if ( dockArea == mainw->bottomDock() )
+		    myDock = Qt::DockBottom;
+	    }
+	    ( (QMainWindow*)mw )->addDockWindow( this, myDock );
+	}
 	moveEnabled = ((QMainWindow*)mw)->dockWindowsMovable();
 	opaque = ((QMainWindow*)mw)->opaqueMoving();
     }
@@ -955,15 +983,10 @@ void QDockWindow::resizeEvent( QResizeEvent *e )
 }
 
 
-void QDockWindow::swapRect( QRect &r, Qt::Orientation o, const QPoint &offset, QDockArea *area )
+void QDockWindow::swapRect( QRect &r, Qt::Orientation o, const QPoint &offset, QDockArea * )
 {
-    if ( !area ) {
-	r.setSize( size() );
-	return;
-    }
-
     QBoxLayout *bl = boxLayout()->createTmpCopy();
-    bl->setDirection( o == Vertical ? QBoxLayout::LeftToRight : QBoxLayout::TopToBottom );
+    bl->setDirection( o == Horizontal ? QBoxLayout::LeftToRight : QBoxLayout::TopToBottom );
     bl->activate();
     r.setSize( bl->sizeHint() );
     bl->data = 0;
@@ -1019,7 +1042,7 @@ void QDockWindow::handleMove( const QPoint &pos, const QPoint &gp, bool drawRect
 	w = 0;
     currRect.moveBy( pos.x(), pos.y() );
     if ( !w || !w->inherits( "QDockArea" ) ) {
-	if ( startOrientation != Horizontal )
+	if ( startOrientation != Horizontal && inherits( "QToolBar" ) )
 	    swapRect( currRect, Horizontal, startOffset, (QDockArea*)w );
 	if ( drawRect ) {
 	    unclippedPainter->setPen( QPen( gray, 3 ) );
@@ -1047,8 +1070,12 @@ void QDockWindow::handleMove( const QPoint &pos, const QPoint &gp, bool drawRect
 
     state = InDock;
     QDockArea *area = (QDockArea*)w;
-    if ( startOrientation != ( area ? area->orientation() : Horizontal ) )
-	    swapRect( currRect, orientation(), startOffset, area );
+    Orientation o = ( area ? area->orientation() :
+		      ( boxLayout()->direction() == QBoxLayout::LeftToRight ||
+			boxLayout()->direction() == QBoxLayout::RightToLeft ?
+			Horizontal : Vertical ) );
+    if ( startOrientation != o )
+	    swapRect( currRect, o, startOffset, area );
     if ( drawRect ) {
 	unclippedPainter->setPen( QPen( gray, 1 ) );
 	QRect dr(currRect);
@@ -1188,7 +1215,8 @@ void QDockWindow::updatePosition( const QPoint &globalPos )
 		return;
 	    delete (QDockArea::DockWindowData*)dockWindowData;
 	    dockWindowData = dockArea->dockWindowData( this );
-	    dockArea->removeDockWindow( this, TRUE, startOrientation != Horizontal );
+	    dockArea->removeDockWindow( this, TRUE,
+					startOrientation != Horizontal && inherits( "QToolBar" ) );
 	}
 	dockArea = 0;
 	move( currRect.topLeft() );
@@ -1394,7 +1422,7 @@ void QDockWindow::setHorizontallyStretchable( bool b )
 /*! \property QDockWindow::verticallyStretchable
   \brief whether the dock window is vertically stretchable.
 
-  A dock window is horizontally stretchable if you call
+  A dock window is vertically stretchable if you call
   setVerticallyStretchable(TRUE) or setResizeEnabled(TRUE).
   \sa setResizeEnabled()
 */
@@ -1436,9 +1464,13 @@ bool QDockWindow::isStretchable() const
 
 Qt::Orientation QDockWindow::orientation() const
 {
-    if ( !dockArea || dockArea->orientation() == Horizontal )
+    if ( dockArea )
+	return dockArea->orientation();
+    if ( inherits( "QToolBar" ) )
 	return Horizontal;
-    return Vertical;
+    return ( ((QDockWindow*)this)->boxLayout()->direction() == QBoxLayout::LeftToRight ||
+	     ((QDockWindow*)this)->boxLayout()->direction() == QBoxLayout::RightToLeft ?
+	     Horizontal : Vertical );
 }
 
 int QDockWindow::offset() const
@@ -1529,7 +1561,8 @@ QBoxLayout *QDockWindow::boxLayout()
 QSize QDockWindow::sizeHint() const
 {
     QSize sh( QFrame::sizeHint() );
-    sh = sh.expandedTo( fixedExtent() );
+    if ( place() == InDock )
+	sh = sh.expandedTo( fixedExtent() );
     sh = sh.expandedTo( QSize( 16, 16 ) );
     if ( area() ) {
 	if ( area()->orientation() == Horizontal && !vHandleRight->isVisible() )
@@ -1546,7 +1579,8 @@ QSize QDockWindow::sizeHint() const
 QSize QDockWindow::minimumSize() const
 {
     QSize ms( QFrame::minimumSize() );
-    ms = ms.expandedTo( fixedExtent() );
+    if ( place() == InDock )
+	ms = ms.expandedTo( fixedExtent() );
     ms = ms.expandedTo( QSize( 16, 16 ) );
     if ( area() ) {
 	if ( area()->orientation() == Horizontal && !vHandleRight->isVisible() )
@@ -1563,7 +1597,8 @@ QSize QDockWindow::minimumSize() const
 QSize QDockWindow::minimumSizeHint() const
 {
     QSize msh( QFrame::minimumSize() );
-    msh = msh.expandedTo( fixedExtent() );
+    if ( place() == InDock )
+	msh = msh.expandedTo( fixedExtent() );
     msh = msh.expandedTo( QSize( 16, 16 ) );
     if ( area() ) {
 	if ( area()->orientation() == Horizontal && !vHandleRight->isVisible() )
@@ -1591,7 +1626,7 @@ void QDockWindow::undock( QWidget *w )
     if ( dockArea ) {
 	delete (QDockArea::DockWindowData*)dockWindowData;
 	dockWindowData = dockArea->dockWindowData( this );
-	dockArea->removeDockWindow( this, TRUE, orientation() != Horizontal );
+	dockArea->removeDockWindow( this, TRUE, orientation() != Horizontal && inherits( "QToolBar" ) );
     }
     dockArea = 0;
     if ( lastPos != QPoint( -1, -1 ) && lastPos.x() > 0 && lastPos.y() > 0 )
@@ -1686,6 +1721,10 @@ void QDockWindow::showEvent( QShowEvent *e )
 
     If this property is FALSE, (the default), the dock window
     will be represented by an outline rectangle whilst it is being moved.
+
+    Opaque moving of toolbars and dockwindows is known to have several
+    problems. We suggest not to use it at this point in time. We will
+    fix that behavior problems in a future release.
 */
 
 void QDockWindow::setOpaqueMoving( bool b )
@@ -1739,37 +1778,58 @@ void QDockWindow::updateSplitterVisibility( bool visible )
 }
 
 /*! \reimp */
-bool QDockWindow::eventFilter( QObject *o, QEvent *e )
+bool QDockWindow::eventFilter( QObject *, QEvent *e )
 {
-    if ( e->type() == QEvent::KeyPress ) {
+    if ( e->type() == QEvent::KeyPress &&
+	( horHandle->mousePressed ||
+	  verHandle->mousePressed ||
+	  titleBar->mousePressed ) ) {
 	QKeyEvent *ke = (QKeyEvent*)e;
 	if ( ke->key() == Key_Escape ) {
-	    horHandle->mousePressed = FALSE;
-	    verHandle->mousePressed = FALSE;
-	    titleBar->mousePressed = FALSE;
+	    horHandle->mousePressed =
+		verHandle->mousePressed =
+		    titleBar->mousePressed = FALSE;
 	    endRectDraw( !opaque );
 	    qApp->removeEventFilter( this );
 	    return TRUE;
 	}
+    } else if ( place() == OutsideDock && isTopLevel() ) {
+	if ( (e->type() == QEvent::WindowDeactivate ||
+	    e->type() == QEvent::WindowActivate ) )
+	    event( e );
     }
-
-    return QFrame::eventFilter( o, e );
+    return FALSE;
 }
 
 /*! \reimp */
 bool QDockWindow::event( QEvent *e )
 {
-    if ( e->type() == QEvent::WindowDeactivate ) {
-	if ( place() == OutsideDock ) {
-	    titleBar->setActive( FALSE );
-	    update();
-	}
-    } else if ( e->type() == QEvent::WindowActivate ) {
-	if ( place() == OutsideDock ) {
-	    titleBar->setActive( TRUE );
-	    update();
+    switch ( e->type() ) {
+    case QEvent::WindowDeactivate:
+	if ( place() == OutsideDock && isTopLevel() && parentWidget()
+	     && parentWidget()->isActiveWindow() )
+	    return TRUE;
+	break;
+    case QEvent::Accel:
+    case QEvent::AccelAvailable: {
+	if ( place() == OutsideDock && isTopLevel() && parentWidget() ) {
+	    // if we are floating and active, we still want our
+	    // parent's accelerators to work
+	    if ( QFrame::event( e ) ) // check our own accelerators first
+		return TRUE;
+	    // then check our parent's accelerators ...
+	    if ( QApplication::sendEvent( parentWidget(), e ) ) {
+		// ... and if they worked, make the parent the active window if we safely can
+		if ( e->type() == QEvent::Accel && isActiveWindow() )
+		    parentWidget()->setActiveWindow();
+		return TRUE;
+	    }
 	}
     }
+    break;
+    default:
+	break;
+    }
     return QFrame::event( e );
 }
 
