@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qheader.cpp   3.0.2   edited Feb 8 10:31 $
+** $Id:  qt/qheader.cpp   3.0.5   edited Jul 8 12:19 $
 **
 ** Implementation of QHeader widget class (table header)
 **
@@ -91,7 +91,8 @@ public:
 
 
     QMemArray<QCOORD>	sizes;
-    int height;
+    int height; // we abuse the heights as widths for vertical layout
+    bool heightDirty;
     QMemArray<QCOORD>	positions; // sorted by index
     QPtrVector<QString>	labels;
     QPtrVector<QIconSet> iconsets;
@@ -388,9 +389,9 @@ void QHeader::init( int n )
     state = Idle;
     cachedIdx = 0; // unused
     cachedPos = 0; // unused
-    d = new QHeaderData(n);
-    int h = fontMetrics().lineSpacing() + 6;
-    d->height = h;
+    d = new QHeaderData( n );
+    d->height = 0;
+    d->heightDirty = TRUE;
     offs = 0;
     if( reverse() )
 	offs = d->lastPos - width();
@@ -841,7 +842,7 @@ void QHeader::setLabel( int section, const QString &s, int size )
 	return;
     d->labels.insert( section, new QString( s ) );
 
-    setSectionSizeAndHeight( section, size, s );
+    setSectionSizeAndHeight( section, size );
 
     if ( isUpdatesEnabled() ) {
 	updateGeometry();
@@ -851,19 +852,21 @@ void QHeader::setLabel( int section, const QString &s, int size )
 }
 
 
+bool qt_qheader_label_return_null_strings = FALSE;
 /*!
   Returns the text for section \a section.
   If the section does not exist, a null string is returned.
 */
-
 QString QHeader::label( int section ) const
 {
     if ( section < 0 || section >= count() )
 	return QString::null;
     if ( d->labels[ section ] )
 	return *( d->labels[ section ] );
-    else
+    else if ( qt_qheader_label_return_null_strings )
 	return QString::null;
+    else
+	return QString::number( section + 1 );
 }
 
 /*!
@@ -946,11 +949,7 @@ void QHeader::removeLabel( int section )
     }
 }
 
-/*!
-  Sets d->sizes[\a section] and d->heights[\a section] to the bounding
-  rect of \a s, with the constraint \a size.
-*/
-void QHeader::setSectionSizeAndHeight( int section, int size, const QString& s )
+QSize QHeader::sectionSizeHint( int section, const QFontMetrics& fm ) const
 {
     int iw = 0;
     int ih = 0;
@@ -961,20 +960,44 @@ void QHeader::setSectionSizeAndHeight( int section, int size, const QString& s )
 	ih = isize.height();
     }
 
-    QFontMetrics fm = fontMetrics();
-    QRect bound = fm.boundingRect( 0, 0, QWIDGETSIZE_MAX, QWIDGETSIZE_MAX,
-				   AlignVCenter, s );
+    QRect bound;
+    QString *label = d->labels[section];
+    if ( label )
+	bound = fm.boundingRect( 0, 0, QWIDGETSIZE_MAX, QWIDGETSIZE_MAX,
+				 AlignVCenter, *label );
     int height = QMAX( bound.height() + 2, ih ) + 4;
     int width = bound.width() + QH_MARGIN * 4 + iw;
+    return QSize( width, height );
+}
+
+/*!
+    Sets d->sizes[\a section] to a bounding rect based on its size
+    hint and font metrics, but constrained by \a size. It also updates
+    d->height.
+*/
+void QHeader::setSectionSizeAndHeight( int section, int size )
+{
+    QSize sz = sectionSizeHint( section, fontMetrics() );
 
     if ( size < 0 ) {
 	if ( d->sizes[section] < 0 )
-	    d->sizes[section] = ( orient == Horizontal ) ? width : height;
+	    d->sizes[section] = ( orient == Horizontal ) ? sz.width()
+							 : sz.height();
     } else {
 	d->sizes[section] = size;
     }
-    // we abuse the heights as widths for vertical layout
-    d->height = QMAX( ( orient == Horizontal ) ? height : width, d->height );
+
+    int newHeight = ( orient == Horizontal ) ? sz.height() : sz.width();
+    if ( newHeight > d->height ) {
+	d->height = newHeight;
+    } else if ( newHeight < d->height ) {
+	/*
+	  We could be smarter, but we aren't. This makes a difference
+	  only for users with many columns and '\n's in their headers
+	  at the same time.
+	*/
+	d->heightDirty = TRUE;
+    }
 }
 
 /*!
@@ -1006,7 +1029,7 @@ int QHeader::addLabel( const QString &s, int size )
 	d->sizes[section] = size;
     } else {
 	d->sizes[section] = -1;
-	setSectionSizeAndHeight( section, size, s );
+	setSectionSizeAndHeight( section, size );
     }
 
     int index = section;
@@ -1050,14 +1073,23 @@ QSize QHeader::sizeHint() const
 
     constPolish();
     QFontMetrics fm = fontMetrics();
+
+    if ( d->heightDirty ) {
+	d->height = fm.lineSpacing() + 6;
+	for ( int i = 0; i < count(); i++ ) {
+	    int h = sectionSizeHint( i, fm ).height();
+	    d->height = QMAX( d->height, h );
+	}
+	d->heightDirty = FALSE;
+    }
+
     if ( orient == Horizontal ) {
 	height = fm.lineSpacing() + 6;
 	width = 0;
 	height = QMAX( height, d->height );
 	for ( int i = 0; i < count(); i++ )
 	    width += d->sizes[i];
-    }
-    else {
+    } else {
 	width = fm.width( ' ' );
 	height = 0;
 	width = QMAX( width, d->height );
@@ -1084,9 +1116,9 @@ void QHeader::setOffset( int x )
 {
     int oldOff = offset();
     offs = x;
-    if( d->lastPos < width() ) {
+    if( d->lastPos < ( orient == Horizontal ? width() : height() ) )
 	offs = 0;
-    } else if ( reverse() )
+    else if ( reverse() )
 	offs = d->lastPos - width() - x;
     if ( orient == Horizontal )
 	scroll( oldOff-offset(), 0 );
@@ -1124,32 +1156,6 @@ int QHeader::pSize( int i ) const
     return d->sizes[ d->i2s[i] ];
 }
 
-/*!
-  Returns the height of section \a i if orientation() is horizontal;
-  returns the width if orientation() is vertical.
-
-*/
-int QHeader::pHeight( int i ) const
-{
-    int section = mapToSection(i);
-    if ( section < 0 )
-	return 0;
-    return d->height;
-}
-
-/*!
-  Sets the height of section \a i to \a h if orientation() is
-  horizontal. Sets the width if orientation() is vertical.
-*/
-void QHeader::setPHeight( int i, int h )
-{
-    int section = mapToSection(i);
-    if ( section < 0 )
-	return;
-    d->height = h;
-}
-
-
 /*!
   \obsolete
 
@@ -1285,6 +1291,7 @@ void QHeader::setClickEnabled( bool enable, int section )
 void QHeader::paintSection( QPainter *p, int index, const QRect& fr )
 {
     int section = mapToSection( index );
+
     if ( section < 0 ) {
 	style().drawPrimitive( QStyle::PE_HeaderSection, p, fr,
 			       colorGroup(), QStyle::Style_Raised |
@@ -1292,9 +1299,12 @@ void QHeader::paintSection( QPainter *p, int index, const QRect& fr )
 	return;
     }
 
+    if ( cellSize( section ) <= 0 )
+	return;
+
     QStyle::SFlags flags;
     flags = ( orient == Horizontal ? QStyle::Style_Horizontal : 0 );
-    if(index == handleIdx) {
+    if(index == handleIdx && isClickEnabled()) {
 	if(state == Pressed || state == Moving)
 	    flags |= QStyle::Style_Down;
 	else if(state != Sliding)
@@ -1690,13 +1700,13 @@ void QHeader::adjustHeaderSize( int diff )
 
     if ( d->fullSize >= 0 ) {
 	int sec = mapToIndex( d->fullSize );
-	int ns = sectionSize( sec ) + ( orientation() == Horizontal ? width() : height() ) - ( sectionPos( count() - 1 ) + sectionSize( count() - 1 ) );
+	int ns = sectionSize( sec ) + ( orientation() == Horizontal ? width() : height() ) - ( sectionPos( count()-1 ) + sectionSize( count()-1 ) );
 	int os = sectionSize( sec );
-	if ( ns > 20 ) {
-	    setCellSize( sec, ns );
-	    repaint( FALSE );
-	    emit sizeChange( sec, os, ns );
-	}
+	if ( ns < 20 )
+	    ns = 20;
+	setCellSize( sec, ns );
+	repaint( FALSE );
+	emit sizeChange( sec, os, ns );
     } else if ( d->fullSize == -1 ) {
 	int df = diff / count();
 	int part = orientation() == Horizontal ? width() / count() : height() / count();
@@ -1704,19 +1714,19 @@ void QHeader::adjustHeaderSize( int diff )
 	    int sec = mapToIndex( i );
 	    int os = sectionSize( sec );
 	    int ns = diff != -1 ? os + df : part;
-	    if ( ns > 20 ) {
-		setCellSize( sec, ns );
-		emit sizeChange( sec, os, ns );
-	    }
+	    if ( ns < 20 )
+		ns = 20;
+	    setCellSize( sec, ns );
+	    emit sizeChange( sec, os, ns );
 	}
 	int sec = mapToIndex( count() - 1 );
 	int ns = ( orientation() == Horizontal ? width() : height() ) - sectionPos( sec );
 	int os = sectionSize( sec );
-	if ( ns > 20 ) {
-	    setCellSize( sec, ns );
-	    repaint( FALSE );
-	    emit sizeChange( sec, os, ns );
-	}
+	if ( ns < 20 )
+	    ns = 20;
+	setCellSize( sec, ns );
+	repaint( FALSE );
+	emit sizeChange( sec, os, ns );
     }
 }
 
