@@ -52,8 +52,8 @@
 #include "qstyle.h"
 #include "qwhatsthis.h"
 #include <ctype.h>
-#include <private/qrichtext_p.h>
-#include <private/qinternal_p.h>
+#include "../kernel/qinternal_p.h"
+#include "../kernel/qrichtext_p.h"
 #if defined(QT_ACCESSIBILITY_SUPPORT)
 #include "qaccessible.h"
 #endif
@@ -67,7 +67,7 @@
 
 struct UndoRedoInfo {
     enum Type { Invalid, Insert, Delete, Backspace, RemoveSelected };
-    UndoRedoInfo( QTextParag *p ) : type( Invalid ), parag( p ) {
+    UndoRedoInfo( QTextParagraph *p ) : type( Invalid ), parag( p ) {
 	text = QString::null; index = -1;
     }
     bool valid() const { return !text.isEmpty() && index >= 0; }
@@ -87,7 +87,7 @@ struct UndoRedoInfo {
     QString text;
     int index;
     Type type;
-    QTextParag *parag;
+    QTextParagraph *parag;
 };
 
 struct QLineEditPrivate {
@@ -103,7 +103,7 @@ struct QLineEditPrivate {
 	validator( 0 ),
 	blinkTimer( l, "QLineEdit blink timer" ),
 	dndTimer( l, "DnD Timer" ),
-	parag( new QTextParag( 0, 0, 0, FALSE ) ),
+	parag( new QTextParagraph( 0, 0, 0, FALSE ) ),
 	dragTimer( l, "QLineEdit drag timer" ),
 	undoRedoInfo( parag ),
 	dragEnabled( TRUE ),
@@ -113,7 +113,7 @@ struct QLineEditPrivate {
     {
 	parag->formatter()->setWrapEnabled( FALSE );
 	cursor = new QTextCursor( 0 );
-	cursor->setParag( parag );
+	cursor->setParagraph( parag );
 
     }
     static QPixmap* pm; // only used when we have focus
@@ -141,13 +141,13 @@ struct QLineEditPrivate {
 	}
 	return res;
     }
-    void getTextObjects( QTextParag **p, QTextCursor **c )
+    void getTextObjects( QTextParagraph **p, QTextCursor **c )
     {
 	if ( mode == QLineEdit::Password ) {
-	    *p = new QTextParag( 0, 0, 0, FALSE);
+	    *p = new QTextParagraph( 0, 0, 0, FALSE);
 	    (*p)->formatter()->setWrapEnabled( FALSE );
 	    *c = new QTextCursor( 0 );
-	    (*c)->setParag( *p );
+	    (*c)->setParagraph( *p );
 	    (*p)->append( displayText() );
 	    (*c)->setIndex( cursor->index() );
 	} else {
@@ -155,7 +155,7 @@ struct QLineEditPrivate {
 	    *c = cursor;
 	}
     }
-    void releaseTextObjects( QTextParag **p, QTextCursor **c )
+    void releaseTextObjects( QTextParagraph **p, QTextCursor **c )
     {
 	if ( mode == QLineEdit::Password ) {
 	    cursor->setIndex( (*c)->index() );
@@ -202,7 +202,7 @@ struct QLineEditPrivate {
     QTimer blinkTimer;
 
     QTimer dndTimer;
-    QTextParag *parag;
+    QTextParagraph *parag;
     QTextCursor *cursor;
     QPoint dnd_startpos;
     QTimer dragTimer;
@@ -370,11 +370,21 @@ QLineEdit::~QLineEdit()
 }
 
 #if defined(Q_INCOMPATIBLE_3_0_ADDONS)
+/*!
+    Sets the password character to \a c.
+
+    \sa passwordChar()
+*/
 void QLineEdit::setPasswordChar( QChar c )
 {
     d->passwordChar = c;
 }
 
+/*!
+    Returns the password character.
+
+    \sa setPasswordChar()
+*/
 QChar QLineEdit::passwordChar() const
 {
     return d->passwordChar;
@@ -405,7 +415,7 @@ void QLineEdit::init()
     //   Specifies that this widget can use more, but is able to survive on
     //   less, horizontal space; and is fixed vertically.
     setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed ) );
-    setBackgroundMode( PaletteBase );
+    setBackgroundMode( NoBackground );
     setKeyCompression( TRUE );
     setMouseTracking( TRUE );
     setFrame( TRUE );
@@ -414,21 +424,23 @@ void QLineEdit::init()
 
 void QLineEdit::setText( const QString &text )
 {
+    d->undoRedoInfo.clear();
     QString oldText = this->text();
     d->parag->truncate( 0 );
     d->parag->append( text );
+    d->parag->commands()->clear();
     d->cursor->setIndex( d->parag->length() - 1 );
     if ( hasFocus() )
-	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
     deselect();
     update();
+    setEdited( FALSE );
     if ( oldText != text ) {
 	emit textChanged( text );
 #if defined(QT_ACCESSIBILITY_SUPPORT)
 	QAccessible::updateAccessibility( this, 0, QAccessible::ValueChanged );
 #endif
     }
-    setEdited( FALSE );
 }
 
 
@@ -447,7 +459,7 @@ void QLineEdit::selectAll()
     d->cursor->gotoEnd();
     updateSelection();
     if ( hasFocus() )
-	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
     update();
 }
 
@@ -464,9 +476,6 @@ void QLineEdit::deselect()
 {
     d->selectionStart = 0;
     d->parag->removeSelection( QTextDocument::Standard );
-#ifndef QT_NO_CURSOR
-    setCursor( isReadOnly() ? arrowCursor : ibeamCursor );
-#endif
     update();
 }
 
@@ -482,12 +491,12 @@ void QLineEdit::deselect()
 
 QString QLineEdit::text() const
 {
-    // only change the text if we need to, this ensure
-    // that multiple calls to text() will get the same value.
-    if ( d->txtBuffer + " " != d->parag->string()->toString() ) {
-	d->txtBuffer = d->parag->string()->toString();
-	d->txtBuffer.remove( d->txtBuffer.length() - 1, 1 );  // remove space
-    }
+    // only change the text if we need to, this ensure that multiple
+    // calls to text() will get the same shared value.
+    QString s = d->parag->string()->toString();
+    s.remove( s.length() - 1, 1 ); // get rid of trailing space
+    if ( d->txtBuffer != s )
+	d->txtBuffer = s;
     return d->txtBuffer;
 }
 
@@ -604,6 +613,8 @@ void QLineEdit::setMaxLength( int m )
 
 void QLineEdit::keyPressEvent( QKeyEvent *e )
 {
+    d->blinkTimer.stop();
+    blinkOn();
     int cursorPos = cursorPosition();
     if ( e->key() == Key_Enter || e->key() == Key_Return ) {
 #ifdef QT_NO_VALIDATOR
@@ -635,6 +646,15 @@ void QLineEdit::keyPressEvent( QKeyEvent *e )
 	if ( !t.isEmpty() && (!e->ascii() || e->ascii()>=32) &&
 	     e->key() != Key_Delete &&
 	     e->key() != Key_Backspace ) {
+	    if ( d->parag && d->parag->string() && d->parag->string()->isRightToLeft() ) {
+		QChar *c = (QChar *)t.unicode();
+		int l = t.length();
+		while( l-- ) {
+		    if ( c->mirrored() )
+			*c = c->mirroredChar();
+		    c++;
+		}
+	    }
 	    insert( t );
 	    return;
 	}
@@ -643,7 +663,11 @@ void QLineEdit::keyPressEvent( QKeyEvent *e )
     if ( e->state() & ControlButton ) {
 	switch ( e->key() ) {
 	case Key_A:
+#if defined(Q_WS_X11)
 	    home( e->state() & ShiftButton );
+#else
+	    selectAll();
+#endif	
 	    break;
 	case Key_B:
 	    cursorForward( e->state() & ShiftButton, -1 );
@@ -713,8 +737,12 @@ void QLineEdit::keyPressEvent( QKeyEvent *e )
 	    }
 	    break;
 	case Key_Z:
-	    if ( !d->readonly )
-		undo();
+	    if ( !d->readonly ) {
+		if(e->state() & ShiftButton)
+		    redo();
+		else
+		    undo();
+	    }
 	    break;
 	case Key_Y:
 	    if ( !d->readonly )
@@ -814,7 +842,7 @@ void QLineEdit::imStartEvent( QIMEvent *e )
     d->preeditStart = cursorPosition();
     d->preeditLength = 0;
     setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0,
-	d->cursor->parag()->rect().height(), TRUE );
+	d->cursor->paragraph()->rect().height(), TRUE );
     e->accept();
 }
 
@@ -829,6 +857,7 @@ void QLineEdit::imComposeEvent( QIMEvent *e )
     d->preeditLength = e->text().length();
     d->cursor->setIndex(d->preeditStart + e->cursorPos());
 
+    emit textChanged( text() );
     e->accept();
 }
 
@@ -843,6 +872,7 @@ void QLineEdit::imEndEvent( QIMEvent *e )
     d->cursor->setIndex(d->preeditStart + e->text().length());
     d->preeditStart = d->preeditLength = -1;
 
+    emit textChanged( text() );
     e->accept();
 }
 
@@ -858,7 +888,7 @@ void QLineEdit::focusInEvent( QFocusEvent * e)
     if ( e->reason() == QFocusEvent::Tab || e->reason() == QFocusEvent::Backtab )
 	selectAll();
     update();
-    setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+    setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
 }
 
 
@@ -884,24 +914,32 @@ void QLineEdit::focusOutEvent( QFocusEvent * e )
 
 void QLineEdit::drawContents( QPainter *painter )
 {
-    int marg = frameWidth() + margin() + 1;
+    int marg = frameWidth();
     painter->translate( marg, 0 );
     const QColorGroup & g = colorGroup();
 
+    int lineheight = QMIN( fontMetrics().lineSpacing() + 4, height() );
+    int linetop = (height() - lineheight ) / 2;
+
     // always double buffer when we have focus, and keep the pixmap
     // around until we loose focus again. If we do not have focus,
     // only use the standard shared buffer.
 
-    if ( hasFocus() && !QLineEditPrivate::pm && !QSharedDoubleBuffer::getRawPixmap( width(), height() ) )
+    if ( hasFocus() && !QLineEditPrivate::pm && !QSharedDoubleBuffer::getRawPixmap( width(), lineheight ) )
 	QLineEditPrivate::pm = new QPixmap; // create special while-we-have-focus buffer. Deleted in focusOutEvent
 
     QSharedDoubleBuffer buffer( !hasFocus(), FALSE, QLineEditPrivate::pm );
-    buffer.begin( painter, rect() );
+    buffer.begin( painter, 0, linetop, width(), lineheight );
     buffer.painter()->setPen( colorGroup().text() );
-    QBrush bg = g.brush((isEnabled()) ? QColorGroup::Base :
-			QColorGroup::Background);
+    const QBrush &bg = g.brush((isEnabled()) ? QColorGroup::Base :
+			       QColorGroup::Background);
     buffer.painter()->fillRect( 0, 0, width(), height(), bg );
-    QTextParag *parag;
+    if ( linetop ) {
+	painter->fillRect( 0, 0, width(), linetop, bg );
+	painter->fillRect( 0, linetop + lineheight, width(), linetop, bg );
+    }
+
+    QTextParagraph *parag;
     QTextCursor *cursor;
     d->getTextObjects( &parag, &cursor );
     if ( echoMode() == Password ) {
@@ -919,18 +957,21 @@ void QLineEdit::drawContents( QPainter *painter )
     QTextFormat *f = parag->formatCollection()->format( font(), buffer.painter()->pen().color() );
     parag->setFormat( 0, parag->length(), f );
     f->removeRef();
-    QRect r( rect().x(), rect().y(), width() - 4, rect().height() );
+    QRect r( rect().x(), rect().y(), width() - 2 * marg, rect().height() );
     parag->pseudoDocument()->docRect = r;
     parag->invalidate( 0 );
     parag->format();
     updateOffset();
     int xoff = 1 - d->offset;
-    int yoff = ( height() - parag->rect().height() ) / 2;
+    int yoff = ( height() - parag->rect().height()  + 1 ) / 2;
     if ( yoff < 0 )
 	yoff = 0;
     buffer.painter()->translate( xoff, yoff );
     if ( d->mode != NoEcho )
-	parag->paint( *buffer.painter(), colorGroup(), d->cursorOn && !d->readonly ? cursor : 0, TRUE );
+	parag->paint( *buffer.painter(), colorGroup(),
+		      d->cursorOn && !d->readonly ? cursor : 0,
+		      TRUE,
+		      -xoff, 0, width(), height() );
 
     buffer.end();
 
@@ -1014,7 +1055,7 @@ enum {
     IdSelectAll = 6
 };
 
-static bool inSelection( int x, QTextParag *p )
+static bool inSelection( int x, QTextParagraph *p )
 {
     return ( x >= p->at( p->selectionStart( QTextDocument::Standard ) )->x &&
 	     x <= p->at( p->selectionEnd( QTextDocument::Standard ) )->x );
@@ -1032,7 +1073,7 @@ void QLineEdit::mousePressEvent( QMouseEvent *e )
 
     d->inDoubleClick = FALSE;
     QPoint p( e->pos().x() + d->offset - frameWidth() - margin() - 1, 0 );
-    QTextParag *par;
+    QTextParagraph *par;
     QTextCursor *c;
     d->getTextObjects(&par, &c);
     int oldPos = c->index();
@@ -1089,7 +1130,7 @@ void QLineEdit::doDrag()
     if ( tdo->drag() && !isReadOnly() )
 	del();
 #ifndef QT_NO_CURSOR
-    setCursor( ibeamCursor );
+    setCursor( isReadOnly() ? arrowCursor : ibeamCursor );
 #endif
     d->mousePressed = FALSE;
 }
@@ -1139,7 +1180,7 @@ void QLineEdit::mouseMoveEvent( QMouseEvent *e )
 void QLineEdit::dragSlot()
 {
     QPoint p( d->lastMovePos.x() + d->offset - frameWidth() - margin() - 1, 0 );
-    QTextParag *par;
+    QTextParagraph *par;
     QTextCursor *c;
     d->getTextObjects(&par, &c);
     c->place( p, par );
@@ -1199,7 +1240,7 @@ void QLineEdit::mouseReleaseEvent( QMouseEvent * e )
 	return;
 
     QPoint p( e->pos().x() + d->offset - frameWidth() - margin() - 1, 0 );
-    QTextParag *par;
+    QTextParagraph *par;
     QTextCursor *c;
     d->getTextObjects(&par, &c);
     c->place( p, par );
@@ -1334,7 +1375,7 @@ void QLineEdit::cursorForward( bool mark, int steps )
 	d->selectionStart = d->cursor->index();
     }
     if ( hasFocus() )
-	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
     update();
 }
 
@@ -1381,7 +1422,8 @@ void QLineEdit::home( bool mark )
 	deselect();
 	d->selectionStart = d->cursor->index();
     }
-    setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+    setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
+    updateOffset();
     update();
 }
 
@@ -1402,7 +1444,7 @@ void QLineEdit::end( bool mark )
 	deselect();
 	d->selectionStart = d->cursor->index();
     }
-    setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+    setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
     update();
 }
 
@@ -1419,11 +1461,8 @@ void QLineEdit::copy() const
 {
     QString t = selectedText();
     if ( !t.isEmpty() && echoMode() == Normal ) {
-	disconnect( QApplication::clipboard(), SIGNAL(dataChanged()), this, 0);
 	disconnect( QApplication::clipboard(), SIGNAL(selectionChanged()), this, 0);
 	QApplication::clipboard()->setText( t );
-	connect( QApplication::clipboard(), SIGNAL(dataChanged()),
-		 this, SLOT(clipboardChanged()) );
 	connect( QApplication::clipboard(), SIGNAL(selectionChanged()),
 		 this, SLOT(clipboardChanged()) );
     }
@@ -1478,7 +1517,7 @@ void QLineEdit::setAlignment( int flag )
     d->parag->format();
     updateOffset();
     if ( hasFocus() )
-	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
     update();
 }
 
@@ -1507,8 +1546,6 @@ int QLineEdit::alignment() const
 void QLineEdit::clipboardChanged()
 {
 #if defined(Q_WS_X11)
-    disconnect( QApplication::clipboard(), SIGNAL(dataChanged()),
-		this, SLOT(clipboardChanged()) );
     disconnect( QApplication::clipboard(), SIGNAL(selectionChanged()),
 		this, SLOT(clipboardChanged()) );
     deselect();
@@ -1596,9 +1633,9 @@ QSize QLineEdit::sizeHint() const
 {
     constPolish();
     QFontMetrics fm( font() );
-    int h = fm.height();
+    int h = fm.lineSpacing();
     int w = fm.width( 'x' ) * 17; // "some"
-    return QSize( w + 4 + frameWidth(), h + 4 + frameWidth() + margin() ).expandedTo( QApplication::globalStrut() );
+    return QSize( w + 2 + 2*frameWidth(), QMAX( h, 14 ) + 2 + 2*frameWidth() ).expandedTo( QApplication::globalStrut() );
 }
 
 
@@ -1613,9 +1650,9 @@ QSize QLineEdit::minimumSizeHint() const
 {
     constPolish();
     QFontMetrics fm( font() );
-    int h = fm.height();
+    int h = fm.lineSpacing();
     int w = fm.maxWidth();
-    return QSize( w + 4 + frameWidth(), h + 4 + frameWidth() + margin() );
+    return QSize( w + 2 + 2*frameWidth(), h + 2 + 2 * frameWidth() );
 }
 
 
@@ -1686,7 +1723,7 @@ void QLineEdit::dragMoveEvent( QDragMoveEvent *e )
 	e->acceptAction();
     else
 	return;
-    QPoint p( e->pos().x() + d->offset - frameWidth() - margin() - 1, 0 );
+    QPoint p( e->pos().x() + d->offset - frameWidth() - 1, 0 );
     d->cursor->place( p, d->parag );
     update();
 }
@@ -1709,7 +1746,7 @@ void QLineEdit::dropEvent( QDropEvent *e )
 	if ( e->source() == this && hasSelectedText() )
 	    deselect();
 	if ( !hasSelectedText() ) {
-	    QPoint p( e->pos().x() + d->offset - frameWidth() - margin() - 1, 0 );
+	    QPoint p( e->pos().x() + d->offset - frameWidth() - 1, 0 );
 	    d->cursor->place( p, d->parag );
 	}
 	insert( str );
@@ -1766,8 +1803,7 @@ bool QLineEdit::validateAndSet( const QString &newText, int newPos,
     }
     t.truncate( maxLength() );
 
-    QString old = d->parag->string()->toString();
-    old.remove( old.length() - 1, 1 );
+    QString old = this->text();
 
 #ifndef QT_NO_VALIDATOR
     const QValidator * v = validator();
@@ -1780,32 +1816,27 @@ bool QLineEdit::validateAndSet( const QString &newText, int newPos,
 #endif
 
     // okay, it succeeded
-    if ( t != old ) {
-	// contents of setText() with one addition
-	QString text = t;
-	QString oldText = this->text();
+    bool text_changed = ( t != old );
+    if ( text_changed ) {
 	d->parag->truncate( 0 );
-	d->parag->append( text );
-	d->cursor->setIndex( d->parag->length() - 1 );
-	if ( hasFocus() )
-	    setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
-	deselect();
-	update();
-	d->cursor->setIndex( newPos ); // put the cursor back where its meant to be before emitting the signal
-	if ( oldText != text ) {
-	    emit textChanged( text );
-#if defined(QT_ACCESSIBILITY_SUPPORT)
-	    QAccessible::updateAccessibility( this, 0, QAccessible::ValueChanged );
-#endif
-	// end of setText contents
-	}
+	d->parag->append( t );
     }
 
     d->cursor->setIndex( newPos );
     d->selectionStart = newMarkAnchor;
     d->parag->setSelection( QTextDocument::Standard, newMarkAnchor, newMarkDrag );
     repaint( FALSE );
-    d->selectionStart = d->cursor->index();
+
+    if ( hasFocus() )
+	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(),
+			   0, d->cursor->paragraph()->rect().height(), TRUE );
+
+    if ( text_changed ) {
+#if defined(QT_ACCESSIBILITY_SUPPORT)
+	QAccessible::updateAccessibility( this, 0, QAccessible::ValueChanged );
+#endif
+	emit textChanged( t );
+    }
     return TRUE;
 }
 
@@ -1861,7 +1892,7 @@ void QLineEdit::insert( const QString &newText )
 #endif
     if ( hasFocus() )
 	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0,
-			   d->cursor->parag()->rect().height(), TRUE );
+			   d->cursor->paragraph()->rect().height(), TRUE );
 }
 
 
@@ -1975,7 +2006,7 @@ void QLineEdit::cursorWordForward( bool mark )
 	d->selectionStart = d->cursor->index();
     }
     if ( hasFocus() )
-	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
     update();
 }
 
@@ -1995,7 +2026,7 @@ void QLineEdit::cursorWordBackward( bool mark )
 	d->selectionStart = d->cursor->index();
     }
     if ( hasFocus() )
-	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+	setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
     update();
 }
 
@@ -2017,12 +2048,12 @@ void QLineEdit::blinkOn()
 void QLineEdit::updateOffset()
 {
     // must not call repaint() - paintEvent() calls this
-    int parWidth = d->parag->rect().width() - 4; // QTextParag adds 4 pixels to the real width
+    int parWidth = d->parag->rect().width() - 4; // QTextParagraph adds 4 pixels to the real width
     int leftGap = d->parag->leftGap();
     int textWidth = parWidth - leftGap;
     int w = width();
     int fw = 0;
-    fw = frameWidth() + margin() + 1;
+    fw = frameWidth() + 1;
     w -= 2*fw + 4;
     int cursorPos = d->cursor->x();
 
@@ -2065,6 +2096,8 @@ void QLineEdit::updateSelection()
     int pos = d->cursor->index();
     int selectionStart = d->selectionStart;
     int selectionEnd;
+    int oldStart = d->parag->selectionStart( QTextDocument::Standard ),
+          oldEnd = d->parag->selectionEnd( QTextDocument::Standard );
     if ( pos > selectionStart ) {
 	selectionEnd = pos;
     } else {
@@ -2082,7 +2115,9 @@ void QLineEdit::updateSelection()
     }
 #endif // QT_NO_CLIPBOARD
 
-    if ( oldHST != hasSelectedText() )
+    if ( (oldHST != hasSelectedText()) ||
+  	 (oldStart != selectionStart) ||
+  	 (oldEnd != selectionEnd) )
 	emit selectionChanged();
 }
 
@@ -2090,6 +2125,7 @@ void QLineEdit::updateSelection()
 void QLineEdit::removeSelectedText()
 {
     insert( QString::null );
+    emit selectionChanged();
 }
 
 
@@ -2207,10 +2243,7 @@ void QLineEdit::windowActivationChange( bool )
     if ( !isVisible() )
 	return;
 
-    const QColorGroup acg = palette().active();
-    const QColorGroup icg = palette().inactive();
-
-    if ( acg != icg )
+    if ( palette().active() != palette().inactive() )
 	update();
 }
 
@@ -2223,11 +2256,11 @@ void QLineEdit::windowActivationChange( bool )
 int QLineEdit::characterAt( int xpos, QChar *chr ) const
 {
     QTextCursor c;
-    c.setParag( d->parag );
+    c.setParagraph( d->parag );
     c.setIndex( 0 );
-    c.place( QPoint( xpos, 0 ), c.parag() );
+    c.place( QPoint( xpos, 0 ), c.paragraph() );
     if ( chr )
-	*chr = c.parag()->at( c.index() )->c;
+	*chr = c.paragraph()->at( c.index() )->c;
     return c.index();
 }
 
@@ -2277,7 +2310,7 @@ void QLineEdit::delOrBackspace( bool backspace )
 		    d->cursor->gotoPreviousLetter();
 		    d->undoRedoInfo.index = d->cursor->index();
 		}
-		QChar ch = d->cursor->parag()->at( d->cursor->index() )->c;
+		QChar ch = d->cursor->paragraph()->at( d->cursor->index() )->c;
 		if ( backspace ) {
 		    d->undoRedoInfo.text.prepend( ch );
 		} else {
@@ -2293,7 +2326,7 @@ void QLineEdit::delOrBackspace( bool backspace )
 		d->selectionStart = d->cursor->index();
 		d->ed = TRUE;
 		update();
-		setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->parag()->rect().height(), TRUE );
+		setMicroFocusHint( d->cursor->x() - d->offset, d->cursor->y(), 0, d->cursor->paragraph()->rect().height(), TRUE );
 		emit textChanged( text() );
 #if defined(QT_ACCESSIBILITY_SUPPORT)
 		QAccessible::updateAccessibility( this, 0, QAccessible::ValueChanged );
