@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qmenubar.cpp   3.0.2   edited Feb 6 11:00 $
+** $Id:  qt/qmenubar.cpp   3.0.5   edited Jun 11 14:06 $
 **
 ** Implementation of QMenuBar class
 **
@@ -129,14 +129,37 @@ static bool inMenu = FALSE;
     Menu items may be removed with removeItem() and enabled or disabled
     with \link QMenuData::setItemEnabled() setItemEnabled()\endlink.
 
-    QMenuBar on Qt/Mac is a wrapper for using the system-wide
-    menubar. However if you have multiple menubars in one dialog the
-    outermost menubar (normally inside a widget with \l WType_TopLevel) will
-    be used for the global menubar.
-
   <img src=qmenubar-m.png> <img src=qmenubar-w.png>
 
+
+    QMenuBar on Qt/Mac is a wrapper for using the system-wide
+    menubar. However, if you have multiple menubars in one dialog the
+    outermost menubar (normally inside a widget with \l
+    WType_TopLevel) will be used for the global menubar.
+
+    Qt/Mac also provides a menubar merging feature, with this your
+    QMenubar will be brought closer to conforming to accepted Mac OS X
+    menubar layout. The merging functionality is based on string
+    matching the title of a QPopupMenu entry, these strings are
+    translated (using QObject::tr()) in the "QMenuBar" context. If an
+    entry is moved the regularly connected slots will still fire as if
+    it was in the original place. The table below outlines the strings
+    looked for and where the entry is placed if matched:
+
+    \table
+    \header \i String matches \i Placement \i Notes
+    \row \i about.* \i Application Menu | About <application name>
+         \i If this entry is not found no About item will appear in the Application Menu
+    \row \i config, options, setup, settings, preferences \i Application Menu | Settings
+         \i If this entry is not found the Settings item will be disabled
+    \row \i quit, exit \i Application Menu | Quit <application name>
+         \i If this entry is not found a default Quit item will be created to call
+	    QApplication::quit()
+    \endtable
+
   \sa QPopupMenu QAccel QAction
+      \link http://developer.apple.com/techpubs/macosx/Carbon/HumanInterfaceToolbox/Aqua/aqua.html
+            Aqua Style Guidelines \endlink
       \link guibooks.html#fowler GUI Design Handbook: Menu Bar \endlink
 */
 
@@ -255,26 +278,11 @@ QMenuBar::QMenuBar( QWidget *parent, const char *name )
     setLineWidth( style().pixelMetric(QStyle::PM_MenuBarFrameWidth, this) );
 
     QFontMetrics fm = fontMetrics();
-    int gs = style().styleHint(QStyle::SH_GUIStyle);
-    int h;
-    if ( gs == WindowsStyle ) {
-	h = 2 + fm.height() + motifItemVMargin + 2*frameWidth() + 2*motifItemFrame;
-    } else {
-	h =  style().pixelMetric( QStyle::PM_DefaultFrameWidth, this ) +
-	    motifBarVMargin + fm.height() + motifItemVMargin +
-	    2*frameWidth() + 2*motifItemFrame;
-    }
+    int h = 2*motifBarVMargin + fm.height() + motifItemVMargin + 2*frameWidth() + 2*motifItemFrame;
 
-    move( 0, 0 );
-    resize( width(), h );
+    setGeometry( 0, 0, width(), h );
 
-    switch ( gs ) {
-	case WindowsStyle:
-	    setMouseTracking( TRUE );
-	    break;
-	default:
-	    break;
-    }
+    setMouseTracking( style().styleHint(QStyle::SH_GUIStyle) == WindowsStyle );
 }
 
 
@@ -283,19 +291,9 @@ QMenuBar::QMenuBar( QWidget *parent, const char *name )
 
 void QMenuBar::styleChange( QStyle& old )
 {
-    switch ( style().styleHint(QStyle::SH_GUIStyle) ) {
-    case WindowsStyle:
-	setMouseTracking( TRUE );
-	break;
-    case MotifStyle:
-	setMouseTracking( FALSE );
-	break;
-    default:
-	break;
-    }
+    setMouseTracking( style().styleHint(QStyle::SH_GUIStyle) == WindowsStyle );
     setFrameStyle( QFrame::MenuBarPanel | QFrame::Raised );
     setLineWidth( style().pixelMetric( QStyle::PM_MenuBarFrameWidth, this ) );
-    updateGeometry();
     QFrame::styleChange( old );
 }
 
@@ -403,7 +401,7 @@ void QMenuBar::performDelayedContentsChanged()
 
 void QMenuBar::menuStateChanged()
 {
-    // here the part that can't be delayed
+    if( pendingDelayedStateChanges )
         return;
     pendingDelayedStateChanges = 1;
     if( !pendingDelayedContentsChanges ) // if the timer hasn't been started yet
@@ -433,20 +431,20 @@ void QMenuBar::performDelayedChanges()
 
 void QMenuBar::menuInsPopup( QPopupMenu *popup )
 {
-    popup->parentMenu = this;			// set parent menu
     connect( popup, SIGNAL(activatedRedirect(int)),
 	     SLOT(subActivated(int)) );
     connect( popup, SIGNAL(highlightedRedirect(int)),
 	     SLOT(subHighlighted(int)) );
+    connect( popup, SIGNAL(destroyed(QObject*)),
+	     this, SLOT(popupDestroyed(QObject*)) );
 }
 
 void QMenuBar::menuDelPopup( QPopupMenu *popup )
 {
-    popup->parentMenu = 0;
-    popup->disconnect( SIGNAL(activatedRedirect(int)), this,
-		       SLOT(subActivated(int)) );
-    popup->disconnect( SIGNAL(highlightedRedirect(int)), this,
-		       SLOT(subHighlighted(int)) );
+    popup->disconnect( SIGNAL(activatedRedirect(int)) );
+    popup->disconnect( SIGNAL(highlightedRedirect(int)) );
+    disconnect( popup, SIGNAL(destroyed(QObject*)),
+		this, SLOT(popupDestroyed(QObject*)) );
 }
 
 void QMenuBar::frameChanged()
@@ -613,6 +611,11 @@ void QMenuBar::accelDestroyed()
 }
 #endif
 
+void QMenuBar::popupDestroyed( QObject *o )
+{
+    removePopup( (QPopupMenu*)o );
+}
+
 bool QMenuBar::tryMouseEvent( QPopupMenu *, QMouseEvent *e )
 {
     QPoint pos = mapFromGlobal( e->globalPos() );
@@ -665,9 +668,10 @@ void QMenuBar::openActPopup()
 
     QRect  r = itemRect( actItem );
     bool reverse = QApplication::reverseLayout();
-    QPoint pos = r.bottomLeft() + QPoint(0,1);
+    const int yoffset = 1; //(style().styleHint( QStyle::SH_GUIStyle ) == QStyle::WindowsStyle) ? 4 : 1; ### this breaks designer mainwindow editing
+    QPoint pos = r.bottomLeft() + QPoint(0,yoffset);
     if( reverse ) {
-	pos = r.bottomRight() + QPoint(0,1);
+	pos = r.bottomRight() + QPoint(0,yoffset);
 	pos.rx() -= popup->sizeHint().width();
     }
 
@@ -689,12 +693,8 @@ void QMenuBar::openActPopup()
     if ( popup->isVisible() )
 	return;
 
-    if (popup->parentMenu != this ){
-	// reuse
-	if (popup->parentMenu)
-	    popup->parentMenu->menuDelPopup(popup);
-	menuInsPopup(popup);
-    }
+    Q_ASSERT( popup->parentMenu == 0 );
+    popup->parentMenu = this;			// set parent menu
 
     popup->snapToMouse = FALSE;
     popup->popup( pos );
@@ -944,7 +944,7 @@ int QMenuBar::calculateRects( int max_width )
 	    rightSide = width()-frameWidth();
 	}
 	if ( max_height != height() )
-	    resize( max_width, max_height );
+	    resize( width(), max_height );
 	for ( i = 0; i < (int)mitems->count(); i++ ) {
 	    irects[i].setHeight( max_item_height  );
 	    QMenuItem *mi = mitems->at(i);
@@ -1181,12 +1181,12 @@ void QMenuBar::keyPressEvent( QKeyEvent *e )
 
     switch ( e->key() ) {
      case Key_Left:
-	dx = -1;
+	dx = QApplication::reverseLayout() ? 1 : -1;
 	break;
 
     case Key_Right:
     case Key_Tab:
-	dx = 1;
+	dx = QApplication::reverseLayout() ? -1 : 1;
 	break;
 
     case Key_Up:
@@ -1386,14 +1386,11 @@ void QMenuBar::setupAccelerators()
 			     SLOT(accelDestroyed()) );
 		}
 		autoaccel->insertItem( i, mi->id() );
+		autoaccel->insertItem( Key_Shift + i, mi->id() );
 	    }
 	}
 	if ( mi->popup() ) {
-	    // reuse
 	    QPopupMenu* popup = mi->popup();
-	    if (popup->parentMenu)
-		popup->parentMenu->menuDelPopup(popup);
-	    menuInsPopup(popup);
 	    popup->updateAccel( this );
 	    if ( !popup->isEnabled() )
 		popup->enableAccel( FALSE );
