@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qscrollbar.cpp   3.0.2   edited Feb 8 10:12 $
+** $Id:  qt/qscrollbar.cpp   3.0.5   edited Jun 3 11:47 $
 **
 ** Implementation of QScrollBar class
 **
@@ -583,13 +583,14 @@ void QScrollBar::mousePressEvent( QMouseEvent *e )
 	    sliderLength = sr.width();
 	} else {
 	    sliderMin = gr.y();
-	    sliderMax = sliderMax + gr.height();
+	    sliderMax = sliderMin + gr.height();
 	    sliderLength = sr.height();
 	}
 
 	int newSliderPos = (HORIZONTAL ? e->pos().x() : e->pos().y())
 			   - sliderLength/2;
 	newSliderPos = QMIN( newSliderPos, sliderMax - sliderLength );
+	newSliderPos = QMAX( newSliderPos, sliderMin );
 	setValue( sliderPosToRangeValue(newSliderPos) );
 	sliderPos = newSliderPos;
 	pressedControl = QStyle::SC_ScrollBarSlider;
@@ -621,7 +622,7 @@ void QScrollBar::mouseReleaseEvent( QMouseEvent *e )
 			  e->button() == MidButton ) )
 	return;
 
-    if ( e->stateAfter() ) // some other button is still pressed
+    if ( e->stateAfter() & MouseButtonMask ) // some other button is still pressed
 	return;
 
     QStyle::SubControl tmp = (QStyle::SubControl) pressedControl;
@@ -937,7 +938,7 @@ int QScrollBar::lineStep() const
 
 /*!
   \property QScrollBar::pageStep
-  \brief the current line step
+  \brief the current page step
 
   When setting pageStep, the virtual stepChange() function will be called
   if the new page step is different from the previous setting.
@@ -977,6 +978,17 @@ void QScrollBar::setValue( int i )
     QRangeControl::setValue( i );
 }
 
+
+/*!
+    This function is called when the scrollbar is hidden.
+*/
+void QScrollBar::hideEvent( QHideEvent* )
+{
+    pressedControl = QStyle::SC_None;
+    clickedAt = FALSE;
+}
+
+
 #undef ADD_LINE_ACTIVE
 #undef SUB_LINE_ACTIVE
 #endif
