@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qspinbox.cpp   3.0.3   edited Mar 15 12:08 $
+** $Id:  qt/qspinbox.cpp   3.0.5   edited Apr 24 16:13 $
 **
 ** Implementation of QSpinBox widget class
 **
@@ -47,7 +47,6 @@
 #include "qvalidator.h"
 #include "qpixmapcache.h"
 #include "qapplication.h"
-#include "qtimer.h"
 #include "qstyle.h"
 #if defined(QT_ACCESSIBILITY_SUPPORT)
 #include "qaccessible.h"
@@ -497,7 +496,7 @@ QSize QSpinBox::sizeHint() const
 	w = QMAX( w, fm.width( s ) + wx );
     }
 
-    return QSize( w + d->controls->downRect().width(), h + style().defaultFrameWidth() * 2 ).expandedTo( QApplication::globalStrut() );
+    return QSize( w + d->controls->downRect().width(), h + style().pixelMetric( QStyle::PM_DefaultFrameWidth ) * 2 ).expandedTo( QApplication::globalStrut() );
 }
 
 
@@ -622,21 +621,24 @@ bool QSpinBox::eventFilter( QObject* /* obj */, QEvent* ev )
     if ( ev->type() == QEvent::KeyPress ) {
 	QKeyEvent* k = (QKeyEvent*)ev;
 
+	bool retval = FALSE; // workaround for MSVC++ optimization bug
 	if( (k->key() == Key_Tab) || (k->key() == Key_BackTab) ){
 	    if ( edited )
 		interpretText();
 	    qApp->sendEvent( this, ev );
-	    return TRUE;
+	    retval = TRUE;
 	} if ( k->key() == Key_Up ) {
 	    stepUp();
-	    return TRUE;
+	    retval = TRUE;
 	} else if ( k->key() == Key_Down ) {
 	    stepDown();
-	    return TRUE;
+	    retval = TRUE;
 	} else if ( k->key() == Key_Return ) {
 	    interpretText();
 	    return FALSE;
 	}
+	if ( retval )
+	    return retval;
     } else if ( ev->type() == QEvent::FocusOut || ev->type() == QEvent::Leave || ev->type() == QEvent::Hide ) {
 	if ( edited ) {
 	    interpretText();
