@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qtabbar.cpp   3.0.2   edited Jan 10 22:15 $
+** $Id:  qt/qtabbar.cpp   3.0.5   edited Jul 3 16:41 $
 **
 ** Implementation of QTab and QTabBar classes
 **
@@ -627,11 +627,14 @@ void QTabBar::paintLabel( QPainter* p, const QRect& br,
 
 void QTabBar::paintEvent( QPaintEvent * e )
 {
-    QSharedDoubleBuffer buffer( this );
+    if ( e->rect().isNull() )
+	return;
+
+    QSharedDoubleBuffer buffer( this, e->rect() );
 
     buffer.painter()->setBrushOrigin( rect().bottomLeft() );
     buffer.painter()->fillRect( 0, 0, width(), height(),
-				QBrush( colorGroup().brush( QColorGroup::Background ) ));
+				colorGroup().brush( QColorGroup::Background ) );
     QTab * t;
     t = l->first();
     do {
@@ -646,11 +649,11 @@ void QTabBar::paintEvent( QPaintEvent * e )
 	int h = height();
 	if ( d->s == RoundedAbove ) {
 	    buffer.painter()->fillRect( 0, 3, 4, h-5,
-			QBrush( colorGroup().brush( QColorGroup::Background ) ));
+			colorGroup().brush( QColorGroup::Background ) );
 	    a.setPoints( 5,  0,2,  3,h/4, 0,h/2, 3,3*h/4, 0,h );
 	} else if ( d->s == RoundedBelow ) {
 	    buffer.painter()->fillRect( 0, 2, 4, h-5,
-			QBrush( colorGroup().brush( QColorGroup::Background ) ));
+			colorGroup().brush( QColorGroup::Background ) );
 	    a.setPoints( 5,  0,0,  3,h/4, 0,h/2, 3,3*h/4, 0,h-3 );
 	}
 
@@ -1048,27 +1051,8 @@ void QTabBar::focusInEvent( QFocusEvent * )
     QTab *t = l->first();
     for ( ; t; t = l->next() ) {
 	if ( t->id == d->focus ) {
-	    QPainter p;
-	    p.begin( this );
-	    QRect r = t->r;
-	    p.setFont( font() );
-
-	    int iw = 0;
-	    int ih = 0;
-	    if ( t->iconset != 0 ) {
-		iw = t->iconset->pixmap( QIconSet::Small, QIconSet::Normal ).width() + 4;
-		ih = t->iconset->pixmap( QIconSet::Small, QIconSet::Normal ).height();
-	    }
-	    QFontMetrics fm = p.fontMetrics();
-	    int fw = fm.width( t->label );
-	    fw -= t->label.contains('&') * fm.width('&');
-	    fw += t->label.contains("&&") * fm.width('&');
-	    int w = iw + fw + 4;
-	    int h = QMAX(fm.height() + 4, ih );
-	    paintLabel( &p, QRect( r.left() + ( r.width() -w ) /2 - 3,
-				   r.top() + ( r.height()-h ) / 2,
-				   w, h ), t, TRUE );
-	    p.end();
+	    repaint( t->r );
+	    break;
 	}
     }
 }
@@ -1081,37 +1065,8 @@ void QTabBar::focusOutEvent( QFocusEvent * )
     QTab *t = l->first();
     for ( ; t; t = l->next() ) {
 	if ( t->id == d->focus ) {
-	    QPainter p;
-	    p.begin( this );
-	    p.setBrushOrigin( rect().bottomLeft() );
-	    QRect r = t->r;
-	    p.setFont( font() );
-
-	    int iw = 0;
-	    int ih = 0;
-	    if ( t->iconset != 0 ) {
-		iw = t->iconset->pixmap( QIconSet::Small, QIconSet::Normal ).width() + 4;
-		ih = t->iconset->pixmap( QIconSet::Small, QIconSet::Normal ).height();
-	    }
-	    QFontMetrics fm = p.fontMetrics();
-	    int fw = fm.width( t->label );
-	    fw -= t->label.contains('&') * fm.width('&');
-	    fw += t->label.contains("&&") * fm.width('&');
-	    int w = iw + fw + 4;
-	    int h = QMAX(fm.height() + 4, ih );
-	    p.fillRect( QRect( r.left() + ( r.width() -w ) / 2 - 4,
-				   r.top() + ( r.height()-h ) / 2 - 1,
-			       w + 4, h + 2 ), colorGroup().brush(QColorGroup::Background ) );
-
-	    QStyle::SFlags flags = QStyle::Style_Default;
-	    flags |= QStyle::Style_Selected;
-	    style().drawControl( QStyle::CE_TabBarTab, &p, this, t->rect(),
-				 colorGroup(), flags, QStyleOption(t) );
-
-	    paintLabel( &p, QRect( r.left() + ( r.width() -w ) /2 - 3,
-				   r.top() + ( r.height()-h ) / 2,
-				   w, h ), t, FALSE );
-	    p.end();
+	    repaint( t->r );
+	    break;
 	}
     }
 }
@@ -1245,7 +1200,8 @@ void QTab::setText( const QString& text )
 	if ( p )
 	    tb->d->a->insertItem( p, id );
 #endif
-        tb->repaint();
+	tb->layoutTabs();
+	tb->repaint();
     }
 }
 
