@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qtabwidget.cpp   3.0.2   edited Nov 15 15:29 $
+** $Id:  qt/qtabwidget.cpp   3.0.5   edited Jun 28 11:02 $
 **
 ** Implementation of QTabWidget class
 **
@@ -369,8 +369,6 @@ void QTabWidget::changeTab( QWidget *w, const QString &label)
     // this will update the accelerators
     t->setText( label );
 
-    d->tabs->layoutTabs();
-
     int ct = d->tabs->currentTab();
     bool block = d->tabs->signalsBlocked();
     d->tabs->blockSignals( TRUE );
@@ -399,10 +397,8 @@ void QTabWidget::changeTab( QWidget *w, const QIconSet& iconset, const QString &
         t->iconset = 0;
     }
     // this will update the accelerators
-    t->setText( label );
     t->iconset = new QIconSet( iconset );
-
-     d->tabs->layoutTabs();
+    t->setText( label );
 
     int ct = d->tabs->currentTab();
     bool block = d->tabs->signalsBlocked();
@@ -519,7 +515,7 @@ void QTabWidget::setTabLabel( QWidget * w, const QString &l )
 
 QWidget * QTabWidget::currentPage() const
 {
-    return d->stack->visibleWidget();
+    return page( currentPageIndex() );
 }
 
 /*! \property QTabWidget::autoMask
@@ -640,7 +636,7 @@ void QTabWidget::setUpLayout( bool onlyCheck )
 	exty = taby - (exth - overlap);
     } else { // Top
 	taby = 0;
-	stacky = t.height()-lw + (exth - overlap), width();
+	stacky = t.height()-lw + (exth - overlap);
 	exty = taby + t.height() - overlap;
     }
 
