@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qtoolbar.cpp   3.0.2   edited Feb 6 16:52 $
+** $Id:  qt/qtoolbar.cpp   3.0.5   edited May 13 18:33 $
 **
 ** Implementation of QToolBar class
 **
@@ -317,7 +317,6 @@ QToolBar::QToolBar( const QString &label,
 
 
 /*!
-    \overload
 
     Constructs an empty horizontal toolbar.
 
@@ -605,6 +604,7 @@ void QToolBar::resizeEvent( QResizeEvent *e )
 	QObjectListIt it( *children() );
 	bool hide = FALSE;
 	bool doHide = FALSE;
+	bool noButtons = TRUE;
 	d->extensionPopup->clear();
 	d->hiddenItems.clear();
 	while ( it.current() ) {
@@ -615,16 +615,18 @@ void QToolBar::resizeEvent( QResizeEvent *e )
 	    }
 	    QWidget *w = (QWidget*)it.current();
 	    hide = FALSE;
+	    QPoint p = w->parentWidget()->mapTo( this, w->geometry().bottomRight() );
 	    if ( orientation() == Horizontal ) {
-		if ( w->x() + w->width() > e->size().width() )
+		if ( p.x() > e->size().width()-d->extension->width()/2 )
 		    hide = TRUE;
 	    } else {
-		if ( w->y() + w->height() > e->size().height() )
+		if ( p.y() > e->size().height()-d->extension->height()/2 )
 		    hide = TRUE;
 	    }
-	    if ( hide ) {
+	    if ( hide && !w->isHidden() ) {
 		doHide = TRUE;
 		if ( w->inherits( "QToolButton" ) ) {
+		    noButtons = FALSE;
 		    QToolButton *b = (QToolButton*)w;
 		    QString s = b->textLabel();
 		    if ( s.isEmpty() )
@@ -641,6 +643,7 @@ void QToolBar::resizeEvent( QResizeEvent *e )
 		    if ( !b->isEnabled() )
 			d->extensionPopup->setItemEnabled( id, FALSE );
 		} else if ( w->inherits( "QButton" ) ) {
+		    noButtons = FALSE;
 		    QButton *b = (QButton*)w;
 		    QString s = b->text();
 		    if ( s.isEmpty() )
@@ -659,11 +662,11 @@ void QToolBar::resizeEvent( QResizeEvent *e )
 	    }
 	    ++it;
 	}
-	if ( doHide ) {
+	if ( doHide && !noButtons ) {
 	    if ( orientation() == Horizontal )
-		d->extension->setGeometry( width() - 20, 1, 20, height() - 2 );
+	        d->extension->setGeometry( width() - 20, 1, 20, height() - 2 );
 	    else
-		d->extension->setGeometry( 1, height() - 20, width() - 2, 20 );
+	        d->extension->setGeometry( 1, height() - 20, width() - 2, 20 );
 	    d->extension->show();
 	    d->extension->raise();
 	} else {
