@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qtoolbutton.cpp   3.0.3   edited Nov 27 19:11 $
+** $Id:  qt/qtoolbutton.cpp   3.0.5   edited May 28 02:49 $
 **
 ** Implementation of QToolButton class
 **
@@ -236,7 +236,9 @@ QToolButton::QToolButton( const QIconSet& iconSet, const QString &textLabel,
 			   parent->mainWindow()->toolTipGroup(), grouptext );
 	else
 	    QToolTip::add( this, textLabel );
-    }
+    } else if ( !grouptext.isEmpty() )
+	QToolTip::add( this, 0,
+		parent->mainWindow()->toolTipGroup(), grouptext );
 #endif
 }
 
@@ -287,11 +289,13 @@ QSize QToolButton::sizeHint() const
      	QPixmap pm = iconSet().pixmap( QIconSet::Large, QIconSet::Normal );
      	w = pm.width();
      	h = pm.height();
-     	if ( w < 32 )
-     	    w = 32;
-     	if ( h < 32 )
-     	    h = 32;
+	QSize iconSize = QIconSet::iconSize( QIconSet::Large );
+	if ( w < iconSize.width() )
+     	    w = iconSize.width();
+     	if ( h < iconSize.height() )
+     	    h = iconSize.height();
     } else {
+	// ### in 3.1, use QIconSet::iconSize( QIconSet::Small );
      	QPixmap pm = iconSet().pixmap( QIconSet::Small, QIconSet::Normal );
      	w = pm.width();
      	h = pm.height();
