@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qtooltip.cpp   3.0.2   edited Feb 6 15:40 $
+** $Id:  qt/qtooltip.cpp   3.0.5   edited May 13 14:21 $
 **
 ** Tool Tips (or Balloon Help) for any widget or rectangle
 **
@@ -208,9 +208,13 @@ void QTipManager::add( const QRect &gm, QWidget *w,
     t->group = g;
     t->geometry = gm;
 
-    if ( h )
+    if ( h ) {
 	tips->take( w );
-    else
+	if (h->autoDelete) {
+	    t->next = h->next;
+	    delete(h);
+	}
+    } else
 	connect( w, SIGNAL(destroyed()), this, SLOT(clientWidgetDestroyed()) );
 
     tips->insert( w, t );
@@ -431,6 +435,7 @@ bool QTipManager::eventFilter( QObject *obj, QEvent *e )
 			 !t->group->del && !t->groupText.isEmpty() ) {
 			removeTimer->stop();
 			emit t->group->showTip( t->groupText );
+			currentTip = t;
 		    }
 		}
 		widget = w;
@@ -466,7 +471,7 @@ void QTipManager::showTip()
     if ( t == 0 )
 	return;
 
-    if (  t == currentTip )
+    if ( t == currentTip && label && label->isVisible() )
 	return; // nothing to do
 
     if ( t->tip ) {
@@ -501,19 +506,27 @@ void QTipManager::showTip()
 	Q_CHECK_PTR( label );
 	connect( label, SIGNAL(destroyed()), SLOT(labelDestroyed()) );
     }
+    int scr = QApplication::desktop()->screenNumber( widget );
+    QRect screen = QApplication::desktop()->screenGeometry( scr );
     QPoint p;
     if ( t->geometry == QRect( -1, -1, -1, -1 ) ) {
 	p = widget->mapToGlobal( pos ) + QPoint( 2, 16 );
+	if ( p.x() + label->width() > screen.x() + screen.width() )
+	    p.rx() -= 4 + label->width();
+	if ( p.y() + label->height() > screen.y() + screen.height() )
+	    p.ry() -= 24 + label->height();
     } else {
 	p = widget->mapToGlobal( t->geometry.topLeft() );
 	label->setAlignment( WordBreak | AlignCenter );
 	int h = label->heightForWidth( t->geometry.width() - 4 );
 	label->resize( label->width(), h );
     }
-    int scr = QApplication::desktop()->screenNumber( widget );
-    QRect screen = QApplication::desktop()->screenGeometry( scr );
+    if ( p.y() < screen.y() )
+	p.setY( screen.y() );
     if ( p.x() + label->width() > screen.x() + screen.width() )
 	p.setX( screen.x() + screen.width() - label->width() );
+    if ( p.x() < screen.x() )
+	p.setX( screen.x() );
     if ( p.y() + label->height() > screen.y() + screen.height() )
 	p.setY( screen.y() + screen.height() - label->height() );
     if ( label->text().length() ) {
@@ -561,6 +574,8 @@ void QTipManager::hideTip()
 	if ( currentTip && currentTip->group &&
 	     !currentTip->group->del && !currentTip->groupText.isEmpty() )
 	    removeTimer->start( 100, TRUE );
+    } else if ( currentTip && currentTip->group ) {
+	removeTimer->start( 100, TRUE );
     }
 
     previousTip = currentTip;
