@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id:  qt/qworkspace.cpp   3.0.2   edited Dec 11 13:07 $
+** $Id:  qt/qworkspace.cpp   3.0.5   edited Jul 2 18:53 $
 **
 ** Implementation of the QWorkspace class
 **
@@ -64,61 +64,61 @@
 
 
 /*!
-  \class QWorkspace qworkspace.h
-  \brief The QWorkspace widget provides a workspace window that can
-  contain decorated windows, e.g. for MDI.
+    \class QWorkspace qworkspace.h
+    \brief The QWorkspace widget provides a workspace window that can
+    contain decorated windows, e.g. for MDI.
 
-  \module workspace
+    \module workspace
 
-  \ingroup application
-  \ingroup organizers
-  \mainclass
+    \ingroup application
+    \ingroup organizers
+    \mainclass
 
-  An MDI (multiple document interface) application has one main window
-  with a menu bar.  The central widget of this window is a workspace.
-  The workspace itself contains zero, one or more document windows,
-  each of which displays a document.
+    An MDI (multiple document interface) application has one main
+    window with a menu bar. The central widget of this window is a
+    workspace. The workspace itself contains zero, one or more
+    document windows, each of which displays a document.
 
-  The workspace itself is an ordinary Qt widget.  It has a standard
-  constructor that takes a parent widget and an object name.  The
-  parent window is usually a QMainWindow, but it need not be.
+    The workspace itself is an ordinary Qt widget. It has a standard
+    constructor that takes a parent widget and an object name. The
+    parent window is usually a QMainWindow, but it need not be.
 
-  Document windows (i.e. MDI windows) are also ordinary Qt widgets which
-  have the workspace as parent widget.  When you call show(), hide(),
-  showMaximized(), setCaption(), etc. on a document window, it is shown,
-  hidden, etc. with a frame, caption, icon and icon text, just as you'd
-  expect. You can provide widget flags which will be used for the layout
-  of the decoration or the behaviour of the widget itself.
+    Document windows (i.e. MDI windows) are also ordinary Qt widgets
+    which have the workspace as parent widget. When you call show(),
+    hide(), showMaximized(), setCaption(), etc. on a document window,
+    it is shown, hidden, etc. with a frame, caption, icon and icon
+    text, just as you'd expect. You can provide widget flags which
+    will be used for the layout of the decoration or the behaviour of
+    the widget itself.
 
-  To change the geometry of the MDI windows it is necessary to make the
-  function calls to the parentWidget() of the widget, as this
-  will move or resize the decorated window.
+    To change the geometry of the MDI windows it is necessary to make
+    the function calls to the parentWidget() of the widget, as this
+    will move or resize the decorated window.
 
-  A document window becomes active when it gets the keyboard focus.
-  You can activate it using setFocus(), and the user can activate it
-  by moving focus in the normal ways.  The workspace emits a signal
-  windowActivated() when it detects the activation change, and the
-  function activeWindow() always returns a pointer to the active
-  document window.
+    A document window becomes active when it gets the keyboard focus.
+    You can activate it using setFocus(), and the user can activate it
+    by moving focus in the normal ways. The workspace emits a signal
+    windowActivated() when it detects the activation change, and the
+    function activeWindow() always returns a pointer to the active
+    document window.
 
-  The convenience function windowList() returns a list of all document
-  windows.  This is useful to create a popup menu "<u>W</u>indows" on the
-  fly, for example.
+    The convenience function windowList() returns a list of all
+    document windows. This is useful to create a popup menu
+    "<u>W</u>indows" on the fly, for example.
 
-  QWorkspace provides two built-in layout strategies for child
-  windows: cascade() and tile().  Both are slots so you can easily
-  connect menu entries to them.
+    QWorkspace provides two built-in layout strategies for child
+    windows: cascade() and tile(). Both are slots so you can easily
+    connect menu entries to them.
 
-  If you want your users to be able to work with document windows
-  larger than the actual workspace, set the scrollBarsEnabled property
-  to TRUE.
-
-  If the top-level window contains a menu bar and a document window is
-  maximised, QWorkspace moves the document window's minimize, restore
-  and close buttons from the document window's frame to the workspace
-  window's menu bar. It then inserts a window operations menu at the
-  extreme left of the menu bar.
+    If you want your users to be able to work with document windows
+    larger than the actual workspace, set the scrollBarsEnabled
+    property to TRUE.
 
+    If the top-level window contains a menu bar and a document window
+    is maximised, QWorkspace moves the document window's minimize,
+    restore and close buttons from the document window's frame to the
+    workspace window's menu bar. It then inserts a window operations
+    menu at the far left of the menu bar.
 */
 
 static bool inCaptionChange = FALSE;
@@ -463,12 +463,6 @@ void QWorkspace::activateWindow( QWidget* w, bool change_focus )
     }
 
     d->active->internalRaise();
-    if ( d->vbar )
-	d->vbar->raise();
-    if ( d->hbar )
-	d->hbar->raise();
-    if ( d->corner )
-	d->corner->raise();
 
     if ( change_focus ) {
 	if ( d->focus.find( d->active ) >=0 ) {
@@ -477,6 +471,7 @@ void QWorkspace::activateWindow( QWidget* w, bool change_focus )
 	}
     }
 
+    updateWorkspace();
     emit windowActivated( w );
 }
 
@@ -519,7 +514,10 @@ void QWorkspace::place( QWidget* w)
 		l = it.current();
 		++it;
 		if (! d->icons.contains(l) && ! l->isHidden() && l != w ) {
-		    r2.setRect(l->x(), l->y(), l->width(), l->height());
+		    if ( d->maxWindow == l )
+			r2 = d->maxRestore;
+		    else
+			r2.setRect(l->x(), l->y(), l->width(), l->height());
 
 		    if (r2.intersects(r1)) {
 			r2.setCoords(QMAX(r1.left(), r2.left()),
@@ -558,7 +556,10 @@ void QWorkspace::place( QWidget* w)
 		l = it.current();
 		++it;
 		if (! d->icons.contains(l) && ! l->isHidden() && l != w ) {
-		    r2.setRect(l->x(), l->y(), l->width(), l->height());
+		    if ( d->maxWindow == l )
+			r2 = d->maxRestore;
+		    else
+			r2.setRect(l->x(), l->y(), l->width(), l->height());
 
 		    if( ( y < r2.bottom() ) && ( r2.top() < w->height() + y ) ) {
 			if( r2.right() > x )
@@ -585,7 +586,10 @@ void QWorkspace::place( QWidget* w)
 		l = it.current();
 		++it;
 		if (l != w && ! d->icons.contains(w)) {
-		    r2.setRect(l->x(), l->y(), l->width(), l->height());
+		    if ( d->maxWindow == l )
+			r2 = d->maxRestore;
+		    else
+			r2.setRect(l->x(), l->y(), l->width(), l->height());
 
 		    if( r2.bottom() > y)
 			possible = possible < r2.bottom() ?
@@ -727,7 +731,7 @@ void QWorkspace::minimizeWindow( QWidget* w)
 		topLevelWidget()->setCaption( d->topCaption );
 #endif
 	    inCaptionChange = FALSE;
-	    if ( !style().styleHint(QStyle::SH_Workspace_FillSpaceOnMaximize, this) && d->maxWindow )
+	    if ( !style().styleHint(QStyle::SH_Workspace_FillSpaceOnMaximize, this) )
 		hideMaximizeControls();
 	    for (QPtrListIterator<QWorkspaceChild> it( d->windows ); it.current(); ++it ) {
 		QWorkspaceChild* c = it.current();
@@ -737,7 +741,13 @@ void QWorkspace::minimizeWindow( QWidget* w)
 	    }
 	}
 	insertIcon( c->iconWidget() );
+	bool wasFocused = c->titlebar->isActive();
 	c->hide();
+	if ( wasFocused && d->active && d->active->testWState( WState_Minimized ) ) {
+	    blockSignals( TRUE );
+	    activateWindow( w, FALSE );
+	    blockSignals( FALSE );
+	}
 	if ( wasMax )
 	    c->setGeometry( d->maxRestore );
 	d->focus.append( c );
@@ -862,6 +872,8 @@ void QWorkspace::showWindow( QWidget* w)
 	maximizeWindow( w );
     else if ( !w->testWFlags( WStyle_Tool ) )
 	normalizeWindow( w );
+    else
+	w->parentWidget()->show();
     if ( d->maxWindow )
 	d->maxWindow->raise();
     updateWorkspace();
@@ -890,7 +902,8 @@ QWidgetList QWorkspace::windowList() const
     while ( it.current () ) {
 	QWorkspaceChild* c = it.current();
 	++it;
-	windows.append( c->windowWidget() );
+	if ( c->windowWidget() )
+	    windows.append( c->windowWidget() );
     }
     return windows;
 }
@@ -1025,10 +1038,20 @@ void QWorkspace::showMaximizeControls()
 #ifndef QT_NO_MENUBAR
     Q_ASSERT(d->maxWindow);
     QMenuBar* b = 0;
-
-    // Do a breadth-first search first, and query recoursively if nothing is found.
-    QObjectList * l = topLevelWidget()->queryList( "QMenuBar", 0,
-						   FALSE, FALSE );
+    
+    // Do a breadth-first search first on every parent, 
+    QWidget* w = parentWidget();
+    QObjectList * l = 0;
+    while ( !l && w ) {
+	l = w->queryList( "QMenuBar", 0, FALSE, FALSE );
+	w = w->parentWidget();	
+	if ( l && !l->count() ) {
+	    delete l;
+	    l = 0;
+	}
+    } 
+    
+    // and query recursively if nothing is found.
     if ( !l || !l->count() ) {
 	if ( l )
 	    delete l;
@@ -1371,7 +1394,7 @@ void QWorkspace::cascade()
 	d->hbar->setValue( 0 );
 	d->hbar->blockSignals( FALSE );
 	scrollBarChanged();
-    }   
+    }
 
     const int xoffset = 13;
     const int yoffset = 20;
@@ -1444,7 +1467,7 @@ void QWorkspace::tile()
 	d->hbar->setValue( 0 );
 	d->hbar->blockSignals( FALSE );
 	scrollBarChanged();
-    }   
+    }
 
     int rows = 1;
     int cols = 1;
@@ -1502,7 +1525,7 @@ void QWorkspace::tile()
 	    qApp->sendPostedEvents( 0, QEvent::ShowNormal );
 	    used[row*cols+col] = TRUE;
 	    if ( add ) {
-		c->setGeometry( col*w, row*h, QMIN( w, c->windowWidget()->maximumWidth()+c->baseSize().width() ), 
+		c->setGeometry( col*w, row*h, QMIN( w, c->windowWidget()->maximumWidth()+c->baseSize().width() ),
 					      QMIN( 2*h, c->windowWidget()->maximumHeight()+c->baseSize().height() ) );
 		used[(row+1)*cols+col] = TRUE;
 		add--;
@@ -1604,8 +1627,15 @@ QWorkspaceChild::QWorkspaceChild( QWidget* window, QWorkspace *parent,
     int th = titlebar ? titlebar->sizeHint().height() : 0;
     if ( titlebar ) {
 #ifndef QT_NO_WIDGET_TOPEXTRA
-	if( childWidget->icon() )
-	    titlebar->setIcon( *childWidget->icon() );
+	if( childWidget->icon() ) {
+	    QPixmap pm(*childWidget->icon());
+	    if(pm.width() != 14 || pm.height() != 14) {
+		QImage im;
+		im = pm;
+		pm = im.smoothScale( 14, 14 );
+	    }
+	    titlebar->setIcon( pm );
+	}
 #endif
 	p = QPoint( contentsRect().x(),
 		    th + contentsRect().y() );
@@ -1733,6 +1763,12 @@ bool QWorkspaceChild::eventFilter( QObject * o, QEvent * e)
 	((QWorkspace*)parentWidget())->showWindow( windowWidget() );
 	break;
     case QEvent::ShowMaximized:
+	if ( windowWidget()->maximumSize().isValid() &&
+	     ( windowWidget()->maximumWidth() < parentWidget()->width() ||
+	       windowWidget()->maximumHeight() < parentWidget()->height() ) ) {
+	    windowWidget()->resize( windowWidget()->maximumSize() );
+	    break;
+	}
 	if ( windowWidget()->testWFlags( WStyle_Maximize ) && !windowWidget()->testWFlags( WStyle_Tool ) )
 	    ((QWorkspace*)parentWidget())->maximizeWindow( windowWidget() );
 	else
@@ -1975,7 +2011,7 @@ void QWorkspaceChild::setActive( bool b )
 		 lastfocusw->focusPolicy() != NoFocus ) {
 		// this is a bug if lastfocusw has been deleted, a new
 		// widget has been created, and the new one is a child
-		// of the same window as the old one.  but even though
+		// of the same window as the old one. but even though
 		// it's a bug the behaviour is reasonable
 		lastfocusw->setFocus();
 	    } else if ( childWidget->focusPolicy() != NoFocus ) {
@@ -2055,34 +2091,17 @@ QWidget* QWorkspaceChild::iconWidget() const
 
 void QWorkspaceChild::showMinimized()
 {
-    Q_ASSERT( windowWidget()->testWFlags( WStyle_Minimize ) && !windowWidget()->testWFlags( WStyle_Tool ) );
     QApplication::postEvent( windowWidget(), new QEvent( QEvent::ShowMinimized ) );
-    if ( titlebar )
-	titlebar->setMovable( TRUE );
-    widgetResizeHandler->setActive( FALSE );
 }
 
 void QWorkspaceChild::showMaximized()
 {
-    if ( windowWidget()->maximumSize().isValid() &&
-	( windowWidget()->maximumWidth() < parentWidget()->width() || windowWidget()->maximumHeight() < parentWidget()->height() ) ) {
-	windowWidget()->resize( windowWidget()->maximumSize() );
-	return;
-    }
-    Q_ASSERT( windowWidget()->testWFlags( WStyle_Maximize ) && !windowWidget()->testWFlags( WStyle_Tool ) );
     QApplication::postEvent( windowWidget(), new QEvent( QEvent::ShowMaximized ) );
-    if ( titlebar )
-	titlebar->setMovable( FALSE );
-    widgetResizeHandler->setActive( FALSE );
 }
 
 void QWorkspaceChild::showNormal()
 {
-    Q_ASSERT( windowWidget()->testWFlags( WStyle_MinMax ) && !windowWidget()->testWFlags( WStyle_Tool ) );
     QApplication::postEvent( windowWidget(), new QEvent( QEvent::ShowNormal ) );
-    if ( titlebar )
-	titlebar->setMovable( TRUE );
-    widgetResizeHandler->setActive( TRUE );
 }
 
 void QWorkspaceChild::showShaded()
@@ -2290,8 +2309,8 @@ QRect QWorkspace::updateWorkspace()
 	int vsbExt = d->vbar->sizeHint().width();
 
 
-	bool showv = d->yoffset || d->yoffset + r.bottom() - height() + 1 > 0;
-	bool showh = d->xoffset || d->xoffset + r.right() - width() + 1 > 0;
+	bool showv = d->yoffset || d->yoffset + r.bottom() - height() + 1 > 0 || d->yoffset + r.top() < 0;
+	bool showh = d->xoffset || d->xoffset + r.right() - width() + 1 > 0 || d->xoffset + r.left() < 0;
 
 	if ( showh && !showv)
 	    showv = d->yoffset + r.bottom() - height() + hsbExt + 1 > 0;
@@ -2305,7 +2324,7 @@ QRect QWorkspace::updateWorkspace()
 
 	if ( showv ) {
 	    d->vbar->setSteps( QMAX( height() / 12, 30 ), height()  - hsbExt );
-	    d->vbar->setRange( 0, d->yoffset + QMAX( 0, r.bottom() - height() + hsbExt + 1) );
+	    d->vbar->setRange( QMIN( 0, d->yoffset + QMIN( 0, r.top() ) ), QMAX( 0, d->yoffset + QMAX( 0, r.bottom() - height() + hsbExt + 1) ) );
 	    d->vbar->setGeometry( width() - vsbExt, 0, vsbExt, height() - hsbExt );
 	    d->vbar->setValue( d->yoffset );
 	    d->vbar->show();
@@ -2315,7 +2334,7 @@ QRect QWorkspace::updateWorkspace()
 
 	if ( showh ) {
 	    d->hbar->setSteps( QMAX( width() / 12, 30 ), width() - vsbExt );
-	    d->hbar->setRange( 0, d->xoffset + QMAX( 0, r.right() - width() + vsbExt  + 1) );
+	    d->hbar->setRange( QMIN( 0, d->xoffset + QMIN( 0, r.left() ) ), QMAX( 0, d->xoffset + QMAX( 0, r.right() - width() + vsbExt  + 1) ) );
 	    d->hbar->setGeometry( 0, height() - hsbExt, width() - vsbExt, hsbExt );
 	    d->hbar->setValue( d->xoffset );
 	    d->hbar->show();
