@@ -50,7 +50,7 @@ static QString make_func_pretty( const QString &s )
 
 FormFile::FormFile( const QString &fn, bool temp, Project *p )
     : filename( fn ), fileNameTemp( temp ), pro( p ), fw( 0 ), ed( 0 ),
-      timeStamp( 0, fn + codeExtension() ), codeEdited( FALSE )
+      timeStamp( 0, fn + codeExtension() ), codeEdited( FALSE ), cm( FALSE )
 {
     LanguageInterface *iface = MetaDataBase::languageInterface( pro->language() );
     if ( iface )
@@ -143,7 +143,7 @@ QString FormFile::code()
 	createSource = FALSE;
 	txt = cod;
     }
-    if ( createSource ) {
+    if ( iface && createSource ) {
 	QValueList<MetaDataBase::Slot> slotList = MetaDataBase::slotList( formWindow() );
 	QMap<QString, QString> bodies = MetaDataBase::functionBodies( formWindow() );
 	for ( QValueList<MetaDataBase::Slot>::Iterator it = slotList.begin(); it != slotList.end(); ++it ) {
@@ -177,6 +177,8 @@ bool FormFile::save( bool withMsgBox )
 	return TRUE;
     if ( ed )
 	ed->save();
+    else if ( !cm )
+	loadCode();
 
     if ( isModified( WFormWindow ) ) {
 	if ( withMsgBox ) {
@@ -194,7 +196,7 @@ bool FormFile::save( bool withMsgBox )
 	    QFile f( pro->makeAbsolute( filename ) );
 	    if ( f.open( IO_ReadOnly ) ) {
 		QFile f2( fn );
-		if ( f2.open( IO_WriteOnly ) ) {
+		if ( f2.open( IO_WriteOnly | IO_Translate ) ) {
 		    QCString data( f.size() );
 		    f.readBlock( data.data(), f.size() );
 		    f2.writeBlock( data );
@@ -205,6 +207,7 @@ bool FormFile::save( bool withMsgBox )
 	}
     }
 
+    cm = FALSE;
     if ( isModified( WFormCode ) && seperateSource ) {
 	if ( QFile::exists( pro->makeAbsolute( codeFile() ) ) ) {
 	    QString fn( pro->makeAbsolute( codeFile() ) );
@@ -216,7 +219,7 @@ bool FormFile::save( bool withMsgBox )
 	    QFile f( pro->makeAbsolute( codeFile() ) );
 	    if ( f.open( IO_ReadOnly ) ) {
 		QFile f2( fn );
-		if ( f2.open( IO_WriteOnly ) ) {
+		if ( f2.open( IO_WriteOnly | IO_Translate) ) {
 		    QCString data( f.size() );
 		    f.readBlock( data.data(), f.size() );
 		    f2.writeBlock( data );
@@ -363,7 +366,7 @@ bool FormFile::isFormWindowModified() const
 bool FormFile::isCodeModified() const
 {
     if ( !editor() )
-	return FALSE;
+	return cm;
     return editor()->isModified();
 }
 
@@ -383,10 +386,11 @@ void FormFile::setCodeModified( bool m )
     bool b = isCodeModified();
     if ( m == b )
 	return;
+    emit somethingChanged( this );
+    cm = TRUE;
     if ( !editor() )
 	return;
     editor()->setModified( m );
-    emit somethingChanged( this );
 }
 
 void FormFile::showFormWindow()
@@ -504,9 +508,11 @@ void FormFile::parseCode( const QString &txt, bool allowModify )
     for ( QValueList<LanguageInterface::Function>::Iterator it = functions.begin();
 	  it != functions.end(); ++it ) {
 	bool found = FALSE;
-	for ( QValueList<MetaDataBase::Slot>::Iterator sit = oldSlots.begin(); sit != oldSlots.end(); ++sit ) {
+	for ( QValueList<MetaDataBase::Slot>::Iterator sit = oldSlots.begin();
+	      sit != oldSlots.end(); ++sit ) {
 	    QString s( (*sit).slot );
-	    if ( MetaDataBase::normalizeSlot( s ) == MetaDataBase::normalizeSlot( (*it).name ) ) {
+	    if ( MetaDataBase::normalizeSlot( s ) ==
+		 MetaDataBase::normalizeSlot( (*it).name ) ) {
 		found = TRUE;
 		MetaDataBase::Slot slot;
 		slot.slot = make_func_pretty( (*it).name );
@@ -535,6 +541,9 @@ void FormFile::parseCode( const QString &txt, bool allowModify )
 	MetaDataBase::setFunctionComments( formWindow(), (*it).name, (*it).comments );
     }
 
+    if ( allowModify && oldSlots.count() > 0 )
+	setFormWindowModified( TRUE );
+	
     MetaDataBase::setSlotList( formWindow(), newSlots );
     MetaDataBase::setFunctionBodies( formWindow(), funcs, pro->language(), QString::null );
 }
@@ -585,7 +594,9 @@ void FormFile::addSlotCode( MetaDataBase::Slot slot )
 	if ( !codeEdited && !timeStamp.isUpToDate() )
 	    loadCode();
 	MetaDataBase::MetaInfo mi = MetaDataBase::metaInfo( formWindow() );
-	QString cn = mi.className;
+	QString cn;
+	if ( mi.classNameChanged )
+	    cn = mi.className;
 	if ( cn.isEmpty() )
 	    cn = formWindow()->name();
 	QString body = "\n\n" + iface->createFunctionStart( cn,
@@ -595,8 +606,8 @@ void FormFile::addSlotCode( MetaDataBase::Slot slot )
 							    slot.returnType ) +
 		       "\n" + iface->createEmptyFunction();
 	cod += body;
-	functionBodies.insert( MetaDataBase::normalizeSlot( slot.slot ), iface->createEmptyFunction() );
-	MetaDataBase::setFunctionBodies( formWindow(), functionBodies, pro->language(), slot.returnType );
+	MetaDataBase::addFunctionBody( formWindow(),
+				       MetaDataBase::normalizeSlot( slot.slot ), iface->createEmptyFunction() );
 	if ( codeEdited ) {
 	    setModified( TRUE );
 	    emit somethingChanged( this );
