@@ -315,23 +315,30 @@ QStringList parse_multiline_part( const QString &contents, const QString &key, i
 	    QStringList lst;
 	    bool inName = FALSE;
 	    QString currName;
-	    bool hadEqual = 0;
+	    bool hadEqual = FALSE;
 	    for ( ; i < (int)contents.length(); ++i ) {
 		c = contents[ i ];
 		if ( !hadEqual && c != '=' )
 		    continue;
-		hadEqual = TRUE;
-		if ( ( c.isLetter() || c.isDigit() || c == '.' || c == '/' || c == '_' ||
+		if ( !hadEqual ) {
+		    hadEqual = TRUE;
+		    continue;
+		}
+		if ( ( c.isLetter() || c.isDigit() || c == '.' || c == '/' || c == '_' || c == '\\' ||
+		       c == '\"' || c == '\'' || c == '=' ||
 		       c == '$' || c == '-' || c == '(' || c == ')' || c == ':'  || c == '+' || c == ',' ) &&
-		     c != ' ' && c != '\t' && c != '\n' && c != '=' && c != '\\' ) {
+		     c != ' ' && c != '\t' && c != '\n' ) {
 		    if ( !inName )
 			currName = QString::null;
-		    currName += c;
-		    inName = TRUE;
+		    if ( c != '\\' || contents[i+1] != '\n' ) {
+			currName += c;
+			inName = TRUE;
+		    }
 		} else {
 		    if ( inName ) {
 			inName = FALSE;
-			lst.append( currName );
+			if ( currName.simplifyWhiteSpace() != "\\" )
+			    lst.append( currName );
 		    }
 		    if ( c == '\n' && i > 0 && contents[ (int)i - 1 ] != '\\' )
 			break;
@@ -635,7 +642,7 @@ void Project::save( bool onlyProjectFile )
 	    contents += *it + "\t= " + val + "\n";
     }
 
-    if ( !f.open( IO_WriteOnly ) ) {
+    if ( !f.open( IO_WriteOnly | IO_Translate ) ) {
 	QMessageBox::warning( MainWindow::self, "Save Project Failed", "Couldn't write project file " + filename );
 	return;
     }
@@ -760,7 +767,7 @@ void Project::saveConnections()
 
     /* .db xml */
     QFile f( makeAbsolute( dbFile ) );
-    if ( f.open( IO_WriteOnly ) ) {
+    if ( f.open( IO_WriteOnly | IO_Translate ) ) {
 	QTextStream ts( &f );
 	ts.setCodec( QTextCodec::codecForName( "UTF-8" ) );
 	ts << "<!DOCTYPE DB><DB version=\"1.0\">" << endl;
