@@ -425,7 +425,7 @@ bool Resource::save( const QString& filename, bool formCodeOnly )
     currFileName = filename;
 
     QFile f( filename );
-    if ( !f.open( IO_WriteOnly ) )
+    if ( !f.open( IO_WriteOnly | IO_Translate ) )
 	return FALSE;
     bool b = save( &f );
     f.close();
@@ -951,8 +951,10 @@ void Resource::saveObjectProperties( QObject *w, QTextStream &ts, int indent )
     changed = MetaDataBase::changedProperties( w );
     if ( w->isWidgetType() ) {
 	if ( w->inherits( "Spacer" ) ) {
-	    if ( changed.find( "sizeHint" ) == changed.end() )
+	    if ( !changed.contains( "sizeHint" ) )
 		changed << "sizeHint";
+	    if ( !changed.contains( "geometry" ) )
+		changed << "geometry";
 	}
     } else if ( w->inherits( "QLayout" ) ) { // #### should be cleaner (RS)
 	changed << "margin" << "spacing";
@@ -993,7 +995,7 @@ void Resource::saveObjectProperties( QObject *w, QTextStream &ts, int indent )
 	    knownNames << w->property( "name" ).toString();
 	ts << makeIndent( indent ) << "<property";
 	ts << " name=\"" << it.current() << "\"";
-	if ( !p->testFlags( QMetaProperty::StdSet ) )
+	if ( !p->stdSet() )
 	    ts << " stdset=\"0\"";
 	ts << ">" << endl;
 	indent++;
@@ -1575,13 +1577,13 @@ QWidget *Resource::createSpacer( const QDomElement &e, QWidget *parent, QLayout
     Spacer *spacer = (Spacer*) WidgetFactory::create( WidgetDatabase::idFromClassName("Spacer"),
 						      parent, "spacer", FALSE);
     spacer->setOrientation( o );
-    spacer->setAutoResize( FALSE );
+    spacer->setInteraciveMode( FALSE );
     while ( !n.isNull() ) {
 	if ( n.tagName() == "property" )
 	    setObjectProperty( spacer, n.attribute( "name" ), n.firstChild().toElement() );
 	n = n.nextSibling().toElement();
     }
-    spacer->setAutoResize( TRUE );
+    spacer->setInteraciveMode( TRUE );
     if ( formwindow )
 	formwindow->insertWidget( spacer, pasting );
     if ( layout ) {
@@ -1765,7 +1767,7 @@ void Resource::saveImageData( const QImage &img, QTextStream &ts, int indent )
 {
     QByteArray ba;
     QBuffer buf( ba );
-    buf.open( IO_WriteOnly );
+    buf.open( IO_WriteOnly | IO_Translate );
     QImageIO iio( &buf, "XPM" );
     iio.setImage( img );
     iio.write();
@@ -2598,10 +2600,12 @@ void Resource::saveFormCode()
 	return;
     QMap<QString, QString> functionBodies = MetaDataBase::functionBodies( formwindow );
     if ( langIface->supports( LanguageInterface::StoreFormCodeSeperate ) ) {
-	if ( formwindow->formFile()->code().isEmpty() || !formwindow->formFile()->hasFormCode() )
+	if ( formwindow->formFile()->hasTempFileName() ||
+	     formwindow->formFile()->code().isEmpty() ||
+	     !formwindow->formFile()->hasFormCode() )
 	    return;
 	QFile f( formwindow->project()->makeAbsolute( formwindow->formFile()->codeFile() ) );
-	if ( f.open( IO_WriteOnly ) ) {
+	if ( f.open( IO_WriteOnly | IO_Translate ) ) {
 	    QTextStream ts( &f );
 	    ts << formwindow->formFile()->code();
 	}
