@@ -1,7 +1,7 @@
 #ifndef CINDENT_H
 #define CINDENT_H
 
-#include <qrichtext_p.h>
+#include <private/qrichtext_p.h>
 #include "dlldefs.h"
 
 class EDITOR_EXPORT CIndent : public QTextIndent
@@ -9,7 +9,7 @@ class EDITOR_EXPORT CIndent : public QTextIndent
 public:
     CIndent();
     virtual ~CIndent() {}
-    void indent( QTextDocument *doc, QTextParag *parag, int *oldIndent, int *newIndent );
+    void indent( QTextDocument *doc, QTextParagraph *parag, int *oldIndent, int *newIndent );
 
 };
 
