@@ -3,6 +3,7 @@
 #include "previewframe.h"
 #include "paletteeditoradvanced.h"
 
+#include <qlabel.h>
 #include <qapplication.h>
 #include <qcombobox.h>
 #include <qstylefactory.h>
@@ -40,7 +41,7 @@ static const char *appearance_text =
 "customize the colors.</p>"
 "<p>Any GUI Style plugins in your plugin path will automatically be added "
 "to the list of built-in Qt styles.</p>"
-"<p>Upon choosing 3-D Effects and Background colors, the Qt Configutaion "
+"<p>Upon choosing 3-D Effects and Background colors, the Qt Configuration "
 "program will automatically generate a palette for you.  To customize "
 "colors further, press the Tune Palette button to open the advanced "
 "palette editor."
@@ -105,10 +106,10 @@ static const char *printer_text =
 "so adding those directories is not needed.</p>";
 
 static const char *about_text =
-"<p><b><font size+=4>About Qt Configuration</font></b><br>"
-"A graphical configuration tool for programs using Qt.</p>"
+"<p><b><font size+=4>About Qt Configuration</font></b></p>"
+"<p>A graphical configuration tool for programs using Qt.</p>"
 "<p>Version 1.0-beta</p>"
-"<p>Copyright (C) 2001 Trolltech AS</p>"
+"<p>Copyright (C) 2001-2002 Trolltech AS</p>"
 "<p></p>"
 "<p>This program is licensed to you under the terms of the GNU General "
 "Public License Version 2 as published by the Free Software Foundation. This "
@@ -565,6 +566,13 @@ MainWindow::MainWindow()
 
     rtlExtensions->setChecked( settings.readBoolEntry( "/qt/useRtlExtensions", FALSE ) );
 
+#ifdef Q_WS_X11
+    inputStyle->setCurrentText( settings.readEntry( "/qt/XIMInputStyle", trUtf8( "On The Spot" ) ) );
+#else
+    inputStyle->hide();
+    inputStyleLabel->hide();
+#endif
+    
 #ifdef Q_WS_X11
     xftcheckbox->setChecked( settings.readBoolEntry( "/qt/enableXft", TRUE ) );
     if ( xftcheckbox->isChecked() ) {
@@ -650,6 +658,18 @@ void MainWindow::fileSave()
 
 	settings.writeEntry("/qt/useRtlExtensions", rtlExtensions->isChecked() );
 
+#ifdef Q_WS_X11	
+	QString style = inputStyle->currentText();
+	QString str = "On The Spot";
+	if ( style == trUtf8( "Over The Spot" ) )
+	    str = "Over The Spot";
+	else if ( style == trUtf8( "Off The Spot" ) )
+	    str = "Off The Spot";
+	else if ( style == trUtf8( "Root" ) )
+	    str = "Root";
+        settings.writeEntry( "/qt/XIMInputStyle", inputStyle->currentText() );
+#endif
+	
 	QStringList effects;
 	if (effectcheckbox->isChecked()) {
 	    effects << "general";
